################################################################################
# summary stats figures ########################################################
################################################################################

xh=read.csv("HF_NestBox_18August2015.csv", header=TRUE, as.is=FALSE)
xd=read.csv("DF_NestBox_18August2015.csv", header=TRUE, as.is=FALSE)

tiff("NestBoxSamplingPeriods.tif", height=6, width=6, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2), mgp=c(3.1,.6,0))
plot(1, type="n", ylab="Julian date", xlab="Year", ylim=c(1,365), xlim=c(2011,2015))
points(JD ~ I(Year-.05), xh, col = "darkolivegreen", pch=16, cex=1.5)
points(JD ~ I(Year+.05), xd, col = "darkorange", pch=16, cex=1.5)
dev.off()

################################################################################
# Duke Forest ##################################################################
################################################################################

x1=read.csv("DF_NestBox_18August2015.csv", header=TRUE, as.is=FALSE)
     x1$Cham=as.factor(x1$Cham)

require(car)
x1$JD_continuous=rep(NA, times=length(x1$Year))
for(i in 1:dim(x1)[1]) {
temp=x1[i, ]
if(temp$Year==2011) {
x1$JD_continuous[i]<-(x1$JD[i] + 365*2)
}
if(temp$Year==2012) {
x1$JD_continuous[i]<-(x1$JD[i] + 365*3)
}
if(temp$Year==2013) {
x1$JD_continuous[i]<-(x1$JD[i] + 365*4)
}
if(temp$Year==2014) {
x1$JD_continuous[i]<-(x1$JD[i] + 365*5)
}
if(temp$Year==2015) {
x1$JD_continuous[i]<-(x1$JD[i] + 365*6)
}
}

#Assign an event number to each check date
JD_continuous=unique(x1$JD_continuous)
Event=c(1:length(unique(JD_continuous)))
table1=cbind(JD_continuous,Event)
x2=merge(x1,table1,all=TRUE)

#Subset data so that it is only data from inside the nests
#This removes all data from beneath the nests, but includes both the newer and older nests
x = x2[x2$Under == 'N',]

aggregate(Cham ~ U.sp, x, length)
unique(x[x$U.sp=="apla",]$Cham)
unique(x[x$U.sp=="apru",]$Cham)
unique(x[x$U.sp=="brch",]$Cham)
unique(x[x$U.sp=="crli",]$Cham)
unique(x[x$U.sp=="tecu",]$Cham)
unique(x[x$U.sp=="nyfl",]$Cham)

#Create a column of unique nest box identifiers
x$NestUnique = paste(x$Cham, x$Nest, x$Under)

#Idenfify all of the unique species in the dataset and remove non-ant species
species = unique(x$U.sp)
x$U.sp = recode(x$U.sp, "'arac'= 0; 'cent'= 0; 'term'= 0; 'unkn'=0; 'ampa'=0; 'prim'=0; 'pyun'=0; 'nyfl'=0; 'pope'=0; 'caca'=0") 
x$U.sp = recode(x$U.sp, "'apru'='aphe';'apla'='aphe'") #Bin A. rudis and A. lamellidens into single category

aggregate(Cham ~ U.sp, x, length)
unique(x[x$U.sp=="aphe",]$Cham)

#subset the dataset to only the event number, unique nest ID and SpeciesID and reshape into wide format
sub = x[,c('Event','NestUnique', 'U.sp')]
require(reshape)
wideNest = as.data.frame(reshape(sub, v.names='U.sp', idvar='NestUnique', timevar='Event',direction='wide'))

#Split the nest box unique ID into its component parts to sort and subset
wideNestsplit=colsplit(wideNest$NestUnique, split=" ",names=c("ch","Nest","Under"))
wideNest2 = cbind(wideNestsplit, wideNest[,2:ncol(wideNest)])
colnames(wideNest2) = c("ch","Nest","Under", c(paste('T',1:(ncol(wideNest2)-3), sep='')))

wideNest2[,ncol(wideNest2)][is.na(wideNest2[,ncol(wideNest2)])] <- 0

dat=wideNest2
dat1=dat[order(dat$ch),]


dfcatches=c()
for(i in 1:dim(dat1)[1]) {
x<-unique(c(as.character(unlist(dat1[i,4:ncol(dat1)]),0)))
temp<-length(x[!is.na(x)])
dfcatches=rbind(temp, dfcatches)
}

hist(dfcatches)

samp.times<-diff(unique(x1$JD_continuous))

range(samp.times)
mean(samp.times)
sd(samp.times)



################################################################################
# transition matrices ##########################################################
################################################################################

library(popbio)

tmats=list()
for(j in 1:length(unique(dat1$ch))) {

      temp1<-dat1[dat1$ch==unique(dat1$ch)[j], ]

            lmats=list()
            for(k in 1:length(unique(temp1$Nest))) {

                  temp2<-temp1[temp1$Nest==unique(temp1$Nest)[k],]

                  temp3<-temp2[,-c(1,2,3)]

                  t1<-temp3

                  t1a<-ifelse(colSums(ifelse(t1 == "aphe", 1, 0), na.rm=TRUE) > 0, 1, 0)
                  t1b<-ifelse(colSums(ifelse(t1 == "brch", 1, 0), na.rm=TRUE) > 0, 1, 0)
                  t1c<-ifelse(colSums(ifelse(t1 == "crli", 1, 0), na.rm=TRUE) > 0, 1, 0)
                  t1t<-ifelse(colSums(ifelse(t1 == "tecu", 1, 0), na.rm=TRUE) > 0, 1, 0)

                  dmat<-rbind(t1a,t1b,t1c,t1t)
                  rownames(dmat)<-c("aphe","brch","crli","tecu")
                  colnames(dmat)<- c(paste('Census',1:ncol(dmat), sep=''))


                  TransMat <- function (Occ=x) {

                  # Set up the empty square transition matrix
                  # With S species, dimensions are (S+1) rows,cols
                   Markov <- matrix(data=rep(0,(nrow(Occ) + 1)^2),nrow=nrow(Occ) + 1)
                      rownames(Markov) <- c("Empty",paste("Species",seq(1:nrow(Occ)),sep=""))
                      colnames(Markov) <- c("Empty",paste("Species",seq(1:nrow(Occ)),sep=""))

                  # Create vector of states at each census
                  # 0 = empty, 1 = Species1, 2 = Species2
                  NestState <- rep(0,ncol(Occ)) # set up empty vector

                  # Now fill it based on occupancy data
                    for (i in 1:ncol(Occ)) {
                      if(sum(Occ[,i])>0) NestState[i] <- which(as.vector(Occ[,i]==1))
                      }

                  # Use the NestState vector to fill the transition matrix with counts
                  NestState <- NestState + 1 # shift empty group label from 0 to 1

                  # Now fill the transition matrix with counts
                  for (i in 1:(length(NestState)-1)) {
                    a <- NestState[i]
                    b <- NestState[i + 1]
                    Markov[b,a] <- Markov[b,a] + 1
                    }
                  return(Markov)
                  }


          lmats[[k]]<-TransMat(dmat)




          }
          tmats[[j]]<-Reduce('+', lmats)

          }



stability=c()
for(z in 1:length(tmats)) {

        SummaryVars <- function(m) {

        # Scale raw counts so columns sum to 1.0
        TransProbs <- prop.table(m,margin=2)

        if(is.na(sum(TransProbs))) {
        TransProbs <- TransProbs[-as.numeric(which(is.na(TransProbs[1 , ]))),-as.numeric(which(is.na(TransProbs[1 , ])))]
        } else(TransProbs<-TransProbs)
        # Sweep NAs from array; recode as 0
        #TransProbs[is.na(TransProbs)]<-0

        # Equilibrium frequencies from popbio package
        StableStage <- eigen.analysis(TransProbs)$stable.stage

        # DampingRatio from popbio package
        DampingRatio <- damping.ratio(TransProbs)

        # Return the list
        MatResult <- list(TransProbs=TransProbs,StableStage=StableStage,DampingRatio=DampingRatio)
          return(MatResult)
          }


raw.trans<-matrix(paste(unlist(lapply( tmats, colSums)), "/320", sep=""), ncol=5, byrow=TRUE)
write.csv(raw.trans, "DF_rawtrans.csv")


sv<-SummaryVars(tmats[[z]])
PIE<-1-sum((sv$StableStage[2:length(sv$StableStage)]/sum(sv$StableStage[2:length(sv$StableStage)]))^2)


stability=rbind(stability, cbind(z, as.numeric(sv$DampingRatio),
ifelse(length(sv$StableStage[which(names(sv$StableStage)=="Empty")])>0, sv$StableStage[which(names(sv$StableStage)=="Empty")], NA), 
ifelse(length(sv$StableStage[which(names(sv$StableStage)=="Species1")])>0, sv$StableStage[which(names(sv$StableStage)=="Species1")], NA),
ifelse(length(sv$StableStage[which(names(sv$StableStage)=="Species2")])>0, sv$StableStage[which(names(sv$StableStage)=="Species2")], NA),
ifelse(length(sv$StableStage[which(names(sv$StableStage)=="Species3")])>0, sv$StableStage[which(names(sv$StableStage)=="Species3")], NA),
ifelse(length(sv$StableStage[which(names(sv$StableStage)=="Species4")])>0, sv$StableStage[which(names(sv$StableStage)=="Species4")], NA),

ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs)=="Empty")])>0, sv$TransProbs["Empty","Empty"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species1","Empty"))])>=2, sv$TransProbs["Species1","Empty"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species2","Empty"))])>=2, sv$TransProbs["Species2","Empty"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species3","Empty"))])>=2, sv$TransProbs["Species3","Empty"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species4","Empty"))])>=2, sv$TransProbs["Species4","Empty"], NA),

ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Empty","Species1"))])>=2, sv$TransProbs["Empty","Species1"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs)=="Species1")])>0, sv$TransProbs["Species1","Species1"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species2","Species1"))])>=2, sv$TransProbs["Species2","Species1"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species3","Species1"))])>=2, sv$TransProbs["Species3","Species1"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species4","Species1"))])>=2, sv$TransProbs["Species4","Species1"], NA),

ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Empty","Species2"))])>=2, sv$TransProbs["Empty","Species2"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species1","Species2"))])>=2, sv$TransProbs["Species1","Species2"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs)=="Species2")])>0, sv$TransProbs["Species2","Species2"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species3","Species2"))])>=2, sv$TransProbs["Species3","Species2"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species4","Species2"))])>=2, sv$TransProbs["Species4","Species2"], NA),

ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Empty","Species3"))])>=2, sv$TransProbs["Empty","Species3"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species1","Species3"))])>=2, sv$TransProbs["Species1","Species3"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species2","Species3"))])>=2, sv$TransProbs["Species2","Species3"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs)=="Species3")])>0, sv$TransProbs["Species3","Species3"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species4","Species3"))])>=2, sv$TransProbs["Species4","Species3"], NA),

ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Empty","Species4"))])>=2, sv$TransProbs["Empty","Species4"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species1","Species4"))])>=2, sv$TransProbs["Species1","Species4"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species2","Species4"))])>=2, sv$TransProbs["Species2","Species4"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species3","Species4"))])>=2, sv$TransProbs["Species3","Species4"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs)=="Species4")])>0, sv$TransProbs["Species4","Species4"], NA),
PIE
))
}


sta<-data.frame(ch=stability[,1], DampingRatio=stability[,2],
StableStageEmpty=stability[,3], StableStageAphe=stability[,4], StableStageBrch=stability[,5], StableStageCrli=stability[,6], StableStageTecu=stability[,7], 
EmptyToEmpty=stability[,8], EmptyToAphe=stability[,9], EmptyToBrch=stability[,10], EmptyToCrli=stability[,11], EmptyToTecu=stability[,12],
ApheToEmpty=stability[,13], ApheToAphe=stability[,14], ApheToBrch=stability[,15], ApheToCrli=stability[,16], ApheToTecu=stability[,17],
BrchToEmpty=stability[,18], BrchToAphe=stability[,19], BrchToBrch=stability[,20], BrchToCrli=stability[,21], BrchToTecu=stability[,22],
CrliToEmpty=stability[,23], CrliToAphe=stability[,24], CrliToBrch=stability[,25], CrliToCrli=stability[,26], CrliToTecu=stability[,27],
TecuToEmpty=stability[,28], TecuToAphe=stability[,29], TecuToBrch=stability[,30], TecuToCrli=stability[,31], TecuToTecu=stability[,32], PIE=stability[,33]
)




library(car)
sta$Target_Delta<-recode(sta$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

sta.dat<-merge(sta, temp_vals[,1:3], "ch")

 write.csv(sta.dat, "DFstadat.csv")


fm.cmat=c()
for(i in 1:15) {
        
        cmat<-tmats[[i]]

        TransProbs <- prop.table(cmat,margin=2)

        if(is.na(sum(TransProbs))) {
        TransProbs <- TransProbs[-as.numeric(which(is.na(TransProbs[1 , ]))),-as.numeric(which(is.na(TransProbs[1 , ])))]
        } else(TransProbs<-TransProbs)
        
pp<-pop.projection(TransProbs,c(10000,rep(0, times=ncol(TransProbs)-1)),10000)$stage.vectors[1,]

mp<-which.min(round(pp,0))

fm.cmat=rbind(fm.cmat, cbind(i,mp))
}

fm.cmat<-as.data.frame(fm.cmat)
colnames(fm.cmat)<-c("ch","rt")

return.time<-merge(sta.dat,fm.cmat)

 write.csv(return.time, "DFreturntime.csv")


plot(pop.projection(TransProbs,c(10000,0,0),10000)$stage.vectors[1,]~seq(0,9999,1))

df.counts<-lapply(tmats, function(x)  sum(ifelse(colSums(x)>0,1,0))-1)
df.counts1<-merge(data.frame(spp.counts=unlist(df.counts),ch=1:15),temp_vals[,1:3], "ch")


write.csv(df.counts1, "DFsppcounts.csv")

tiff("DF_PIE_provisional_6August2015.tif", height=6, width=6, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2), mgp=c(3.1,.6,0))
plot(PIE ~ CAT_Avg, data=sta.dat, xlab="Chamber temperature (C)", ylab="PIE", pch=16, cex=1.5)
dm<-lm(PIE ~ CAT_Avg, data=sta.dat, na.action=na.omit)
abline(dm)
cf <- round(coef(dm), 2)
eq <- paste0("y = ", cf[1],
             ifelse(sign(cf[2])==1, " + ", " - "), abs(cf[2]), " MAT; p = ", round(summary(dm)$coefficients[2,4],2))
mtext(eq, 3, line=.5)
dev.off() 



################################################################################
# Harvard Forest ###############################################################
################################################################################

x1=read.csv("HF_NestBox_18August2015.csv", header=TRUE, as.is=FALSE)
x1$Cham=as.factor(x1$Cham)

require(car)
x1$JD_continuous=rep(NA, times=length(x1$Year))

for(i in 1:dim(x1)[1]) {
  temp=x1[i, ]

  if(temp$Year==2011) {
    x1$JD_continuous[i]<-(x1$JD[i] + 365*2)
  }

  if(temp$Year==2012) {
    x1$JD_continuous[i]<-(x1$JD[i] + 365*3)
  }

  if(temp$Year==2013) {
    x1$JD_continuous[i]<-(x1$JD[i] + 365*4)
  }

  if(temp$Year==2014) {
    x1$JD_continuous[i]<-(x1$JD[i] + 365*5)
  }
  
  if(temp$Year==2015) {
    x1$JD_continuous[i]<-(x1$JD[i] + 365*6)
  }
}

#Subset data so that it is only data from inside the first set of nests.
#This removes all data from the 2nd set of nests and beneath either nest
x = x1[!x1$Under == 'Yes',]

aggregate(Cham ~ U.sp, x, length)
unique(x[x$U.sp=="appi",]$Cham)
unique(x[x$U.sp=="apru",]$Cham)
unique(x[x$U.sp=="apun",]$Cham)
unique(x[x$U.sp=="cane",]$Cham)
unique(x[x$U.sp=="cano",]$Cham)
unique(x[x$U.sp=="cape",]$Cham)
unique(x[x$U.sp=="foun",]$Cham)
unique(x[x$U.sp=="laal",]$Cham)
unique(x[x$U.sp=="lane",]$Cham)
unique(x[x$U.sp=="laun",]$Cham)
unique(x[x$U.sp=="mypu",]$Cham)
unique(x[x$U.sp=="myun",]$Cham)
unique(x[x$U.sp=="tase",]$Cham)
unique(x[x$U.sp=="telo",]$Cham)


#Create a column of unique nest box identifiers
x$NestUnique = paste(x$Cham, x$Nest)

#Idenfify all of the unique species in the dataset and remove non-ant species
species = unique(x$U.sp)
x$U.sp = recode(x$U.sp, "'arac'= 0; 'cent'= 0; 'term'= 0; 'foun'=0; 'tase'=0; 'unkn'=0") 
x$U.sp = recode(x$U.sp, "'apru'='aphe';
                'appi'='aphe';
                'apun'='aphe';
                'laun'='laal';
                'lane'='laal';
                'cape'='camp';
                'cano'='camp';
                'cane'='camp';
                'myun'='myrm';
                'mypu'='myrm'") 
                
aggregate(Cham ~ U.sp, x, length)
unique(x[x$U.sp=="aphe",]$Cham)
unique(x[x$U.sp=="camp",]$Cham)
unique(x[x$U.sp=="laal",]$Cham)
unique(x[x$U.sp=="myrm",]$Cham)
unique(x[x$U.sp=="telo",]$Cham)


#subset the dataset to only the event number, unique nest ID and SpeciesID and reshape into wide format
sub = x[,c('JD_continuous','NestUnique', 'U.sp')]

require(reshape)
wideNest = as.data.frame(reshape(sub, v.names='U.sp', idvar='NestUnique', timevar='JD_continuous',direction='wide'))

#Split the nest box unique ID into its component parts to sort and subset
wideNestsplit=colsplit(wideNest$NestUnique, split=" ",names=c("ch","Nest"))
wideNest2 = cbind(wideNestsplit, wideNest[,2:ncol(wideNest)])
colnames(wideNest2) = c("ch","Nest", c(paste('T',1:(ncol(wideNest2)-2), sep='')))

wideNest2[,12:ncol(wideNest2)][is.na(wideNest2[,12:ncol(wideNest2)])] <- 0


dat=wideNest2
dat1=dat[order(dat$ch),]


hfcatches=c()
for(i in 1:dim(dat1)[1]) {
x<-unique(c(as.character(unlist(dat1[i,4:ncol(dat1)]),0)))
temp<-length(x[!is.na(x)])
hfcatches=rbind(temp, hfcatches)
}

hist(hfcatches)

samp.times<-diff(unique(x1$JD_continuous))

range(samp.times)
mean(samp.times)
sd(samp.times)


################################################################################
# transition matrices ##########################################################
################################################################################

library(popbio)

tmats=list()
for(j in 1:length(unique(dat1$ch))) {

      temp1<-dat1[dat1$ch==unique(dat1$ch)[j], ]

            lmats=list()
            for(k in 1:length(unique(temp1$Nest))) {

                  temp2<-temp1[temp1$Nest==unique(temp1$Nest)[k],]

                  temp3<-temp2[,-c(1,2)]

                  t1<-temp3

                  t1a<-ifelse(colSums(ifelse(t1 == "aphe", 1, 0), na.rm=TRUE) > 0, 1, 0)
                  t1c<-ifelse(colSums(ifelse(t1 == "camp", 1, 0), na.rm=TRUE) > 0, 1, 0)
                  t1l<-ifelse(colSums(ifelse(t1 == "laal", 1, 0), na.rm=TRUE) > 0, 1, 0)
                  t1m<-ifelse(colSums(ifelse(t1 == "myrm", 1, 0), na.rm=TRUE) > 0, 1, 0)
                  t1t<-ifelse(colSums(ifelse(t1 == "telo", 1, 0), na.rm=TRUE) > 0, 1, 0)

                  dmat<-rbind(t1a,t1c,t1l,t1m,t1t)
                  rownames(dmat)<-c("aphe","camp","laal","myrm","telo")
                  colnames(dmat)<- c(paste('Census',1:ncol(dmat), sep=''))


                  TransMat <- function (Occ=x) {

                  # Set up the empty square transition matrix
                  # With S species, dimensions are (S+1) rows,cols
                   Markov <- matrix(data=rep(0,(nrow(Occ) + 1)^2),nrow=nrow(Occ) + 1)
                      rownames(Markov) <- c("Empty",paste("Species",seq(1:nrow(Occ)),sep=""))
                      colnames(Markov) <- c("Empty",paste("Species",seq(1:nrow(Occ)),sep=""))

                  # Create vector of states at each census
                  # 0 = empty, 1 = Species1, 2 = Species2
                  NestState <- rep(0,ncol(Occ)) # set up empty vector

                  # Now fill it based on occupancy data
                    for (i in 1:ncol(Occ)) {
                      if(sum(Occ[,i])>0) NestState[i] <- which(as.vector(Occ[,i]==1))
                      }

                  # Use the NestState vector to fill the transition matrix with counts
                  NestState <- NestState + 1 # shift empty group label from 0 to 1

                  # Now fill the transition matrix with counts
                  for (i in 1:(length(NestState)-1)) {
                    a <- NestState[i]
                    b <- NestState[i + 1]
                    Markov[b,a] <- Markov[b,a] + 1
                    }
                  return(Markov)
                  }

                  lmats[[k]]<-TransMat(dmat)




                  }
                  tmats[[j]]<-Reduce('+', lmats)

                  }

raw.trans<-matrix(paste(unlist(lapply( tmats, colSums)), "/144", sep=""), ncol=6, byrow=TRUE)
write.csv(raw.trans, "HF_rawtrans.csv")

#tmats[[3]]<-tmats[[3]][-3,-3]
#tmats[[10]]<-tmats[[10]][-3,-3]
tmats[[3]][c(1,2,4,5,6),3]<-1
tmats[[10]][c(1,2,4,5,6),3]<-1

stability=c()
for(z in 1:length(tmats)) {

        SummaryVars <- function(m) {

        # Scale raw counts so columns sum to 1.0
        TransProbs <- prop.table(m,margin=2)

        if(is.na(sum(TransProbs))) {
        TransProbs <- TransProbs[-as.numeric(which(is.na(TransProbs[1 , ]))),-as.numeric(which(is.na(TransProbs[1 , ])))]
        } else(TransProbs<-TransProbs)

        # Equilibrium frequencies from popbio package
        StableStage <- eigen.analysis(TransProbs)$stable.stage

        # DampingRatio from popbio package
        DampingRatio <- damping.ratio(TransProbs)

        # Return the list
        MatResult <- list(TransProbs=TransProbs,StableStage=StableStage,DampingRatio=DampingRatio)
          return(MatResult)
          }


sv<-SummaryVars(tmats[[z]])
PIE<-1-sum((sv$StableStage[2:length(sv$StableStage)]/sum(sv$StableStage[2:length(sv$StableStage)]))^2)

stability=rbind(stability, cbind(z, as.numeric(sv$DampingRatio),
ifelse(length(sv$StableStage[which(names(sv$StableStage)=="Empty")])>0, sv$StableStage[which(names(sv$StableStage)=="Empty")], NA), 
ifelse(length(sv$StableStage[which(names(sv$StableStage)=="Species1")])>0, sv$StableStage[which(names(sv$StableStage)=="Species1")], NA),
ifelse(length(sv$StableStage[which(names(sv$StableStage)=="Species2")])>0, sv$StableStage[which(names(sv$StableStage)=="Species2")], NA),
ifelse(length(sv$StableStage[which(names(sv$StableStage)=="Species3")])>0, sv$StableStage[which(names(sv$StableStage)=="Species3")], NA),
ifelse(length(sv$StableStage[which(names(sv$StableStage)=="Species4")])>0, sv$StableStage[which(names(sv$StableStage)=="Species4")], NA),
ifelse(length(sv$StableStage[which(names(sv$StableStage)=="Species5")])>0, sv$StableStage[which(names(sv$StableStage)=="Species5")], NA),

ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs)=="Empty")])>0, sv$TransProbs["Empty","Empty"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species1","Empty"))])>=2, sv$TransProbs["Species1","Empty"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species2","Empty"))])>=2, sv$TransProbs["Species2","Empty"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species3","Empty"))])>=2, sv$TransProbs["Species3","Empty"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species4","Empty"))])>=2, sv$TransProbs["Species4","Empty"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species5","Empty"))])>=2, sv$TransProbs["Species5","Empty"], NA),

ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Empty","Species1"))])>=2, sv$TransProbs["Empty","Species1"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs)=="Species1")])>0, sv$TransProbs["Species1","Species1"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species2","Species1"))])>=2, sv$TransProbs["Species2","Species1"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species3","Species1"))])>=2, sv$TransProbs["Species3","Species1"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species4","Species1"))])>=2, sv$TransProbs["Species4","Species1"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species5","Species1"))])>=2, sv$TransProbs["Species5","Species1"], NA),

ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Empty","Species2"))])>=2, sv$TransProbs["Empty","Species2"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species1","Species2"))])>=2, sv$TransProbs["Species1","Species2"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs)=="Species2")])>0, sv$TransProbs["Species2","Species2"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species3","Species2"))])>=2, sv$TransProbs["Species3","Species2"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species4","Species2"))])>=2, sv$TransProbs["Species4","Species2"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species5","Species2"))])>=2, sv$TransProbs["Species5","Species2"], NA),

ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Empty","Species3"))])>=2, sv$TransProbs["Empty","Species3"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species1","Species3"))])>=2, sv$TransProbs["Species1","Species3"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species2","Species3"))])>=2, sv$TransProbs["Species2","Species3"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs)=="Species3")])>0, sv$TransProbs["Species3","Species3"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species4","Species3"))])>=2, sv$TransProbs["Species4","Species3"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species5","Species3"))])>=2, sv$TransProbs["Species5","Species3"], NA),

ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Empty","Species4"))])>=2, sv$TransProbs["Empty","Species4"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species1","Species4"))])>=2, sv$TransProbs["Species1","Species4"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species2","Species4"))])>=2, sv$TransProbs["Species2","Species4"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species3","Species4"))])>=2, sv$TransProbs["Species3","Species4"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs)=="Species4")])>0, sv$TransProbs["Species4","Species4"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species5","Species4"))])>=2, sv$TransProbs["Species5","Species4"], NA),

ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Empty","Species5"))])>=2, sv$TransProbs["Empty","Species5"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species1","Species5"))])>=2, sv$TransProbs["Species1","Species5"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species2","Species5"))])>=2, sv$TransProbs["Species2","Species5"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species3","Species5"))])>=2, sv$TransProbs["Species3","Species5"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs) %in% c("Species4","Species5"))])>=2, sv$TransProbs["Species4","Species5"], NA),
ifelse(length(sv$TransProbs[which(colnames(sv$TransProbs)=="Species5")])>0, sv$TransProbs["Species5","Species5"], NA),
PIE
))
}



sta<-data.frame(ch=stability[,1], DampingRatio=stability[,2],
StableStageEmpty=stability[,3], StableStageAphe=stability[,4], StableStageCamp=stability[,5], StableStageLaal=stability[,6], StableStageMyrm=stability[,7], StableStageTelo=stability[,8],
EmptyToEmpty=stability[,9], EmptyToAphe=stability[,10], EmptyToCamp=stability[,11], EmptyToLaal=stability[,12], EmptyToMyrm=stability[,13], EmptyToTelo=stability[,14],
ApheToEmpty=stability[,15], ApheToAphe=stability[,16], ApheToCamp=stability[,17], ApheToLaal=stability[,18], ApheToMyrm=stability[,19], ApheToTelo=stability[,20],
CampToEmpty=stability[,21], CampToAphe=stability[,22], CampToCamp=stability[,23], CampToLaal=stability[,24], CampToMyrm=stability[,25], CampToTelo=stability[,26],
LaalToEmpty=stability[,27], LaalToAphe=stability[,28], LaalToCamp=stability[,29], LaalToLaal=stability[,30], LaalToMyrm=stability[,31], LaalToTelo=stability[,32],
MyrmToEmpty=stability[,33], MyrmToAphe=stability[,34], MyrmToCamp=stability[,35], MyrmToLaal=stability[,36], MyrmToMyrm=stability[,37], MyrmToTelo=stability[,38],
TeloToEmpty=stability[,39], TeloToAphe=stability[,40], TeloToCamp=stability[,41], TeloToLaal=stability[,42], TeloToMyrm=stability[,43], TeloToTelo=stability[,44],
PIE=stability[,45]
)
library(car)
sta$Target_Delta<-recode(sta$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))






temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

sta.dat<-merge(sta, temp_vals[,1:3], "ch")

 write.csv(sta.dat, "HFstadat.csv")

fm.cmat=c()
for(i in 1:15) {
        
        cmat<-tmats[[i]]

        TransProbs <- prop.table(cmat,margin=2)

        if(is.na(sum(TransProbs))) {
        TransProbs <- TransProbs[-as.numeric(which(is.na(TransProbs[1 , ]))),-as.numeric(which(is.na(TransProbs[1 , ])))]
        } else(TransProbs<-TransProbs)
        
pp<-pop.projection(TransProbs,c(10000,rep(0, times=ncol(TransProbs)-1)),10000)$stage.vectors[1,]

mp<-which.min(round(pp,0))

fm.cmat=rbind(fm.cmat, cbind(i,mp))
}

fm.cmat<-as.data.frame(fm.cmat)
colnames(fm.cmat)<-c("ch","rt")

return.time<-merge(sta.dat,fm.cmat)

 write.csv(return.time, "HFreturntime.csv")
 
 plot(DampingRatio ~ rt, return.time[return.time$ch!=5,])
 anova(lm(rt ~ CAT_Avg, return.time[return.time$ch!=5,]))



hf.counts<-lapply(tmats, function(x)  sum(ifelse(colSums(x)>0,1,0))-1)
hf.counts1<-merge(data.frame(spp.counts=unlist(hf.counts),ch=1:15),temp_vals[,1:3], "ch")


write.csv(hf.counts1, "HFsppcounts.csv")



tiff("HF_PIE_provisional_6August2015.tif", height=6, width=6, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2), mgp=c(3.1,.6,0))
plot(PIE ~ CAT_Avg, data=sta.dat, xlab="Chamber temperature (C)", ylab="PIE", pch=16, cex=1.5)
dm<-lm(PIE ~ CAT_Avg, data=sta.dat, na.action=na.omit)
abline(dm)
cf <- round(coef(dm), 2)
eq <- paste0("y = ", cf[1],
             ifelse(sign(cf[2])==1, " + ", " - "), abs(cf[2]), " MAT; p = ", round(summary(dm)$coefficients[2,4],2))
mtext(eq, 3, line=.5)
dev.off() 





################################################################################
# cross-site ANCOVA ############################################################
################################################################################

library(binom)
# damping ratio
dfdat<-read.csv("DFstadat.csv", header=TRUE)
dfdat$site<-rep("DF", times=dim(dfdat)[1])
hfdat<-read.csv("HFstadat.csv", header=TRUE)
hfdat$site<-rep("HF", times=dim(hfdat)[1])
hfdat<-hfdat[hfdat$ch !="5",]

alldat<-merge(dfdat,hfdat, all=TRUE)
alldat$cols<-recode(alldat$site, "'DF'='darkorange';'HF'='darkolivegreen'")
alldat$pchs<-recode(alldat$ch, "lo:12=16; 13:hi=21")
alldat$site.ch<-paste(alldat$site, alldat$ch, sep="_")
alldat$cols.bg<-recode(alldat$site.ch, "'DF_1'='darkorange';
                                       'DF_2'='darkorange';
                                       'DF_3'='darkorange';
                                       'DF_4'='darkorange';
                                       'DF_5'='darkorange';
                                       'DF_6'='darkorange';
                                       'DF_7'='darkorange';
                                       'DF_8'='darkorange';
                                       'DF_9'='darkorange';
                                       'DF_10'='darkorange';
                                       'DF_11'='darkorange';
                                       'DF_12'='darkorange';
                                       'DF_13'='transparent';
                                       'DF_14'='transparent';
                                       'DF_15'='transparent';
                                       'HF_1'='darkolivegreen';
                                       'HF_2'='darkolivegreen';
                                       'HF_3'='darkolivegreen';
                                       'HF_4'='darkolivegreen';
                                       'HF_5'='darkolivegreen';
                                       'HF_6'='darkolivegreen';
                                       'HF_7'='darkolivegreen';
                                       'HF_8'='darkolivegreen';
                                       'HF_9'='darkolivegreen';
                                       'HF_10'='darkolivegreen';
                                       'HF_11'='darkolivegreen';
                                       'HF_12'='darkolivegreen';
                                       'HF_13'='transparent';
                                       'HF_14'='transparent';
                                       'HF_15'='transparent'")

# df comm
dfcomm1<-read.csv("Entire_DF_community_18August2015.csv", header=TRUE)

# recode the chamber IDs to target deltas
library(car)
dfcomm1$Target_Delta<-recode(dfcomm1$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"


dfcomm<-merge(dfcomm1, temp_vals[,1:3], "ch")
dfcomm$pchs<-recode(dfcomm$ch, "lo:12=16; 13:hi=21")

dfcomm.col<-dfcomm[dfcomm$col.den > 0,]
dfcomm.ext<-dfcomm[dfcomm$ext.den > 0,]
dfcomm.occ<-dfcomm[dfcomm$occ.den > 0,]

dfmod.col<-glm(cbind(col.numr,col.denr) ~ CAT_Avg, dfcomm.col, family=quasibinomial)
dfmod.ext<-glm(cbind(ext.numr,ext.denr) ~ CAT_Avg, dfcomm.ext, family=quasibinomial)
dfmod.occ<-glm(cbind(occ.numr,occ.denr) ~ CAT_Avg, dfcomm.occ, family=quasibinomial)


# hf comm
hfcomm1<-read.csv("Entire_HF_community_18August2015.csv", header=TRUE)

# recode the chamber IDs to target deltas
library(car)
hfcomm1$Target_Delta<-recode(hfcomm1$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hfcomm<-merge(hfcomm1, temp_vals[,1:3], "ch")
hfcomm$pchs<-recode(hfcomm$ch, "lo:12=16; 13:hi=21")

hfcomm.col<-hfcomm[hfcomm$col.den > 0 & hfcomm$ch !=5,]
hfcomm.ext<-hfcomm[hfcomm$ext.den > 0 & hfcomm$ch !=5,]
hfcomm.occ<-hfcomm[hfcomm$occ.den > 0 & hfcomm$ch !=5,]

hfmod.col<-glm(cbind(col.numr,col.denr) ~ CAT_Avg, hfcomm.col, family=quasibinomial)
hfmod.ext<-glm(cbind(ext.numr,ext.denr) ~ CAT_Avg, hfcomm.ext, family=quasibinomial)
hfmod.occ<-glm(cbind(occ.numr,occ.denr) ~ CAT_Avg, hfcomm.occ, family=quasibinomial)

# col vs. extinction of occupancy

df.col.ext<-glm(cbind(occ.numr, occ.denr) ~ I(col.numr/col.denr) + I(ext.numr/ext.denr), data = dfcomm, family=quasibinomial)
summary(df.col.ext)
anova(df.col.ext, test="Chi")

hf.col.ext<-glm(cbind(occ.numr, occ.denr) ~ I(col.numr/col.denr) + I(ext.numr/ext.denr), data = hfcomm[hfcomm$ch !=5,], family=quasibinomial)
summary(hf.col.ext)
anova(hf.col.ext, test="Chi")


# plot begin ###################################################################

tiff("DampingRatio_CommResponses_29Aug2015.tiff", height=12, width=12, units="in", res=300)

par(mfrow=c(2,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2), mgp=c(3.1,.6,0))

# damping ratio ################################################################
library(TeachingDemos)
plot(DampingRatio ~ CAT_Avg, data=alldat, ylab="Damping Ratio", xlab="Chamber temperature (C)", type="n")

my.symbols(x=alldat$CAT_Avg , y=alldat$DampingRatio, symb=ms.filled.polygon, n=6, inches=.25, bg=alldat$cols.bg, fg=alldat$cols, adj=0)

# HF
dm<-lm(DampingRatio ~ CAT_Avg, data=alldat[alldat$site=="HF",])
lines(predict(dm, data.frame(CAT_Avg=seq(min(alldat[alldat$site=="HF",]$CAT_Avg), max(alldat[alldat$site=="HF",]$CAT_Avg), length.out=100))) ~ 
seq(min(alldat[alldat$site=="HF",]$CAT_Avg), max(alldat[alldat$site=="HF",]$CAT_Avg), length.out=100), col="darkolivegreen", lty=2, lwd=2.5)

# DF
dm<-lm(DampingRatio ~ CAT_Avg, data=alldat[alldat$site=="DF",])
lines(predict(dm, data.frame(CAT_Avg=seq(min(alldat[alldat$site=="DF",]$CAT_Avg), max(alldat[alldat$site=="DF",]$CAT_Avg), length.out=100))) ~ 
seq(min(alldat[alldat$site=="DF",]$CAT_Avg), max(alldat[alldat$site=="DF",]$CAT_Avg), length.out=100), col="darkorange", lty=2, lwd=2.5)

# overall
dm<-lm(DampingRatio ~ site + CAT_Avg, data=alldat)

lines(predict(dm, data.frame(CAT_Avg=seq(8,20,length.out=20), site="HF"))~seq(8,20,length.out=20), lwd=3.5, col="darkolivegreen")
lines(predict(dm, data.frame(CAT_Avg=seq(8,20,length.out=20), site="DF"))~seq(8,20,length.out=20), lwd=3.5, col="darkorange")

# Occupancy ####################################################################
plot(1, type="n", xlab="Chamber temperature (C)", ylab="Occupancy", xlim=c(8.810171, 19.540700), ylim=c(0,0.6))

hf.occ.agg<-as.data.frame(aggregate(cbind(occ.numr,occ.denr) ~ ch, hfcomm.occ, sum))
hf.occ.agg.ci<-binom.confint(hf.occ.agg$occ.numr, hf.occ.agg$occ.denr, methods="exact")
colnames(hf.occ.agg.ci)[2]<-"occ.numr"
colnames(hf.occ.agg.ci)[3]<-"occ.denr"

hf.sum<-merge(hf.occ.agg.ci, hf.occ.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$cols<-"darkolivegreen"
hf.sum2$cols.bg<-recode(hf.sum2$ch, "lo:12='darkolivegreen'; 13:hi='transparent'")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
my.symbols(x=hf.sum2$CAT_Avg , y=hf.sum2$mean, symb=ms.filled.polygon, n=6, inches=.25, bg=hf.sum2$cols.bg, fg=hf.sum2$cols, adj=0)
lines(exp(predict(hfmod.occ, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=2.5, lty=2)

df.occ.agg<-as.data.frame(aggregate(cbind(occ.numr,occ.denr) ~ ch, dfcomm.occ, sum))
df.occ.agg.ci<-binom.confint(df.occ.agg$occ.numr, df.occ.agg$occ.denr, methods="exact")
colnames(df.occ.agg.ci)[2]<-"occ.numr"
colnames(df.occ.agg.ci)[3]<-"occ.denr"

df.sum<-merge(df.occ.agg.ci, df.occ.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$cols<-"darkorange"
df.sum2$cols.bg<-recode(df.sum2$ch, "lo:12='darkorange'; 13:hi='transparent'")


segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
my.symbols(x=df.sum2$CAT_Avg , y=df.sum2$mean, symb=ms.filled.polygon, n=6, inches=.25, bg=df.sum2$cols.bg, fg=df.sum2$cols, adj=0)
lines(exp(predict(dfmod.occ, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=2.5, lty=2)

# Colonization #################################################################
plot(1, type="n", xlab="Chamber temperature (C)", ylab="Colonization", xlim=c(8.810171, 19.540700), ylim=c(0,.25))

hf.col.agg<-as.data.frame(aggregate(cbind(col.numr,col.denr) ~ ch, hfcomm.col, sum))
hf.col.agg.ci<-binom.confint(hf.col.agg$col.numr, hf.col.agg$col.denr, methods="exact")
colnames(hf.col.agg.ci)[2]<-"col.numr"
colnames(hf.col.agg.ci)[3]<-"col.denr"

hf.sum<-merge(hf.col.agg.ci, hf.col.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$cols<-"darkolivegreen"
hf.sum2$cols.bg<-recode(hf.sum2$ch, "lo:12='darkolivegreen'; 13:hi='transparent'")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
my.symbols(x=hf.sum2$CAT_Avg , y=hf.sum2$mean, symb=ms.filled.polygon, n=6, inches=.25, bg=hf.sum2$cols.bg, fg=hf.sum2$cols, adj=0)
lines(exp(predict(hfmod.col, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=2.5, lty=2)

df.col.agg<-as.data.frame(aggregate(cbind(col.numr,col.denr) ~ ch, dfcomm.col, sum))
df.col.agg.ci<-binom.confint(df.col.agg$col.numr, df.col.agg$col.denr, methods="exact")
colnames(df.col.agg.ci)[2]<-"col.numr"
colnames(df.col.agg.ci)[3]<-"col.denr"

df.sum<-merge(df.col.agg.ci, df.col.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$cols<-"darkorange"
df.sum2$cols.bg<-recode(df.sum2$ch, "lo:12='darkorange'; 13:hi='transparent'")

segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
my.symbols(x=df.sum2$CAT_Avg , y=df.sum2$mean, symb=ms.filled.polygon, n=6, inches=.25, bg=df.sum2$cols.bg, fg=df.sum2$cols, adj=0)
lines(exp(predict(dfmod.col, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=2.5, lty=2)

# Extinction ###################################################################
plot(1, type="n", xlab="Chamber temperature (C)", ylab="Extinction", xlim=c(8.810171, 19.540700), ylim=c(0,1))

hf.ext.agg<-as.data.frame(aggregate(cbind(ext.numr,ext.denr) ~ ch, hfcomm.ext, sum))
hf.ext.agg.ci<-binom.confint(hf.ext.agg$ext.numr, hf.ext.agg$ext.denr, methods="exact")
colnames(hf.ext.agg.ci)[2]<-"ext.numr"
colnames(hf.ext.agg.ci)[3]<-"ext.denr"

hf.sum<-merge(hf.ext.agg.ci, hf.ext.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$cols<-"darkolivegreen"
hf.sum2$cols.bg<-recode(hf.sum2$ch, "lo:12='darkolivegreen'; 13:hi='transparent'")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
my.symbols(x=hf.sum2$CAT_Avg , y=hf.sum2$mean, symb=ms.filled.polygon, n=6, inches=.25, bg=hf.sum2$cols.bg, fg=hf.sum2$cols, adj=0)
lines(exp(predict(hfmod.ext, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=2.5, lty=2)

df.ext.agg<-as.data.frame(aggregate(cbind(ext.numr,ext.denr) ~ ch, dfcomm.ext, sum))
df.ext.agg.ci<-binom.confint(df.ext.agg$ext.numr, df.ext.agg$ext.denr, methods="exact")
colnames(df.ext.agg.ci)[2]<-"ext.numr"
colnames(df.ext.agg.ci)[3]<-"ext.denr"

df.sum<-merge(df.ext.agg.ci, df.ext.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$cols<-"darkorange"
df.sum2$cols.bg<-recode(df.sum2$ch, "lo:12='darkorange'; 13:hi='transparent'")

segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
my.symbols(x=df.sum2$CAT_Avg , y=df.sum2$mean, symb=ms.filled.polygon, n=6, inches=.25, bg=df.sum2$cols.bg, fg=df.sum2$cols, adj=0)
lines(exp(predict(dfmod.ext, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=2.5, lty=2)


dev.off()

# plot begin ###################################################################

tiff("DampingRatio_CommResponses_5November2015.tiff", height=12, width=12, units="in", res=300)

par(mfrow=c(2,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2), mgp=c(3.1,.6,0))

# damping ratio ################################################################
library(TeachingDemos)
plot(DampingRatio ~ CAT_Avg, data=alldat, ylab="Damping Ratio", xlab="Chamber temperature (C)", type="n")

my.symbols(x=alldat$CAT_Avg , y=alldat$DampingRatio, symb=ms.filled.polygon, n=6, inches=.25, bg=alldat$cols.bg, fg=alldat$cols, adj=0)

# HF
dm<-lm(DampingRatio ~ CAT_Avg, data=alldat[alldat$site=="HF",])
lines(predict(dm, data.frame(CAT_Avg=seq(min(alldat[alldat$site=="HF",]$CAT_Avg), max(alldat[alldat$site=="HF",]$CAT_Avg), length.out=100))) ~ 
seq(min(alldat[alldat$site=="HF",]$CAT_Avg), max(alldat[alldat$site=="HF",]$CAT_Avg), length.out=100), col="darkolivegreen", lty=2, lwd=2.5)

# DF
dm<-lm(DampingRatio ~ CAT_Avg, data=alldat[alldat$site=="DF",])
lines(predict(dm, data.frame(CAT_Avg=seq(min(alldat[alldat$site=="DF",]$CAT_Avg), max(alldat[alldat$site=="DF",]$CAT_Avg), length.out=100))) ~ 
seq(min(alldat[alldat$site=="DF",]$CAT_Avg), max(alldat[alldat$site=="DF",]$CAT_Avg), length.out=100), col="darkorange", lty=2, lwd=2.5)

# overall
dm<-lm(DampingRatio ~ site + CAT_Avg, data=alldat)

lines(predict(dm, data.frame(CAT_Avg=seq(8,20,length.out=20), site="HF"))~seq(8,20,length.out=20), lwd=3.5, col="darkolivegreen")
lines(predict(dm, data.frame(CAT_Avg=seq(8,20,length.out=20), site="DF"))~seq(8,20,length.out=20), lwd=3.5, col="darkorange")

legend("topright", " ", cex=4)



# Occupancy ####################################################################
plot(1, type="n", xlab="Chamber temperature (C)", ylab="Occupancy", xlim=c(8.810171, 19.540700), ylim=c(0,0.6))

hf.occ.agg<-as.data.frame(aggregate(cbind(occ.numr,occ.denr) ~ ch, hfcomm.occ, sum))
hf.occ.agg.ci<-binom.confint(hf.occ.agg$occ.numr, hf.occ.agg$occ.denr, methods="exact")
colnames(hf.occ.agg.ci)[2]<-"occ.numr"
colnames(hf.occ.agg.ci)[3]<-"occ.denr"

hf.sum<-merge(hf.occ.agg.ci, hf.occ.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$cols<-"darkolivegreen"
hf.sum2$cols.bg<-recode(hf.sum2$ch, "lo:12='darkolivegreen'; 13:hi='transparent'")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
my.symbols(x=hf.sum2$CAT_Avg , y=hf.sum2$mean, symb=ms.filled.polygon, n=6, inches=.25, bg=hf.sum2$cols.bg, fg=hf.sum2$cols, adj=0)
lines(exp(predict(hfmod.occ, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=2.5, lty=2)

df.occ.agg<-as.data.frame(aggregate(cbind(occ.numr,occ.denr) ~ ch, dfcomm.occ, sum))
df.occ.agg.ci<-binom.confint(df.occ.agg$occ.numr, df.occ.agg$occ.denr, methods="exact")
colnames(df.occ.agg.ci)[2]<-"occ.numr"
colnames(df.occ.agg.ci)[3]<-"occ.denr"

df.sum<-merge(df.occ.agg.ci, df.occ.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$cols<-"darkorange"
df.sum2$cols.bg<-recode(df.sum2$ch, "lo:12='darkorange'; 13:hi='transparent'")


segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
my.symbols(x=df.sum2$CAT_Avg , y=df.sum2$mean, symb=ms.filled.polygon, n=6, inches=.25, bg=df.sum2$cols.bg, fg=df.sum2$cols, adj=0)
lines(exp(predict(dfmod.occ, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=2.5, lty=2)

legend("topleft", " ", cex=4)



# Colonization #################################################################
plot(1, type="n", xlab="Chamber temperature (C)", ylab="Colonization", xlim=c(8.810171, 19.540700), ylim=c(0,.25))

hf.col.agg<-as.data.frame(aggregate(cbind(col.numr,col.denr) ~ ch, hfcomm.col, sum))
hf.col.agg.ci<-binom.confint(hf.col.agg$col.numr, hf.col.agg$col.denr, methods="exact")
colnames(hf.col.agg.ci)[2]<-"col.numr"
colnames(hf.col.agg.ci)[3]<-"col.denr"

hf.sum<-merge(hf.col.agg.ci, hf.col.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$cols<-"darkolivegreen"
hf.sum2$cols.bg<-recode(hf.sum2$ch, "lo:12='darkolivegreen'; 13:hi='transparent'")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
my.symbols(x=hf.sum2$CAT_Avg , y=hf.sum2$mean, symb=ms.filled.polygon, n=6, inches=.25, bg=hf.sum2$cols.bg, fg=hf.sum2$cols, adj=0)
lines(exp(predict(hfmod.col, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=2.5, lty=2)

df.col.agg<-as.data.frame(aggregate(cbind(col.numr,col.denr) ~ ch, dfcomm.col, sum))
df.col.agg.ci<-binom.confint(df.col.agg$col.numr, df.col.agg$col.denr, methods="exact")
colnames(df.col.agg.ci)[2]<-"col.numr"
colnames(df.col.agg.ci)[3]<-"col.denr"

df.sum<-merge(df.col.agg.ci, df.col.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$cols<-"darkorange"
df.sum2$cols.bg<-recode(df.sum2$ch, "lo:12='darkorange'; 13:hi='transparent'")

segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
my.symbols(x=df.sum2$CAT_Avg , y=df.sum2$mean, symb=ms.filled.polygon, n=6, inches=.25, bg=df.sum2$cols.bg, fg=df.sum2$cols, adj=0)
lines(exp(predict(dfmod.col, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=2.5, lty=2)

legend("topright", " ", cex=4)

# Extinction ###################################################################
plot(1, type="n", xlab="Chamber temperature (C)", ylab="Extinction", xlim=c(8.810171, 19.540700), ylim=c(0,1))

hf.ext.agg<-as.data.frame(aggregate(cbind(ext.numr,ext.denr) ~ ch, hfcomm.ext, sum))
hf.ext.agg.ci<-binom.confint(hf.ext.agg$ext.numr, hf.ext.agg$ext.denr, methods="exact")
colnames(hf.ext.agg.ci)[2]<-"ext.numr"
colnames(hf.ext.agg.ci)[3]<-"ext.denr"

hf.sum<-merge(hf.ext.agg.ci, hf.ext.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$cols<-"darkolivegreen"
hf.sum2$cols.bg<-recode(hf.sum2$ch, "lo:12='darkolivegreen'; 13:hi='transparent'")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
my.symbols(x=hf.sum2$CAT_Avg , y=hf.sum2$mean, symb=ms.filled.polygon, n=6, inches=.25, bg=hf.sum2$cols.bg, fg=hf.sum2$cols, adj=0)
lines(exp(predict(hfmod.ext, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=2.5, lty=2)

df.ext.agg<-as.data.frame(aggregate(cbind(ext.numr,ext.denr) ~ ch, dfcomm.ext, sum))
df.ext.agg.ci<-binom.confint(df.ext.agg$ext.numr, df.ext.agg$ext.denr, methods="exact")
colnames(df.ext.agg.ci)[2]<-"ext.numr"
colnames(df.ext.agg.ci)[3]<-"ext.denr"

df.sum<-merge(df.ext.agg.ci, df.ext.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$cols<-"darkorange"
df.sum2$cols.bg<-recode(df.sum2$ch, "lo:12='darkorange'; 13:hi='transparent'")

segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
my.symbols(x=df.sum2$CAT_Avg , y=df.sum2$mean, symb=ms.filled.polygon, n=6, inches=.25, bg=df.sum2$cols.bg, fg=df.sum2$cols, adj=0)
lines(exp(predict(dfmod.ext, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=2.5, lty=2)

legend("topright", " ", cex=4)

dev.off()

# models

hf.dm<-lm(DampingRatio ~ CAT_Avg, data=alldat[alldat$site=="HF",])
summary(hf.dm)
anova(hf.dm)

df.dm<-lm(DampingRatio ~ CAT_Avg, data=alldat[alldat$site=="DF",])
summary(df.dm)
anova(df.dm)

all.dm<-lm(DampingRatio ~ CAT_Avg + site, data=alldat)
summary(all.dm)
anova(all.dm)

#occupancy
summary(dfmod.occ)
anova(dfmod.occ, test="Chi")
1 - (dfmod.occ$deviance / dfmod.occ$null.deviance)

summary(hfmod.occ)
anova(hfmod.occ, test="Chi")
1 - (hfmod.occ$deviance / hfmod.occ$null.deviance)

dfcomm.occ$site<-rep("DF", times=dim(dfcomm.occ)[1])
hfcomm.occ$site<-rep("HF", times=dim(hfcomm.occ)[1])
occ.all<-merge(dfcomm.occ, hfcomm.occ, all=TRUE)
occ.all.mod<-glm(cbind(occ.numr,occ.denr) ~ CAT_Avg*site, occ.all, family=quasibinomial)
anova(occ.all.mod, test="Chi")
summary(occ.all.mod)
1 - (occ.all.mod$deviance / occ.all.mod$null.deviance)


#colonization
summary(dfmod.col)
anova(dfmod.col, test="Chi")
1 - (dfmod.col$deviance / dfmod.col$null.deviance)

summary(hfmod.col)
anova(hfmod.col, test="Chi")
1 - (hfmod.col$deviance / hfmod.col$null.deviance)

dfcomm.col$site<-rep("DF", times=dim(dfcomm.col)[1])
hfcomm.col$site<-rep("HF", times=dim(hfcomm.col)[1])
col.all<-merge(dfcomm.col, hfcomm.col, all=TRUE)
col.all.mod<-glm(cbind(col.numr,col.denr) ~ CAT_Avg*site, col.all, family=quasibinomial)
anova(col.all.mod, test="Chi")
summary(col.all.mod)
1 - (col.all.mod$deviance / col.all.mod$null.deviance)


#extinction
summary(dfmod.ext)
anova(dfmod.ext, test="Chi")
1 - (dfmod.ext$deviance / dfmod.ext$null.deviance)

summary(hfmod.ext)
anova(hfmod.ext, test="Chi")
1 - (hfmod.ext$deviance / hfmod.ext$null.deviance)

dfcomm.ext$site<-rep("DF", times=dim(dfcomm.ext)[1])
hfcomm.ext$site<-rep("HF", times=dim(hfcomm.ext)[1])
ext.all<-merge(dfcomm.ext, hfcomm.ext, all=TRUE)
ext.all.mod<-glm(cbind(ext.numr,ext.denr) ~ CAT_Avg*site, ext.all, family=quasibinomial)
anova(ext.all.mod, test="Chi")
summary(ext.all.mod)
1 - (ext.all.mod$deviance / ext.all.mod$null.deviance)

# return time

tiff("DampingRatio_vs_ReturnTime.tif", height=6, width=12, units="in", res=300)
par(mfrow=c(1,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,1,1))

hfret<-read.csv("HFreturntime.csv", header=TRUE)
hfret$pchs<-recode(hfret$ch, "lo:12=16; 13:hi=21")

plot(DampingRatio ~ rt, hfret[hfret$ch!=5,], col="darkolivegreen", pch=hfret$pchs, ylab="Damping ratio", xlab="Return time", cex=2.25)

dfret<-read.csv("DFreturntime.csv", header=TRUE)
dfret$pchs<-recode(dfret$ch, "lo:12=16; 13:hi=21")

plot(DampingRatio ~ rt, dfret, col="darkorange", pch=dfret$pchs, ylab="Damping ratio", xlab="Return time", cex=2.25)

dev.off()

cor.test(hfret[hfret$ch!=5,]$rt,hfret[hfret$ch!=5,]$DampingRatio, method="s") 
cor.test(dfret$rt,dfret$DampingRatio, method="s") 


tiff("MAT_vs_ReturnTime.tif", height=6, width=6, units="in", res=300)
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,1,1))

plot(1, type="n", xlab="MAT", ylab="Return time", xlim=c(8.810171, 19.54), ylim=c(0,1400))
points(rt ~ CAT_Avg,   hfret[hfret$ch!=5,], col="darkolivegreen", pch=hfret$pchs, cex=2.25)
points(rt ~ CAT_Avg,   dfret, col="darkorange", pch=dfret$pchs, cex=2.25)

dev.off()


tiff("PIE_vs_MAT.tif", height=5, width=10, units="in", res=300)
par(mfrow=c(1,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2), mgp=c(3.1,.6,0))

hfret<-read.csv("HFreturntime.csv", header=TRUE)
hfret$pchs<-recode(hfret$ch, "lo:12=16; 13:hi=21")

plot(PIE ~ CAT_Avg, hfret[hfret$ch!=5,], col="darkolivegreen", pch=hfret[hfret$ch!=5,]$pchs, ylab="PIE", xlab="Chamber temperature (C)", cex=2.25)
dm<-glm(as.numeric(as.character(PIE)) ~ CAT_Avg, data=hfret[hfret$ch!=5,], family=quasibinomial, na.action=na.omit)
lines(predict(dm, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)), type="response") ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
summary(dm)
anova(dm, test="Chi")

dfret<-read.csv("DFreturntime.csv", header=TRUE)
dfret$pchs<-recode(dfret$ch, "lo:12=16; 13:hi=21")

plot(PIE ~ CAT_Avg, dfret, col="darkorange", pch=dfret$pchs, ylab="PIE", xlab="Chamber temperature (C)", cex=2.25)
dm<-glm(as.numeric(as.character(PIE)) ~ CAT_Avg, data=dfret, family=quasibinomial, na.action=na.omit)
lines(predict(dm, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)), type="response") ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
summary(dm)
anova(dm, test="Chi")

dev.off()

hfmod<-lm(PIE ~ CAT_Avg, hfret[hfret$ch!=5,])
summary(hfmod)

dfmod<-lm(PIE ~ CAT_Avg, dfret)
summary(dfmod)

dfret$site<-rep("DF", times=dim(dfret)[1])
hfret$site<-rep("HF", times=dim(hfret)[1])

dfhf<-merge(hfret[hfret$ch!=5,], dfret, all=TRUE)
dfhfmod<-lm(PIE ~ CAT_Avg*site, dfhf)
summary(dfhfmod)



# stable stage

tiff("DF_StableStage_23August2015.tiff", height=8, width=12, res=300, units="in")
par(mfrow=c(2,3), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2), mgp=c(3.1,.6,0))

plot(as.numeric(as.character(StableStageEmpty)) ~ CAT_Avg, data=dfdat, xlab="Chamber temperature (C)", ylab="Equilibrium frequency: Empty", pch=recode(dfdat$ch, "lo:12=16;13:hi=21"), cex=2.25, col="darkorange")
dm<-glm(as.numeric(as.character(StableStageEmpty)) ~ CAT_Avg, data=dfdat, family=quasibinomial, na.action=na.omit)
lines(predict(dm, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)), type="response") ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)

summary(dm)
anova(dm, test="Chi")


plot(as.numeric(as.character(StableStageAphe)) ~ CAT_Avg, data=dfdat, xlab="Chamber temperature (C)", ylab=expression(paste("Equilibrium frequency:  ", italic("Aphaenogaster"))), pch=recode(dfdat$ch, "lo:12=16;13:hi=21"), cex=2.25, col="darkorange")
dm<-glm(as.numeric(as.character(StableStageAphe)) ~ CAT_Avg, data=dfdat, family=quasibinomial, na.action=na.omit)
lines(predict(dm, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)), type="response") ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)

summary(dm)
anova(dm, test="Chi")


plot(as.numeric(as.character(StableStageBrch)) ~ CAT_Avg, data=dfdat, xlab="Chamber temperature (C)", ylab=expression(paste("Equilibrium frequency:  ", italic("Brachyponera"))), pch=recode(dfdat$ch, "lo:12=16;13:hi=21"), cex=2.25, col="darkorange")
dm<-glm(as.numeric(as.character(StableStageBrch)) ~ CAT_Avg, data=dfdat, family=quasibinomial, na.action=na.omit)
#lines(predict(dm, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)), type="response") ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)

summary(dm)
anova(dm, test="Chi")

plot(as.numeric(as.character(StableStageCrli)) ~ CAT_Avg, data=dfdat, xlab="Chamber temperature (C)", ylab=expression(paste("Equilibrium frequency:  ", italic("Crematogaster"))), pch=recode(dfdat$ch, "lo:12=16;13:hi=21"), cex=2.25, col="darkorange")
dm<-glm(as.numeric(as.character(StableStageCrli)) ~ CAT_Avg, data=dfdat, family=quasibinomial, na.action=na.omit)
lines(predict(dm, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)), type="response") ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)

summary(dm)
anova(dm, test="Chi")

plot(as.numeric(as.character(StableStageTecu)) ~ CAT_Avg, data=dfdat, xlab="Chamber temperature (C)", ylab=expression(paste("Equilibrium frequency:  ", italic("Temnothorax"))), pch=recode(dfdat$ch, "lo:12=16;13:hi=21"), cex=2.25, col="darkorange")
dm<-glm(as.numeric(as.character(StableStageTecu)) ~ CAT_Avg, data=dfdat, family=quasibinomial, na.action=na.omit)
lines(predict(dm, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)), type="response") ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)

summary(dm)
anova(dm, test="Chi")


dev.off()

############


hfdat<-hfdat[hfdat$ch!=5,]
tiff("HF_StableStage_23August2015.tiff", height=8, width=12, res=300, units="in")
par(mfrow=c(2,3), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2), mgp=c(3.1,.6,0))

plot(as.numeric(as.character(StableStageEmpty)) ~ CAT_Avg, data=hfdat, xlab="Chamber temperature (C)", ylab="Equilibrium frequency: Empty", pch=recode(hfdat$ch, "lo:12=16;13:hi=21"), cex=2.25, col="darkolivegreen")
dm<-glm(as.numeric(as.character(StableStageEmpty)) ~ CAT_Avg, data=hfdat, family=quasibinomial, na.action=na.omit)
lines(predict(dm, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)), type="response") ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)

summary(dm)
anova(dm, test="Chi")


plot(as.numeric(as.character(StableStageAphe)) ~ CAT_Avg, data=hfdat, xlab="Chamber temperature (C)", ylab=expression(paste("Equilibrium frequency:  ", italic("Aphaenogaster"))), pch=recode(hfdat$ch, "lo:12=16;13:hi=21"), cex=2.25, col="darkolivegreen")
dm<-glm(as.numeric(as.character(StableStageAphe)) ~ CAT_Avg, data=hfdat, family=quasibinomial, na.action=na.omit)
lines(predict(dm, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)), type="response") ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)

summary(dm)
anova(dm, test="Chi")

plot(as.numeric(as.character(StableStageCamp)) ~ CAT_Avg, data=hfdat, xlab="Chamber temperature (C)", ylab=expression(paste("Equilibrium frequency:  ", italic("Camponotus"))), pch=recode(hfdat$ch, "lo:12=16;13:hi=21"), cex=2.25, col="darkolivegreen")
dm<-glm(as.numeric(as.character(StableStageCamp)) ~ CAT_Avg, data=hfdat, family=quasibinomial, na.action=na.omit)
lines(predict(dm, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)), type="response") ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)

summary(dm)
anova(dm, test="Chi")

plot(as.numeric(as.character(StableStageLaal)) ~ CAT_Avg, data=hfdat, xlab="Chamber temperature (C)", ylab=expression(paste("Equilibrium frequency:  ", italic("Lasius"))), pch=recode(hfdat$ch, "lo:12=16;13:hi=21"), cex=2.25, col="darkolivegreen")
dm<-glm(as.numeric(as.character(StableStageLaal)) ~ CAT_Avg, data=hfdat, family=quasibinomial, na.action=na.omit)
lines(predict(dm, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)), type="response") ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)

summary(dm)
anova(dm, test="Chi")

plot(as.numeric(as.character(StableStageMyrm)) ~ CAT_Avg, data=hfdat, xlab="Chamber temperature (C)", ylab=expression(paste("Equilibrium frequency:  ", italic("Myrmica"))), pch=recode(hfdat$ch, "lo:12=16;13:hi=21"), cex=2.25, col="darkolivegreen")
dm<-glm(as.numeric(as.character(StableStageMyrm)) ~ CAT_Avg, data=hfdat, family=quasibinomial, na.action=na.omit)
lines(predict(dm, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)), type="response") ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)

summary(dm)
anova(dm, test="Chi")


plot(as.numeric(as.character(StableStageTelo)) ~ CAT_Avg, data=hfdat, xlab="Chamber temperature (C)", ylab=expression(paste("Equilibrium frequency:  ", italic("Temnothorax"))), pch=recode(hfdat$ch, "lo:12=16;13:hi=21"), cex=2.25, col="darkolivegreen")
dm<-glm(as.numeric(as.character(StableStageTelo)) ~ CAT_Avg, data=hfdat, family=quasibinomial, na.action=na.omit)
lines(predict(dm, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)), type="response") ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)

summary(dm)
anova(dm, test="Chi")

dev.off()



# relative importance of colonization vs. extinction to occupancy

rel.df<-glm(cbind(occ.numr,occ.denr) ~ I(col.numr/col.denr) + I(ext.numr/ext.denr), dfcomm, family=quasibinomial)
summary(rel.df)

rel.hf<-glm(cbind(occ.numr,occ.denr) ~ I(col.numr/col.denr) + I(ext.numr/ext.denr), hfcomm, family=quasibinomial)
summary(rel.hf)



# DF Individual Transition Probabilities #######################################

#Empty to other states
dmee<-glm(EmptyToEmpty ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)
dmea<-glm(EmptyToAphe ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)
dmeb<-glm(EmptyToBrch ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)
dmec<-glm(EmptyToCrli ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)
dmet<-glm(EmptyToTecu ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)

#Aphe to other states 
dmae<-glm(ApheToEmpty ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)
dmaa<-glm(ApheToAphe ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)
dmab<-glm(ApheToBrch ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)
dmac<-glm(ApheToCrli ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)
dmat<-glm(ApheToTecu ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)

#Brch to other states 
dmbe<-glm(BrchToEmpty ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)
dmba<-glm(BrchToAphe ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)
dmbb<-glm(BrchToBrch ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)
dmbc<-glm(BrchToCrli ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)
dmbt<-glm(BrchToTecu ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)

#Crli to other states 
dmce<-glm(CrliToEmpty ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)
dmca<-glm(CrliToAphe ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)
dmcb<-glm(CrliToBrch ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)
dmcc<-glm(CrliToCrli ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)
dmct<-glm(CrliToTecu ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)

#Tecu to other states 
dmte<-glm(TecuToEmpty ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)
dmta<-glm(TecuToAphe ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)
dmtb<-glm(TecuToBrch ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)
dmtc<-glm(TecuToCrli ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)
dmtt<-glm(TecuToTecu ~ CAT_Avg, data=dfdat, na.action=na.omit, family=quasibinomial)

df_indspp_table<-
rbind(
      cbind("Empty to Empty", signif(summary(dmee)$coefficients[2,1],3), 
                   signif(summary(dmee)$coefficients[2,2],3), 
                   signif(anova(dmee, test="Chi")$Deviance[2],3), 
                   signif(anova(dmee, test="Chi")$"Pr(>Chi)"[2],3)),
                   
      cbind("Empty to Aphaenogaster", signif(summary(dmea)$coefficients[2,1],3), 
                   signif(summary(dmea)$coefficients[2,2],3), 
                   signif(anova(dmea, test="Chi")$Deviance[2],3), 
                   signif(anova(dmea, test="Chi")$"Pr(>Chi)"[2],3)),
                   
                   
      cbind("Empty to Brachyponera", NA,NA,NA,NA),                   
                   
      cbind("Empty to Crematogaster", signif(summary(dmec)$coefficients[2,1],3), 
                   signif(summary(dmec)$coefficients[2,2],3), 
                   signif(anova(dmec, test="Chi")$Deviance[2],3), 
                   signif(anova(dmec, test="Chi")$"Pr(>Chi)"[2],3)),                       
                   
      cbind("Empty to Temnothorax", signif(summary(dmet)$coefficients[2,1],3), 
                   signif(summary(dmet)$coefficients[2,2],3), 
                   signif(anova(dmet, test="Chi")$Deviance[2],3), 
                   signif(anova(dmet, test="Chi")$"Pr(>Chi)"[2],3)),                      
                   
                   
      cbind("Aphaenogaster to Empty", signif(summary(dmae)$coefficients[2,1],3), 
                   signif(summary(dmae)$coefficients[2,2],3), 
                   signif(anova(dmae, test="Chi")$Deviance[2],3), 
                   signif(anova(dmae, test="Chi")$"Pr(>Chi)"[2],3)),                   
                   
      cbind("Aphaenogaster to Aphaenogaster", signif(summary(dmaa)$coefficients[2,1],3), 
                   signif(summary(dmaa)$coefficients[2,2],3), 
                   signif(anova(dmaa, test="Chi")$Deviance[2],3), 
                   signif(anova(dmaa, test="Chi")$"Pr(>Chi)"[2],3)),                     
                   
      cbind("Aphaenogaster to Brachyponera", NA,NA,NA,NA),     
                   
      cbind("Aphaenogaster to Crematogaster", signif(summary(dmac)$coefficients[2,1],3), 
                   signif(summary(dmac)$coefficients[2,2],3), 
                   signif(anova(dmac, test="Chi")$Deviance[2],3), 
                   signif(anova(dmac, test="Chi")$"Pr(>Chi)"[2],3)),                       
                   
      cbind("Aphaenogaster to Temnothorax", signif(summary(dmat)$coefficients[2,1],3), 
                   signif(summary(dmat)$coefficients[2,2],3), 
                   signif(anova(dmat, test="Chi")$Deviance[2],3), 
                   signif(anova(dmat, test="Chi")$"Pr(>Chi)"[2],3)),                        
                   
                   
      cbind("Brachyponera to Empty", NA,NA,NA,NA),    
                   
      cbind("Brachyponera to Aphaenogaster", NA,NA,NA,NA),  
                                      
      cbind("Brachyponera to Brachyponera", NA,NA,NA,NA),  
                                    
      cbind("Brachyponera to Crematogaster", NA,NA,NA,NA),                     
                   
      cbind("Brachyponera to Temnothorax", NA,NA,NA,NA),                     
                   
                   
      cbind("Crematogaster to Empty", signif(summary(dmce)$coefficients[2,1],3), 
                   signif(summary(dmce)$coefficients[2,2],3), 
                   signif(anova(dmce, test="Chi")$Deviance[2],3), 
                   signif(anova(dmce, test="Chi")$"Pr(>Chi)"[2],3)),                    
                   
      cbind("Crematogaster to Aphaenogaster", signif(summary(dmca)$coefficients[2,1],3), 
                   signif(summary(dmca)$coefficients[2,2],3), 
                   signif(anova(dmca, test="Chi")$Deviance[2],3), 
                   signif(anova(dmca, test="Chi")$"Pr(>Chi)"[2],3)),   
                   
      cbind("Crematogaster to Brachyponera", NA,NA,NA,NA),                      
                   
      cbind("Crematogaster to Crematogaster", signif(summary(dmcc)$coefficients[2,1],3), 
                   signif(summary(dmcc)$coefficients[2,2],3), 
                   signif(anova(dmcc, test="Chi")$Deviance[2],3), 
                   signif(anova(dmcc, test="Chi")$"Pr(>Chi)"[2],3)),                    
                   
      cbind("Crematogaster to Temnothorax", signif(summary(dmct)$coefficients[2,1],3), 
                   signif(summary(dmct)$coefficients[2,2],3), 
                   signif(anova(dmct, test="Chi")$Deviance[2],3), 
                   signif(anova(dmct, test="Chi")$"Pr(>Chi)"[2],3)),                    
                   
                   
      cbind("Temnothorax to Empty", signif(summary(dmte)$coefficients[2,1],3), 
                   signif(summary(dmte)$coefficients[2,2],3), 
                   signif(anova(dmte, test="Chi")$Deviance[2],3), 
                   signif(anova(dmte, test="Chi")$"Pr(>Chi)"[2],3)),                    
                   
      cbind("Temnothorax to Aphaenogaster", signif(summary(dmta)$coefficients[2,1],3), 
                   signif(summary(dmta)$coefficients[2,2],3), 
                   signif(anova(dmta, test="Chi")$Deviance[2],3), 
                   signif(anova(dmta, test="Chi")$"Pr(>Chi)"[2],3)),                     
                   
      cbind("Temnothorax to Brachyponera", NA,NA,NA,NA),                     
                   
      cbind("Temnothorax to Crematogaster", signif(summary(dmtc)$coefficients[2,1],3), 
                   signif(summary(dmtc)$coefficients[2,2],3), 
                   signif(anova(dmtc, test="Chi")$Deviance[2],3), 
                   signif(anova(dmtc, test="Chi")$"Pr(>Chi)"[2],3)),                     

      cbind("Temnothorax to Temnothorax", signif(summary(dmtt)$coefficients[2,1],3), 
                   signif(summary(dmtt)$coefficients[2,2],3), 
                   signif(anova(dmtt, test="Chi")$Deviance[2],3), 
                   signif(anova(dmtt, test="Chi")$"Pr(>Chi)"[2],3))
                   
                   )                     
                   
colnames(df_indspp_table)<-c("Transition","Estimate","SE","Deviance","P")                    
write.csv(df_indspp_table, "df_indspp_table.csv")                   
                   
       
       
       
       
                   
# HF Individual Transition Probabilities #######################################
hfdat<-hfdat[hfdat$ch !=5,]
#Empty to other states
dmee<-glm(EmptyToEmpty ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmea<-glm(EmptyToAphe ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmec<-glm(EmptyToCamp ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmel<-glm(EmptyToLaal ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmem<-glm(EmptyToMyrm ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmet<-glm(EmptyToTelo ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)

#Aphe to other states 
dmae<-glm(ApheToEmpty ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmaa<-glm(ApheToAphe ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmac<-glm(ApheToCamp ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmal<-glm(ApheToLaal ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmam<-glm(ApheToMyrm ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmat<-glm(ApheToTelo ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)

#Camp to other states 
dmce<-glm(CampToEmpty ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmca<-glm(CampToAphe ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmcc<-glm(CampToCamp ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmcl<-glm(CampToLaal ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmcm<-glm(CampToMyrm ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmct<-glm(CampToTelo ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)

#Laal to other states 
dmle<-glm(LaalToEmpty ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmla<-glm(LaalToAphe ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmlc<-glm(LaalToCamp ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmll<-glm(LaalToLaal ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmlm<-glm(LaalToMyrm ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmlt<-glm(LaalToTelo ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)

#Myrm to other states 
dmme<-glm(MyrmToEmpty ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmma<-glm(MyrmToAphe ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmmc<-glm(MyrmToCamp ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmml<-glm(MyrmToLaal ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmmm<-glm(MyrmToMyrm ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmmt<-glm(MyrmToTelo ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)

#Telo to other states 
dmte<-glm(TeloToEmpty ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmta<-glm(TeloToAphe ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmtc<-glm(TeloToCamp ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmtl<-glm(TeloToLaal ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmtm<-glm(TeloToMyrm ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)
dmtt<-glm(TeloToTelo ~ CAT_Avg, data=hfdat, na.action=na.omit, family=quasibinomial)

hf_indspp_table<-
rbind(
      cbind("Empty to Empty", signif(summary(dmee)$coefficients[2,1],3), 
                   signif(summary(dmee)$coefficients[2,2],3), 
                   signif(anova(dmee, test="Chi")$Deviance[2],3), 
                   signif(anova(dmee, test="Chi")$"Pr(>Chi)"[2],3)),
                   
      cbind("Empty to Aphaenogaster", signif(summary(dmea)$coefficients[2,1],3), 
                   signif(summary(dmea)$coefficients[2,2],3), 
                   signif(anova(dmea, test="Chi")$Deviance[2],3), 
                   signif(anova(dmea, test="Chi")$"Pr(>Chi)"[2],3)),
                   
      cbind("Empty to Camponotus", signif(summary(dmec)$coefficients[2,1],3), 
                   signif(summary(dmec)$coefficients[2,2],3), 
                   signif(anova(dmec, test="Chi")$Deviance[2],3), 
                   signif(anova(dmec, test="Chi")$"Pr(>Chi)"[2],3)), 

      cbind("Empty to Lasius", signif(summary(dmel)$coefficients[2,1],3), 
                   signif(summary(dmel)$coefficients[2,2],3), 
                   signif(anova(dmel, test="Chi")$Deviance[2],3), 
                   signif(anova(dmel, test="Chi")$"Pr(>Chi)"[2],3)),
                                                        
      cbind("Empty to Myrmica", signif(summary(dmem)$coefficients[2,1],3), 
                   signif(summary(dmem)$coefficients[2,2],3), 
                   signif(anova(dmem, test="Chi")$Deviance[2],3), 
                   signif(anova(dmem, test="Chi")$"Pr(>Chi)"[2],3)),
                   
      cbind("Empty to Temnothorax", signif(summary(dmet)$coefficients[2,1],3), 
                   signif(summary(dmet)$coefficients[2,2],3), 
                   signif(anova(dmet, test="Chi")$Deviance[2],3), 
                   signif(anova(dmet, test="Chi")$"Pr(>Chi)"[2],3)),                      
                   
                   
      cbind("Aphaenogaster to Empty", signif(summary(dmae)$coefficients[2,1],3), 
                   signif(summary(dmae)$coefficients[2,2],3), 
                   signif(anova(dmae, test="Chi")$Deviance[2],3), 
                   signif(anova(dmae, test="Chi")$"Pr(>Chi)"[2],3)),                   
                   
      cbind("Aphaenogaster to Aphaenogaster", signif(summary(dmaa)$coefficients[2,1],3), 
                   signif(summary(dmaa)$coefficients[2,2],3), 
                   signif(anova(dmaa, test="Chi")$Deviance[2],3), 
                   signif(anova(dmaa, test="Chi")$"Pr(>Chi)"[2],3)),                       
                   
      cbind("Aphaenogaster to Camponotus", signif(summary(dmac)$coefficients[2,1],3), 
                   signif(summary(dmac)$coefficients[2,2],3), 
                   signif(anova(dmac, test="Chi")$Deviance[2],3), 
                   signif(anova(dmac, test="Chi")$"Pr(>Chi)"[2],3)),                       

      cbind("Aphaenogaster to Lasius", signif(summary(dmal)$coefficients[2,1],3), 
                   signif(summary(dmal)$coefficients[2,2],3), 
                   signif(anova(dmal, test="Chi")$Deviance[2],3), 
                   signif(anova(dmal, test="Chi")$"Pr(>Chi)"[2],3)), 

      cbind("Aphaenogaster to Myrmica", signif(summary(dmam)$coefficients[2,1],3), 
                   signif(summary(dmam)$coefficients[2,2],3), 
                   signif(anova(dmam, test="Chi")$Deviance[2],3), 
                   signif(anova(dmam, test="Chi")$"Pr(>Chi)"[2],3)), 
                                                         
      cbind("Aphaenogaster to Temnothorax", signif(summary(dmat)$coefficients[2,1],3), 
                   signif(summary(dmat)$coefficients[2,2],3), 
                   signif(anova(dmat, test="Chi")$Deviance[2],3), 
                   signif(anova(dmat, test="Chi")$"Pr(>Chi)"[2],3)),                        
                   
                   
      cbind("Camponotus to Empty", signif(summary(dmce)$coefficients[2,1],3), 
                   signif(summary(dmce)$coefficients[2,2],3), 
                   signif(anova(dmce, test="Chi")$Deviance[2],3), 
                   signif(anova(dmce, test="Chi")$"Pr(>Chi)"[2],3)),                    
                   
      cbind("Camponotus to Aphaenogaster", signif(summary(dmca)$coefficients[2,1],3), 
                   signif(summary(dmca)$coefficients[2,2],3), 
                   signif(anova(dmca, test="Chi")$Deviance[2],3), 
                   signif(anova(dmca, test="Chi")$"Pr(>Chi)"[2],3)),                      
                   
      cbind("Camponotus to Camponotus", signif(summary(dmcc)$coefficients[2,1],3), 
                   signif(summary(dmcc)$coefficients[2,2],3), 
                   signif(anova(dmcc, test="Chi")$Deviance[2],3), 
                   signif(anova(dmcc, test="Chi")$"Pr(>Chi)"[2],3)),  
                                     
      cbind("Camponotus to Lasius", NA,NA,NA,NA),  
                    
      cbind("Camponotus to Myrmica", signif(summary(dmcm)$coefficients[2,1],3), 
                   signif(summary(dmcm)$coefficients[2,2],3), 
                   signif(anova(dmcm, test="Chi")$Deviance[2],3), 
                   signif(anova(dmcm, test="Chi")$"Pr(>Chi)"[2],3)),   
                                                     
      cbind("Camponotus to Temnothorax", signif(summary(dmct)$coefficients[2,1],3), 
                   signif(summary(dmct)$coefficients[2,2],3), 
                   signif(anova(dmct, test="Chi")$Deviance[2],3), 
                   signif(anova(dmct, test="Chi")$"Pr(>Chi)"[2],3)),                    
                   
                   
      cbind("Lasius to Empty", signif(summary(dmle)$coefficients[2,1],3), 
                   signif(summary(dmle)$coefficients[2,2],3), 
                   signif(anova(dmle, test="Chi")$Deviance[2],3), 
                   signif(anova(dmle, test="Chi")$"Pr(>Chi)"[2],3)),                    
                   
      cbind("Lasius to Aphaenogaster", signif(summary(dmla)$coefficients[2,1],3), 
                   signif(summary(dmla)$coefficients[2,2],3), 
                   signif(anova(dmla, test="Chi")$Deviance[2],3), 
                   signif(anova(dmla, test="Chi")$"Pr(>Chi)"[2],3)),                      
                   
      cbind("Lasius to Camponotus", NA,NA,NA,NA),  
                                     
      cbind("Lasius to Lasius", signif(summary(dmll)$coefficients[2,1],3), 
                   signif(summary(dmll)$coefficients[2,2],3), 
                   signif(anova(dmll, test="Chi")$Deviance[2],3), 
                   signif(anova(dmll, test="Chi")$"Pr(>Chi)"[2],3)),  

      cbind("Lasius to Myrmica", signif(summary(dmlm)$coefficients[2,1],3), 
                   signif(summary(dmlm)$coefficients[2,2],3), 
                   signif(anova(dmlm, test="Chi")$Deviance[2],3), 
                   signif(anova(dmlm, test="Chi")$"Pr(>Chi)"[2],3)),   
                                                     
      cbind("Lasius to Temnothorax", NA,NA,NA,NA),  
                   
                   
      cbind("Myrmica to Empty", signif(summary(dmme)$coefficients[2,1],3), 
                   signif(summary(dmme)$coefficients[2,2],3), 
                   signif(anova(dmme, test="Chi")$Deviance[2],3), 
                   signif(anova(dmme, test="Chi")$"Pr(>Chi)"[2],3)),                    
                   
      cbind("Myrmica to Aphaenogaster", signif(summary(dmma)$coefficients[2,1],3), 
                   signif(summary(dmma)$coefficients[2,2],3), 
                   signif(anova(dmma, test="Chi")$Deviance[2],3), 
                   signif(anova(dmma, test="Chi")$"Pr(>Chi)"[2],3)),                      
                   
      cbind("Myrmica to Camponotus", signif(summary(dmmc)$coefficients[2,1],3), 
                   signif(summary(dmmc)$coefficients[2,2],3), 
                   signif(anova(dmmc, test="Chi")$Deviance[2],3), 
                   signif(anova(dmmc, test="Chi")$"Pr(>Chi)"[2],3)),  
                                     
      cbind("Myrmica to Lasius", signif(summary(dmml)$coefficients[2,1],3), 
                   signif(summary(dmml)$coefficients[2,2],3), 
                   signif(anova(dmml, test="Chi")$Deviance[2],3), 
                   signif(anova(dmml, test="Chi")$"Pr(>Chi)"[2],3)),  
                    
      cbind("Myrmica to Myrmica", signif(summary(dmmm)$coefficients[2,1],3), 
                   signif(summary(dmmm)$coefficients[2,2],3), 
                   signif(anova(dmmm, test="Chi")$Deviance[2],3), 
                   signif(anova(dmmm, test="Chi")$"Pr(>Chi)"[2],3)),   
                                                     
      cbind("Myrmica to Temnothorax", signif(summary(dmmt)$coefficients[2,1],3), 
                   signif(summary(dmmt)$coefficients[2,2],3), 
                   signif(anova(dmmt, test="Chi")$Deviance[2],3), 
                   signif(anova(dmmt, test="Chi")$"Pr(>Chi)"[2],3)), 
                   
                                      
      cbind("Temnothorax to Empty", signif(summary(dmte)$coefficients[2,1],3), 
                   signif(summary(dmte)$coefficients[2,2],3), 
                   signif(anova(dmte, test="Chi")$Deviance[2],3), 
                   signif(anova(dmte, test="Chi")$"Pr(>Chi)"[2],3)),                    
                   
      cbind("Temnothorax to Aphaenogaster", signif(summary(dmta)$coefficients[2,1],3), 
                   signif(summary(dmta)$coefficients[2,2],3), 
                   signif(anova(dmta, test="Chi")$Deviance[2],3), 
                   signif(anova(dmta, test="Chi")$"Pr(>Chi)"[2],3)),
                     
      cbind("Temnothorax to Camponotus", signif(summary(dmtc)$coefficients[2,1],3), 
                   signif(summary(dmtc)$coefficients[2,2],3), 
                   signif(anova(dmtc, test="Chi")$Deviance[2],3), 
                   signif(anova(dmtc, test="Chi")$"Pr(>Chi)"[2],3)), 
                                                        
      cbind("Temnothorax to Lasius", NA,NA,NA,NA), 
                   
      cbind("Temnothorax to Myrmica", signif(summary(dmtm)$coefficients[2,1],3), 
                   signif(summary(dmtm)$coefficients[2,2],3), 
                   signif(anova(dmtm, test="Chi")$Deviance[2],3), 
                   signif(anova(dmtm, test="Chi")$"Pr(>Chi)"[2],3)),        
                                                                                  
      cbind("Temnothorax to Temnothorax", signif(summary(dmtt)$coefficients[2,1],3), 
                   signif(summary(dmtt)$coefficients[2,2],3), 
                   signif(anova(dmtt, test="Chi")$Deviance[2],3), 
                   signif(anova(dmtt, test="Chi")$"Pr(>Chi)"[2],3))
                   
                   )                     
                   
colnames(hf_indspp_table)<-c("Transition","Estimate","SE","Deviance","P")                    
write.csv(hf_indspp_table, "hf_indspp_table.csv")                       
                   
                   
# damping ratio correlates
dfdr<-read.csv("DF_DRdecomp.csv", header=T)
hfdr<-read.csv("HF_DRdecomp.csv", header=T)

# HF
cor.test(hfdr[hfdr$ch!=5,]$all.counts,hfdr[hfdr$ch!=5,]$DampingRatio, method="s") 
cor.test(hfdr[hfdr$ch!=5,]$all.counts.me,hfdr[hfdr$ch!=5,]$DampingRatio, method="s") 

cor.test(hfdr[hfdr$ch!=5,]$disturbance,hfdr[hfdr$ch!=5,]$DampingRatio, method="s") 
cor.test(hfdr[hfdr$ch!=5,]$disturbance.me,hfdr[hfdr$ch!=5,]$DampingRatio, method="s") 

cor.test(hfdr[hfdr$ch!=5,]$DR_var,hfdr[hfdr$ch!=5,]$DampingRatio, method="s") 
cor.test(hfdr[hfdr$ch!=5,]$DR_var.me,hfdr[hfdr$ch!=5,]$DampingRatio, method="s") 

cor.test(hfdr[hfdr$ch!=5,]$resistance,hfdr[hfdr$ch!=5,]$DampingRatio, method="s") 
cor.test(hfdr[hfdr$ch!=5,]$resistance.me,hfdr[hfdr$ch!=5,]$DampingRatio, method="s") 

cor.test(hfret[hfret$ch!=5,]$rt,hfret[hfret$ch!=5,]$DampingRatio, method="s") 

# DF
cor.test(dfdr$all.counts,dfdr$DampingRatio, method="s") 
cor.test(dfdr$all.counts.me,dfdr$DampingRatio, method="s") 

cor.test(dfdr$disturbance,dfdr$DampingRatio, method="s") 
cor.test(dfdr$disturbance.me,dfdr$DampingRatio, method="s") 

cor.test(dfdr$DR_var,dfdr$DampingRatio, method="s") 
cor.test(dfdr$DR_var.me,dfdr$DampingRatio, method="s") 

cor.test(dfdr$resistance,dfdr$DampingRatio, method="s") 
cor.test(dfdr$resistance.me,dfdr$DampingRatio, method="s") 

cor.test(dfret$rt,dfret$DampingRatio, method="s") 

                   
                   
                   