dat1<-read.csv("DF_NestBox_responses_alldates_20150818.csv",header=T)

# recode the chamber IDs to target deltas
library(car)
dat1$Target_Delta<-recode(dat1$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"




dat<-merge(dat1, temp_vals[,1:3], "ch")

# Species
cr<-dat[dat$Sp=="Crem",]
ap<-dat[dat$Sp=="Aphen",]
te<-dat[dat$Sp=="Temno",]
bp<-dat[dat$Sp=="Brachyponera_chinensis",]

################################################################################
# quasibinomial models - crli ##################################################
################################################################################

cr.col<-cr[cr$col.den > 0,]
cr.ext<-cr[cr$ext.den > 0,]
cr.occ<-cr[cr$occ.den > 0,]
cr.stasis<-cr[cr$stasis.den > 0 & !is.na(cr$stasis.den),]
cr.per<-cr[cr$per.den > 0 & !is.na(cr$per.den),]

mod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, cr.col, family=quasibinomial)
mod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, cr.ext, family=quasibinomial)
mod.col2<-glm(cbind(col.num2,col.den) ~ CAT_Avg, cr.col, family=quasibinomial)
mod.ext2<-glm(cbind(ext.num2,ext.den) ~ CAT_Avg, cr.ext, family=quasibinomial)
mod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, cr.occ, family=quasibinomial)
mod.sta<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, cr.stasis, family=quasibinomial)
mod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, cr.per, family=quasibinomial)

anova(mod.col, test="Chi")
anova(mod.ext, test="Chi")
anova(mod.occ, test="Chi")
anova(mod.sta, test="Chi")
anova(mod.per, test="Chi")

cr_table<-
rbind(
      cbind("occ", signif(summary(mod.occ)$coefficients[2,1],3), 
                   signif(summary(mod.occ)$coefficients[2,2],3), 
                   signif(anova(mod.occ, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.occ, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("ext", signif(summary(mod.ext)$coefficients[2,1],3), 
                   signif(summary(mod.ext)$coefficients[2,2],3), 
                   signif(anova(mod.ext, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.ext, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("col", signif(summary(mod.col)$coefficients[2,1],3), 
                   signif(summary(mod.col)$coefficients[2,2],3), 
                   signif(anova(mod.col, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.col, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("sta", signif(summary(mod.sta)$coefficients[2,1],3), 
                   signif(summary(mod.sta)$coefficients[2,2],3), 
                   signif(anova(mod.sta, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.sta, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("per", signif(summary(mod.per)$coefficients[2,1],3), 
                   signif(summary(mod.per)$coefficients[2,2],3), 
                   signif(anova(mod.per, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.per, test="Chi")$"Pr(>Chi)"[2],3))                   
                   )
                   
colnames(cr_table)<-c("response","estimate","se","deviance","p")                    
write.csv(cr_table, "Cre_lin_model_results.csv")

################################################################################
# quasibinomial models - aphe ##################################################
################################################################################

ap.col<-ap[ap$col.den > 0,]
ap.ext<-ap[ap$ext.den > 0,]
ap.occ<-ap[ap$occ.den > 0,]
ap.stasis<-ap[ap$stasis.den > 0 & !is.na(ap$stasis.den),]
ap.per<-ap[ap$per.den > 0 & !is.na(ap$per.den),]

mod.col<-glm(cbind(col.num,col.den) ~ Target_Delta, ap.col, family=quasibinomial)
mod.ext<-glm(cbind(ext.num,ext.den) ~ Target_Delta, ap.ext, family=quasibinomial)
mod.col2<-glm(cbind(col.num2,col.den) ~ Target_Delta, ap.col, family=quasibinomial)
mod.ext2<-glm(cbind(ext.num2,ext.den) ~ Target_Delta, ap.ext, family=quasibinomial)
mod.occ<-glm(cbind(occ.num,occ.den) ~ Target_Delta, ap.occ, family=quasibinomial)
mod.sta<-glm(cbind(stasis.num,stasis.den) ~ Target_Delta, ap.stasis, family=quasibinomial)
mod.per<-glm(cbind(per.num,per.den) ~ Target_Delta, ap.per, family=quasibinomial)

anova(mod.col, test="Chi")
anova(mod.ext, test="Chi")
anova(mod.occ, test="Chi")
anova(mod.sta, test="Chi")
anova(mod.per, test="Chi")

ap_table<-
rbind(
      cbind("occ", signif(summary(mod.occ)$coefficients[2,1],3), 
                   signif(summary(mod.occ)$coefficients[2,2],3), 
                   signif(anova(mod.occ, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.occ, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("ext", signif(summary(mod.ext)$coefficients[2,1],3), 
                   signif(summary(mod.ext)$coefficients[2,2],3), 
                   signif(anova(mod.ext, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.ext, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("col", signif(summary(mod.col)$coefficients[2,1],3), 
                   signif(summary(mod.col)$coefficients[2,2],3), 
                   signif(anova(mod.col, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.col, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("sta", signif(summary(mod.sta)$coefficients[2,1],3), 
                   signif(summary(mod.sta)$coefficients[2,2],3), 
                   signif(anova(mod.sta, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.sta, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("per", signif(summary(mod.per)$coefficients[2,1],3), 
                   signif(summary(mod.per)$coefficients[2,2],3), 
                   signif(anova(mod.per, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.per, test="Chi")$"Pr(>Chi)"[2],3))                   
                   )
                   
colnames(ap_table)<-c("response","estimate","se","deviance","p") 
write.csv(ap_table, "Aph_rud_model_results.csv")

################################################################################
# quasibinomial models - tecu ##################################################
################################################################################

te.col<-te[te$col.den > 0,]
te.ext<-te[te$ext.den > 0,]
te.occ<-te[te$occ.den > 0,]
te.stasis<-te[te$stasis.den > 0 & !is.na(te$stasis.den),]
te.per<-te[te$per.den > 0 & !is.na(te$per.den),]

mod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, te.col, family=quasibinomial)
mod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, te.ext, family=quasibinomial)
mod.col2<-glm(cbind(col.num2,col.den) ~ CAT_Avg, te.col, family=quasibinomial)
mod.ext2<-glm(cbind(ext.num2,ext.den) ~ CAT_Avg, te.ext, family=quasibinomial)
mod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, te.occ, family=quasibinomial)
mod.sta<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, te.stasis, family=quasibinomial)
mod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, te.per, family=quasibinomial)

anova(mod.col, test="Chi")
anova(mod.ext, test="Chi")
anova(mod.occ, test="Chi")
anova(mod.sta, test="Chi")
anova(mod.per, test="Chi")

te_table<-
rbind(
      cbind("occ", signif(summary(mod.occ)$coefficients[2,1],3), 
                   signif(summary(mod.occ)$coefficients[2,2],3), 
                   signif(anova(mod.occ, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.occ, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("ext", signif(summary(mod.ext)$coefficients[2,1],3), 
                   signif(summary(mod.ext)$coefficients[2,2],3), 
                   signif(anova(mod.ext, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.ext, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("col", signif(summary(mod.col)$coefficients[2,1],3), 
                   signif(summary(mod.col)$coefficients[2,2],3), 
                   signif(anova(mod.col, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.col, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("sta", signif(summary(mod.sta)$coefficients[2,1],3), 
                   signif(summary(mod.sta)$coefficients[2,2],3), 
                   signif(anova(mod.sta, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.sta, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("per", signif(summary(mod.per)$coefficients[2,1],3), 
                   signif(summary(mod.per)$coefficients[2,2],3), 
                   signif(anova(mod.per, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.per, test="Chi")$"Pr(>Chi)"[2],3))                   
                   )
                   
colnames(te_table)<-c("response","estimate","se","deviance","p") 
write.csv(te_table, "Tem_cur_model_results.csv")

################################################################################
# quasibinomial models - brch ##################################################
################################################################################

bp.col<-bp[bp$col.den > 0,]
bp.ext<-bp[bp$ext.den > 0,]
bp.occ<-bp[bp$occ.den > 0,]
bp.stasis<-bp[bp$stasis.den > 0 & !is.na(bp$stasis.den),]
bp.per<-bp[bp$per.den > 0 & !is.na(bp$per.den),]

mod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, bp.col, family=quasibinomial)
mod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, bp.ext, family=quasibinomial)
mod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, bp.occ, family=quasibinomial)
mod.sta<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, bp.stasis, family=quasibinomial)
mod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, bp.per, family=quasibinomial)

anova(mod.col, test="Chi")
anova(mod.ext, test="Chi")
anova(mod.occ, test="Chi")
anova(mod.sta, test="Chi")
anova(mod.per, test="Chi")

bp_table<-
rbind(
      cbind("occ", signif(summary(mod.occ)$coefficients[2,1],3), 
                   signif(summary(mod.occ)$coefficients[2,2],3), 
                   signif(anova(mod.occ, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.occ, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("ext", signif(summary(mod.ext)$coefficients[2,1],3), 
                   signif(summary(mod.ext)$coefficients[2,2],3), 
                   signif(anova(mod.ext, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.ext, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("col", signif(summary(mod.col)$coefficients[2,1],3), 
                   signif(summary(mod.col)$coefficients[2,2],3), 
                   signif(anova(mod.col, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.col, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("per", signif(summary(mod.per)$coefficients[2,1],3), 
                   signif(summary(mod.per)$coefficients[2,2],3), 
                   signif(anova(mod.per, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.per, test="Chi")$"Pr(>Chi)"[2],3))                   
                   )  # stasis model does not converge, not enough degrees of freedom
                   
colnames(bp_table)<-c("response","estimate","se","deviance","p") 
write.csv(bp_table, "Bra_chi_model_results.csv")


################################################################################


ap.occ<-ap[ap$occ.den > 0,]
bp.occ<-bp[bp$occ.den > 0,]
cr.occ<-cr[cr$occ.den > 0,]
te.occ<-te[te$occ.den > 0,]

# Occupancy
tiff("DF_Occupancy.tiff", height=10, width=10, res=300, units="in")
par(mfrow=c(2,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2), mgp=c(3,.6,0))

dfmod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, ap.occ, family=quasibinomial)
plot(occ.num/occ.den ~ CAT_Avg, ap.occ, xlab="Chamber temperature (C)", ylab="Occupancy", type="n", ylim=c(0,0.35))

df.occ.agg<-as.data.frame(aggregate(cbind(occ.num,occ.den) ~ ch, ap.occ, sum))
df.occ.agg.ci<-binom.confint(df.occ.agg$occ.num, df.occ.agg$occ.den, methods="exact")
colnames(df.occ.agg.ci)[2]<-"occ.num"
colnames(df.occ.agg.ci)[3]<-"occ.den"

df.sum<-merge(df.occ.agg.ci, df.occ.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$pchs<-recode(df.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
points(mean ~ CAT_Avg, df.sum2, col="darkorange", pch=df.sum2$pchs, cex=2.25)
lines(exp(predict(dfmod.occ, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  expression(paste(italic("Aphaenogaster"), " sp.")), cex=1.5)



dfmod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, bp.occ, family=quasibinomial)
plot(occ.num/occ.den ~ CAT_Avg, bp.occ, xlab="Chamber temperature (C)", ylab="Occupancy", type="n", ylim=c(0,0.08))

df.occ.agg<-as.data.frame(aggregate(cbind(occ.num,occ.den) ~ ch, bp.occ, sum))
df.occ.agg.ci<-binom.confint(df.occ.agg$occ.num, df.occ.agg$occ.den, methods="exact")
colnames(df.occ.agg.ci)[2]<-"occ.num"
colnames(df.occ.agg.ci)[3]<-"occ.den"

df.sum<-merge(df.occ.agg.ci, df.occ.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$pchs<-recode(df.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
points(mean ~ CAT_Avg, df.sum2, col="darkorange", pch=df.sum2$pchs, cex=2.25)
lines(exp(predict(dfmod.occ, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  "Brachyponera chinensis", font=3, cex=1.5)



dfmod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, cr.occ, family=quasibinomial)
plot(occ.num/occ.den ~ CAT_Avg, cr.occ, xlab="Chamber temperature (C)", ylab="Occupancy", type="n", ylim=c(0,0.45))

df.occ.agg<-as.data.frame(aggregate(cbind(occ.num,occ.den) ~ ch, cr.occ, sum))
df.occ.agg.ci<-binom.confint(df.occ.agg$occ.num, df.occ.agg$occ.den, methods="exact")
colnames(df.occ.agg.ci)[2]<-"occ.num"
colnames(df.occ.agg.ci)[3]<-"occ.den"

df.sum<-merge(df.occ.agg.ci, df.occ.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$pchs<-recode(df.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
points(mean ~ CAT_Avg, df.sum2, col="darkorange", pch=df.sum2$pchs, cex=2.25)
lines(exp(predict(dfmod.occ, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  "Crematogaster lineolata", font=3, cex=1.5)



dfmod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, te.occ, family=quasibinomial)
plot(occ.num/occ.den ~ CAT_Avg, te.occ, xlab="Chamber temperature (C)", ylab="Occupancy", type="n", ylim=c(0,0.2))

df.occ.agg<-as.data.frame(aggregate(cbind(occ.num,occ.den) ~ ch, te.occ, sum))
df.occ.agg.ci<-binom.confint(df.occ.agg$occ.num, df.occ.agg$occ.den, methods="exact")
colnames(df.occ.agg.ci)[2]<-"occ.num"
colnames(df.occ.agg.ci)[3]<-"occ.den"

df.sum<-merge(df.occ.agg.ci, df.occ.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$pchs<-recode(df.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
points(mean ~ CAT_Avg, df.sum2, col="darkorange", pch=df.sum2$pchs, cex=2.25)
lines(exp(predict(dfmod.occ, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  "Temnothorax curvispinosus", font=3, cex=1.5)

dev.off()




ap.col<-ap[ap$col.den > 0,]
bp.col<-bp[bp$col.den > 0,]
cr.col<-cr[cr$col.den > 0,]
te.col<-te[te$col.den > 0,]

# Colonization
tiff("DF_Colonization.tiff", height=10, width=10, res=300, units="in")
par(mfrow=c(2,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2), mgp=c(3,.6,0))

dfmod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, ap.col, family=quasibinomial)
plot(col.num/col.den ~ CAT_Avg, ap.col, xlab="Chamber temperature (C)", ylab="Colonization", type="n", ylim=c(0,.3))

df.col.agg<-as.data.frame(aggregate(cbind(col.num,col.den) ~ ch, ap.col, sum))
df.col.agg.ci<-binom.confint(df.col.agg$col.num, df.col.agg$col.den, methods="exact")
colnames(df.col.agg.ci)[2]<-"col.num"
colnames(df.col.agg.ci)[3]<-"col.den"

df.sum<-merge(df.col.agg.ci, df.col.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$pchs<-recode(df.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
points(mean ~ CAT_Avg, df.sum2, col="darkorange", pch=df.sum2$pchs, cex=2.25)
lines(exp(predict(dfmod.col, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  expression(paste(italic("Aphaenogaster"), " sp.")), cex=1.5)



dfmod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, bp.col, family=quasibinomial)
plot(col.num/col.den ~ CAT_Avg, bp.col, xlab="Chamber temperature (C)", ylab="Colonization", type="n", ylim=c(0,0.06))

df.col.agg<-as.data.frame(aggregate(cbind(col.num,col.den) ~ ch, bp.col, sum))
df.col.agg.ci<-binom.confint(df.col.agg$col.num, df.col.agg$col.den, methods="exact")
colnames(df.col.agg.ci)[2]<-"col.num"
colnames(df.col.agg.ci)[3]<-"col.den"

df.sum<-merge(df.col.agg.ci, df.col.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$pchs<-recode(df.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
points(mean ~ CAT_Avg, df.sum2, col="darkorange", pch=df.sum2$pchs, cex=2.25)
lines(exp(predict(dfmod.col, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  "Brachyponera chinensis", font=3, cex=1.5)



dfmod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, cr.col, family=quasibinomial)
plot(col.num/col.den ~ CAT_Avg, cr.col, xlab="Chamber temperature (C)", ylab="Colonization", type="n", ylim=c(0,0.25))

df.col.agg<-as.data.frame(aggregate(cbind(col.num,col.den) ~ ch, cr.col, sum))
df.col.agg.ci<-binom.confint(df.col.agg$col.num, df.col.agg$col.den, methods="exact")
colnames(df.col.agg.ci)[2]<-"col.num"
colnames(df.col.agg.ci)[3]<-"col.den"

df.sum<-merge(df.col.agg.ci, df.col.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$pchs<-recode(df.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
points(mean ~ CAT_Avg, df.sum2, col="darkorange", pch=df.sum2$pchs, cex=2.25)
lines(exp(predict(dfmod.col, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  "Crematogaster lineolata", font=3, cex=1.5)



dfmod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, te.col, family=quasibinomial)
plot(col.num/col.den ~ CAT_Avg, te.col, xlab="Chamber temperature (C)", ylab="Colonization", type="n", ylim=c(0,0.07))

df.col.agg<-as.data.frame(aggregate(cbind(col.num,col.den) ~ ch, te.col, sum))
df.col.agg.ci<-binom.confint(df.col.agg$col.num, df.col.agg$col.den, methods="exact")
colnames(df.col.agg.ci)[2]<-"col.num"
colnames(df.col.agg.ci)[3]<-"col.den"

df.sum<-merge(df.col.agg.ci, df.col.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$pchs<-recode(df.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
points(mean ~ CAT_Avg, df.sum2, col="darkorange", pch=df.sum2$pchs, cex=2.25)
lines(exp(predict(dfmod.col, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  "Temnothorax curvispinosus", font=3, cex=1.5)


dev.off()







ap.ext<-ap[ap$ext.den > 0,]
bp.ext<-bp[bp$ext.den > 0,]
cr.ext<-cr[cr$ext.den > 0,]
te.ext<-te[te$ext.den > 0,]

# Extinction
tiff("DF_Extinction.tiff", height=10, width=10, res=300, units="in")
par(mfrow=c(2,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2), mgp=c(3,.6,0))

dfmod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, ap.ext, family=quasibinomial)
plot(ext.num/ext.den ~ CAT_Avg, ap.ext, xlab="Chamber temperature (C)", ylab="Extinction", type="n", ylim=c(0,1.15))

df.ext.agg<-as.data.frame(aggregate(cbind(ext.num,ext.den) ~ ch, ap.ext, sum))
df.ext.agg.ci<-binom.confint(df.ext.agg$ext.num, df.ext.agg$ext.den, methods="exact")
colnames(df.ext.agg.ci)[2]<-"ext.num"
colnames(df.ext.agg.ci)[3]<-"ext.den"

df.sum<-merge(df.ext.agg.ci, df.ext.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$pchs<-recode(df.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
points(mean ~ CAT_Avg, df.sum2, col="darkorange", pch=df.sum2$pchs, cex=2.25)
lines(exp(predict(dfmod.ext, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  expression(paste(italic("Aphaenogaster"), " sp.")), cex=1.5)



dfmod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, bp.ext, family=quasibinomial)
plot(ext.num/ext.den ~ CAT_Avg, bp.ext, xlab="Chamber temperature (C)", ylab="Extinction", type="n", ylim=c(0,1.15), xlim=c(14.56874, 19.540700))

df.ext.agg<-as.data.frame(aggregate(cbind(ext.num,ext.den) ~ ch, bp.ext, sum))
df.ext.agg.ci<-binom.confint(df.ext.agg$ext.num, df.ext.agg$ext.den, methods="exact")
colnames(df.ext.agg.ci)[2]<-"ext.num"
colnames(df.ext.agg.ci)[3]<-"ext.den"

df.sum<-merge(df.ext.agg.ci, df.ext.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$pchs<-recode(df.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
points(mean ~ CAT_Avg, df.sum2, col="darkorange", pch=df.sum2$pchs, cex=2.25)
lines(exp(predict(dfmod.ext, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  "Brachyponera chinensis", font=3, cex=1.5)



dfmod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, cr.ext, family=quasibinomial)
plot(ext.num/ext.den ~ CAT_Avg, cr.ext, xlab="Chamber temperature (C)", ylab="Extinction", type="n", ylim=c(0,1.15))

df.ext.agg<-as.data.frame(aggregate(cbind(ext.num,ext.den) ~ ch, cr.ext, sum))
df.ext.agg.ci<-binom.confint(df.ext.agg$ext.num, df.ext.agg$ext.den, methods="exact")
colnames(df.ext.agg.ci)[2]<-"ext.num"
colnames(df.ext.agg.ci)[3]<-"ext.den"

df.sum<-merge(df.ext.agg.ci, df.ext.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$pchs<-recode(df.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
points(mean ~ CAT_Avg, df.sum2, col="darkorange", pch=df.sum2$pchs, cex=2.25)
lines(exp(predict(dfmod.ext, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  "Crematogaster lineolata", font=3, cex=1.5)



dfmod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, te.ext, family=quasibinomial)
plot(ext.num/ext.den ~ CAT_Avg, te.ext, xlab="Chamber temperature (C)", ylab="Extinction", type="n", ylim=c(0,1.15))

df.ext.agg<-as.data.frame(aggregate(cbind(ext.num,ext.den) ~ ch, te.ext, sum))
df.ext.agg.ci<-binom.confint(df.ext.agg$ext.num, df.ext.agg$ext.den, methods="exact")
colnames(df.ext.agg.ci)[2]<-"ext.num"
colnames(df.ext.agg.ci)[3]<-"ext.den"

df.sum<-merge(df.ext.agg.ci, df.ext.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$pchs<-recode(df.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
points(mean ~ CAT_Avg, df.sum2, col="darkorange", pch=df.sum2$pchs, cex=2.25)
lines(exp(predict(dfmod.ext, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  "Temnothorax curvispinosus", font=3, cex=1.5)


dev.off()





ap.per<-ap[ap$per.den > 0 & !is.na(ap$per.den),]
bp.per<-bp[bp$per.den > 0 & !is.na(bp$per.den),]
cr.per<-cr[cr$per.den > 0 & !is.na(cr$per.den),]
te.per<-te[te$per.den > 0 & !is.na(te$per.den),]

# Persistence
tiff("DF_Persistence.tiff", height=10, width=10, res=300, units="in")
par(mfrow=c(2,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2), mgp=c(3,.6,0))

dfmod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, ap.per, family=quasibinomial)
plot(per.num/per.den ~ CAT_Avg, ap.per, xlab="Chamber temperature (C)", ylab="Persistence", type="n", ylim=c(0,0.8))

df.per.agg<-as.data.frame(aggregate(cbind(per.num,per.den) ~ ch, ap.per, sum))
df.per.agg.ci<-binom.confint(df.per.agg$per.num, df.per.agg$per.den, methods="exact")
colnames(df.per.agg.ci)[2]<-"per.num"
colnames(df.per.agg.ci)[3]<-"per.den"

df.sum<-merge(df.per.agg.ci, df.per.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$pchs<-recode(df.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
points(mean ~ CAT_Avg, df.sum2, col="darkorange", pch=df.sum2$pchs, cex=2.25)
lines(exp(predict(dfmod.per, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  expression(paste(italic("Aphaenogaster"), " sp.")), cex=1.5)



dfmod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, bp.per, family=quasibinomial)
plot(ext.num/ext.den ~ CAT_Avg, bp.ext, xlab="Chamber temperature (C)", ylab="Persistence", type="n", ylim=c(0,1.05), xlim=c(14.56874, 19.540700))

df.per.agg<-as.data.frame(aggregate(cbind(per.num,per.den) ~ ch, bp.per, sum))
df.per.agg.ci<-binom.confint(df.per.agg$per.num, df.per.agg$per.den, methods="exact")
colnames(df.per.agg.ci)[2]<-"per.num"
colnames(df.per.agg.ci)[3]<-"per.den"

df.sum<-merge(df.per.agg.ci, df.per.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$pchs<-recode(df.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
points(mean ~ CAT_Avg, df.sum2, col="darkorange", pch=df.sum2$pchs, cex=2.25)
#lines(exp(predict(dfmod.per, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  "Brachyponera chinensis", font=3, cex=1.5)



dfmod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, cr.per, family=quasibinomial)
plot(per.num/per.den ~ CAT_Avg, cr.per, xlab="Chamber temperature (C)", ylab="Persistence", type="n", ylim=c(0,1.05))

df.per.agg<-as.data.frame(aggregate(cbind(per.num,per.den) ~ ch, cr.ext, sum))
df.per.agg.ci<-binom.confint(df.per.agg$per.num, df.per.agg$per.den, methods="exact")
colnames(df.per.agg.ci)[2]<-"per.num"
colnames(df.per.agg.ci)[3]<-"per.den"

df.sum<-merge(df.per.agg.ci, df.per.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$pchs<-recode(df.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
points(mean ~ CAT_Avg, df.sum2, col="darkorange", pch=df.sum2$pchs, cex=2.25)
lines(exp(predict(dfmod.per, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  "Crematogaster lineolata", font=3, cex=1.5)



dfmod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, te.per, family=quasibinomial)
plot(per.num/per.den ~ CAT_Avg, te.per, xlab="Chamber temperature (C)", ylab="Persistence", type="n", ylim=c(0,1.05))

df.per.agg<-as.data.frame(aggregate(cbind(per.num,per.den) ~ ch, te.per, sum))
df.per.agg.ci<-binom.confint(df.per.agg$per.num, df.per.agg$per.den, methods="exact")
colnames(df.per.agg.ci)[2]<-"per.num"
colnames(df.per.agg.ci)[3]<-"per.den"

df.sum<-merge(df.per.agg.ci, df.per.agg, all=TRUE)

df.sum$Target_Delta<-recode(df.sum$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("DF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(14.56717, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

df.sum2<-merge(df.sum, temp_vals[,1:3], "ch")
df.sum2$pchs<-recode(df.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = df.sum2$CAT_Avg, x1 = df.sum2$CAT_Avg, y0=df.sum2$lower, y1=df.sum2$upper, col="darkorange")
points(mean ~ CAT_Avg, df.sum2, col="darkorange", pch=df.sum2$pchs, cex=2.25)
lines(exp(predict(dfmod.per, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  "Temnothorax curvispinosus", font=3, cex=1.5)


dev.off()






# Levins model

tiff("DF_Levins.tiff", height=10, width=10, res=300, units="in")
par(mfrow=c(2,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2), mgp=c(3,.6,0))
ap$pchs<-recode(ap$ch, "lo:12=16; 13:hi=21")
ap$p.occ.hat=(ap$col.num/ap$col.den)/((ap$col.num/ap$col.den)+(ap$ext.num/ap$ext.den)) 
plot(p.occ.hat ~ CAT_Avg, ap, xlab="Chamber temperature (C)", ylab="Estimated occupancy", type="n", ylim=c(0,0.6))
points(ap$p.occ.hat ~ ap$CAT_Avg, col="darkorange", pch=ap$pchs, cex=2.25)
mod.occ.hat<-glm(p.occ.hat ~ CAT_Avg, ap, family=quasibinomial, na.action=na.omit)
lines(exp(predict(mod.occ.hat, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  expression(paste(italic("Aphaenogaster"), " sp.")), cex=1.5)

anova(mod.occ.hat, test="Chi")
summary(mod.occ.hat)

bp$pchs<-recode(bp$ch, "lo:12=16; 13:hi=21")
bp$p.occ.hat=(bp$col.num/bp$col.den)/((bp$col.num/bp$col.den)+(bp$ext.num/bp$ext.den)) 
plot(p.occ.hat ~ CAT_Avg, bp, xlab="Chamber temperature (C)", ylab="Estimated occupancy", type="n", ylim=c(0,0.3))
points(bp$p.occ.hat ~ bp$CAT_Avg, col="darkorange", pch=bp$pchs, cex=2.25)
mod.occ.hat<-glm(p.occ.hat ~ CAT_Avg, bp, family=quasibinomial, na.action=na.omit)
lines(exp(predict(mod.occ.hat, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  "Brachyponera chinensis", font=3, cex=1.5)

anova(mod.occ.hat, test="Chi")
summary(mod.occ.hat)

cr$pchs<-recode(cr$ch, "lo:12=16; 13:hi=21")
cr$p.occ.hat=(cr$col.num/cr$col.den)/((cr$col.num/cr$col.den)+(cr$ext.num/cr$ext.den)) 
plot(p.occ.hat ~ CAT_Avg, cr, xlab="Chamber temperature (C)", ylab="Estimated occupancy", type="n", ylim=c(0,0.7))
points(cr$p.occ.hat ~ cr$CAT_Avg, col="darkorange", pch=cr$pchs, cex=2.25)
mod.occ.hat<-glm(p.occ.hat ~ CAT_Avg, cr, family=quasibinomial, na.action=na.omit)
lines(exp(predict(mod.occ.hat, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  "Crematogaster lineolata", font=3, cex=1.5)

anova(mod.occ.hat, test="Chi")
summary(mod.occ.hat)

te$pchs<-recode(te$ch, "lo:12=16; 13:hi=21")
te$p.occ.hat=(te$col.num/te$col.den)/((te$col.num/te$col.den)+(te$ext.num/te$ext.den)) 
plot(p.occ.hat ~ CAT_Avg, te, xlab="Chamber temperature (C)", ylab="Estimated occupancy", type="n", ylim=c(0,0.7))
points(te$p.occ.hat ~ te$CAT_Avg, col="darkorange", pch=te$pchs, cex=2.25)
mod.occ.hat<-glm(p.occ.hat ~ CAT_Avg, te, family=quasibinomial, na.action=na.omit)
lines(exp(predict(mod.occ.hat, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  "Temnothorax curvispinosus", font=3, cex=1.5)

anova(mod.occ.hat, test="Chi")
summary(mod.occ.hat)

dev.off()


# Turnover model
tiff("DF_Turnover.tiff", height=10, width=10, res=300, units="in")
par(mfrow=c(2,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2), mgp=c(3,.6,0))

ap0<-ap[ap$ext.den > 0 & ap$col.den > 0,]
ap0$p.turn<-((ap0$col.num/ap0$col.den)*(ap0$ext.num/ap0$ext.den))/((ap0$col.num/ap0$col.den)+(ap0$ext.num/ap0$ext.den))
ap0$pchs<-recode(ap0$ch, "lo:12=16; 13:hi=21")
plot(p.turn ~ CAT_Avg, ap0, xlab="Chamber temperature (C)", ylab="Turnover", ylim=c(0,.35), col="darkorange", pch=ap0$pchs, cex=2.25)
mod.p.turn<-glm(p.turn ~ CAT_Avg, ap0, family=quasibinomial)
lines(exp(predict(mod.p.turn, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  expression(paste(italic("Aphaenogaster"), " sp.")), cex=1.5)

anova(mod.p.turn, test="Chi")
summary(mod.p.turn)


bp0<-bp[bp$ext.den > 0 & bp$col.den > 0,]
bp0$p.turn<-((bp0$col.num/bp0$col.den)*(bp0$ext.num/bp0$ext.den))/((bp0$col.num/bp0$col.den)+(bp0$ext.num/bp0$ext.den))
bp0$pchs<-recode(bp0$ch, "lo:12=16; 13:hi=21")
plot(p.turn ~ CAT_Avg, bp0, xlab="Chamber temperature (C)", ylab="Turnover", ylim=c(0,.1), col="darkorange", pch=bp0$pchs, cex=2.25, xlim=c(14.56874, 19.540700))
mod.p.turn<-glm(p.turn ~ CAT_Avg, bp0, family=quasibinomial)
lines(exp(predict(mod.p.turn, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  "Brachyponera chinensis", font=3, cex=1.5)

anova(mod.p.turn, test="Chi")
summary(mod.p.turn)


cr0<-cr[cr$ext.den > 0 & cr$col.den > 0,]
cr0$p.turn<-((cr0$col.num/cr0$col.den)*(cr0$ext.num/cr0$ext.den))/((cr0$col.num/cr0$col.den)+(cr0$ext.num/cr0$ext.den))
cr0$pchs<-recode(cr0$ch, "lo:12=16; 13:hi=21")
plot(p.turn ~ CAT_Avg, cr0, xlab="Chamber temperature (C)", ylab="Turnover", ylim=c(0,.35), col="darkorange", pch=cr0$pchs, cex=2.25)
mod.p.turn<-glm(p.turn ~ CAT_Avg, cr0, family=quasibinomial)
lines(exp(predict(mod.p.turn, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  "Crematogaster lineolata", font=3, cex=1.5)

anova(mod.p.turn, test="Chi")
summary(mod.p.turn)

te0<-te[te$ext.den > 0 & te$col.den > 0,]
te0$p.turn<-((te0$col.num/te0$col.den)*(te0$ext.num/te0$ext.den))/((te0$col.num/te0$col.den)+(te0$ext.num/te0$ext.den))
te0$pchs<-recode(te0$ch, "lo:12=16; 13:hi=21")
plot(p.turn ~ CAT_Avg, te0, xlab="Chamber temperature (C)", ylab="Turnover", ylim=c(0,.15), col="darkorange", pch=te0$pchs, cex=2.25)
mod.p.turn<-glm(p.turn ~ CAT_Avg, te0, family=quasibinomial)
lines(exp(predict(mod.p.turn, newdata=data.frame(CAT_Avg=seq(14.56874, 19.540700,length.out=1000)))) ~ seq(14.56874, 19.540700,length.out=1000), col="darkorange", lwd=1.5, lty=2)
mtext(side=3, line=-2,  "Temnothorax curvispinosus", font=3, cex=1.5)

anova(mod.p.turn, test="Chi")
summary(mod.p.turn)

dev.off()

################################################################################                   
# crli plots ###################################################################
################################################################################
                   
cr.col<-cr[cr$col.den > 0,]
cr.ext<-cr[cr$ext.den > 0,]
cr.occ<-cr[cr$occ.den > 0,]
cr.stasis<-cr[cr$stasis.den > 0 & !is.na(cr$stasis.den),]
cr.per<-cr[cr$per.den > 0 & !is.na(cr$per.den),]

mod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, cr.col, family=quasibinomial)
mod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, cr.ext, family=quasibinomial)
mod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, cr.occ, family=quasibinomial)
mod.sta<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, cr.stasis, family=quasibinomial)
mod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, cr.per, family=quasibinomial)



# plot the raw proportions for each nest box in each chamber
tiff("Nest_box_responses_actualT_Cre_lin_DF.tiff", height=10, width=10, res=300, units="in")
par(mfrow=c(2,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(occ.num/occ.den ~ CAT_Avg, cr.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy")
lines(exp(predict(mod.occ, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(col.num/col.den ~ CAT_Avg, cr.col, xlab="Chamber temperature (C)", ylab="Colonization")
lines(exp(predict(mod.col, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(ext.num/ext.den ~ CAT_Avg, cr.ext, xlab="Chamber temperature (C)", ylab="Extinction")
lines(exp(predict(mod.ext, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(stasis.num/stasis.den ~ CAT_Avg, cr.stasis, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.sta, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

dev.off()



# revised persistence
tiff("Nest_box_responses_actualT_Cre_lin_persistence.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(per.num/per.den ~ CAT_Avg, cr.per, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.per, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)
dev.off()



# colonization-extinction predicted occupancy
tiff("Nest_box_responses_actualT_Cre_lin_occ_obs_exp.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))

plot(occ.num/occ.den ~ CAT_Avg, cr.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy", ylim=c(0,1), col="blue", pch=16)
lines(exp(predict(mod.occ, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

cr$p.occ.hat=(cr$col.num/cr$col.den)/((cr$col.num/cr$col.den)+(cr$ext.num/cr$ext.den)) 

points(cr$p.occ.hat ~ cr$CAT_Avg, col="red", pch=16)
mod.occ.hat<-glm(p.occ.hat ~ CAT_Avg, cr, family=quasibinomial, na.action=na.omit)
lines(exp(predict(mod.occ.hat, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="red", lwd=2)

legend("topleft", c("GLM", "Col-Ext Model"), col=c("blue", "red"), lty=1, bty="n", lwd=2)

dev.off()



# MacArthur-Wilson model: turnover
cr0<-cr[cr$ext.den > 0 & cr$col.den > 0,]
cr0$p.turn<-((cr0$col.num/cr0$col.den)*(cr0$ext.num/cr0$ext.den))/((cr0$col.num/cr0$col.den)+(cr0$ext.num/cr0$ext.den))

tiff("Nest_box_responses_actualT_Cre_lin_MW_turnover.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))

plot(p.turn ~ CAT_Avg, cr0, xlab="Chamber temperature (C)", ylab="Turnover", ylim=c(0,.4), col="blue", pch=16)
mod.p.turn<-glm(p.turn ~ CAT_Avg, cr0, family=quasibinomial)
lines(exp(predict(mod.p.turn, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

dev.off()



write.csv(summary(mod.occ.hat)$coefficients, "Cre_lin_col_ext_mod.csv")
write.csv(summary(mod.p.turn)$coefficients, "Cre_lin_turnover_mod.csv")
 
################################################################################
# aphe plots ###################################################################
################################################################################

ap.col<-ap[ap$col.den > 0,]
ap.ext<-ap[ap$ext.den > 0,]
ap.occ<-ap[ap$occ.den > 0,]
ap.stasis<-ap[ap$stasis.den > 0 & !is.na(ap$stasis.den),]
ap.per<-ap[ap$per.den > 0 & !is.na(ap$per.den),]

mod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, ap.col, family=quasibinomial)
mod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, ap.ext, family=quasibinomial)
mod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, ap.occ, family=quasibinomial)
mod.sta<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, ap.stasis, family=quasibinomial)
mod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, ap.per, family=quasibinomial)



# plot the raw proportions for each nest box in each chamber
tiff("Nest_box_responses_actualT_Aph_rud_DF.tiff", height=10, width=10, res=300, units="in")
par(mfrow=c(2,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(occ.num/occ.den ~ CAT_Avg, ap.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy")
lines(exp(predict(mod.occ, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(col.num/col.den ~ CAT_Avg, ap.col, xlab="Chamber temperature (C)", ylab="Colonization")
lines(exp(predict(mod.col, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(ext.num/ext.den ~ CAT_Avg, ap.ext, xlab="Chamber temperature (C)", ylab="Extinction")
lines(exp(predict(mod.ext, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(stasis.num/stasis.den ~ CAT_Avg, ap.stasis, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.sta, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)
dev.off()



# revised persistence
tiff("Nest_box_responses_actualT_Aph_rud_persistence.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(per.num/per.den ~ CAT_Avg, ap.per, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.per, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)
dev.off()



# colonization-extinction predicted occupancy
tiff("Nest_box_responses_actualT_Aph_rud_occ_obs_exp.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))

plot(occ.num/occ.den ~ CAT_Avg, ap.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy", ylim=c(0,1), col="blue", pch=16)
lines(exp(predict(mod.occ, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

ap$p.occ.hat=(ap$col.num/ap$col.den)/((ap$col.num/ap$col.den)+(ap$ext.num/ap$ext.den)) 

points(ap$p.occ.hat ~ ap$CAT_Avg, col="red", pch=16)
mod.occ.hat<-glm(p.occ.hat ~ CAT_Avg, ap, family=quasibinomial, na.action=na.omit)
lines(exp(predict(mod.occ.hat, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="red", lwd=2)

legend("topleft", c("GLM", "Col-Ext Model"), col=c("blue", "red"), lty=1, bty="n", lwd=2)

dev.off()



# MacArthur-Wilson model: turnover
ap0<-ap[ap$ext.den > 0 & ap$col.den > 0,]
ap0$p.turn<-((ap0$col.num/ap0$col.den)*(ap0$ext.num/ap0$ext.den))/((ap0$col.num/ap0$col.den)+(ap0$ext.num/ap0$ext.den))

tiff("Nest_box_responses_actualT_Aph_rud_MW_turnover.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))

plot(p.turn ~ CAT_Avg, ap0, xlab="Chamber temperature (C)", ylab="Turnover", ylim=c(0,.4), col="blue", pch=16)
mod.p.turn<-glm(p.turn ~ CAT_Avg, ap0, family=quasibinomial)
lines(exp(predict(mod.p.turn, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

dev.off()



write.csv(summary(mod.occ.hat)$coefficients, "Aph_rud_col_ext_mod.csv")
write.csv(summary(mod.p.turn)$coefficients, "Aph_rud_turnover_mod.csv")

################################################################################
# tecu plots ###################################################################
################################################################################

te.col<-te[te$col.den > 0,]
te.ext<-te[te$ext.den > 0,]
te.occ<-te[te$occ.den > 0,]
te.stasis<-te[te$stasis.den > 0 & !is.na(te$stasis.den),]
te.per<-te[te$per.den > 0 & !is.na(te$per.den),]

mod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, te.col, family=quasibinomial)
mod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, te.ext, family=quasibinomial)
mod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, te.occ, family=quasibinomial)
mod.sta<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, te.stasis, family=quasibinomial)
mod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, te.per, family=quasibinomial)



# plot the raw proportions for each nest box in each chamber
tiff("Nest_box_responses_actualT_Tem_cur_DF.tiff", height=10, width=10, res=300, units="in")
par(mfrow=c(2,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(occ.num/occ.den ~ CAT_Avg, te.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy")
lines(exp(predict(mod.occ, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(col.num/col.den ~ CAT_Avg, te.col, xlab="Chamber temperature (C)", ylab="Colonization")
lines(exp(predict(mod.col, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(ext.num/ext.den ~ CAT_Avg, te.ext, xlab="Chamber temperature (C)", ylab="Extinction")
lines(exp(predict(mod.ext, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(stasis.num/stasis.den ~ CAT_Avg, te.stasis, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.sta, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)
dev.off()



# revised persistence
tiff("Nest_box_responses_actualT_Tem_cur_persistence.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(per.num/per.den ~ CAT_Avg, te.per, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.per, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)
dev.off()



# colonization-extinction predicted occupancy
tiff("Nest_box_responses_actualT_Tem_cur_occ_obs_exp.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))

plot(occ.num/occ.den ~ CAT_Avg, te.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy", ylim=c(0,1), col="blue", pch=16)
lines(exp(predict(mod.occ, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

te$p.occ.hat=(te$col.num/te$col.den)/((te$col.num/te$col.den)+(te$ext.num/te$ext.den)) 

points(te$p.occ.hat ~ te$CAT_Avg, col="red", pch=16)
mod.occ.hat<-glm(p.occ.hat ~ CAT_Avg, te, family=quasibinomial, na.action=na.omit)
lines(exp(predict(mod.occ.hat, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="red", lwd=2)

legend("topleft", c("GLM", "Col-Ext Model"), col=c("blue", "red"), lty=1, bty="n", lwd=2)

dev.off()



# MacArthur-Wilson model: turnover
te0<-te[te$ext.den > 0 & te$col.den > 0,]
te0$p.turn<-((te0$col.num/te0$col.den)*(te0$ext.num/te0$ext.den))/((te0$col.num/te0$col.den)+(te0$ext.num/te0$ext.den))

tiff("Nest_box_responses_actualT_Tem_cur_MW_turnover.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))

plot(p.turn ~ CAT_Avg, te0, xlab="Chamber temperature (C)", ylab="Turnover", ylim=c(0,.4), col="blue", pch=16)
mod.p.turn<-glm(p.turn ~ CAT_Avg, te0, family=quasibinomial)
lines(exp(predict(mod.p.turn, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

dev.off()



write.csv(summary(mod.occ.hat)$coefficients, "Tem_cur_col_ext_mod.csv")
write.csv(summary(mod.p.turn)$coefficients, "Tem_cur_turnover_mod.csv")

################################################################################
# brch plots ###################################################################
################################################################################

bp.col<-bp[bp$col.den > 0,]
bp.ext<-bp[bp$ext.den > 0,]
bp.occ<-bp[bp$occ.den > 0,]
bp.stasis<-bp[bp$stasis.den > 0 & !is.na(bp$stasis.den),]
bp.per<-bp[bp$per.den > 0 & !is.na(bp$per.den),]

mod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, bp.col, family=quasibinomial)
mod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, bp.ext, family=quasibinomial)
mod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, bp.occ, family=quasibinomial)
mod.sta<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, bp.stasis, family=quasibinomial)
mod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, bp.per, family=quasibinomial)



# plot the raw proportions for each nest box in each chamber
tiff("Nest_box_responses_actualT_Bra_chi_DF.tiff", height=10, width=10, res=300, units="in")
par(mfrow=c(2,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(occ.num/occ.den ~ CAT_Avg, bp.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy", col="blue", xlim=c(14,20), pch=16)

plot(col.num/col.den ~ CAT_Avg, bp.col, xlab="Chamber temperature (C)", ylab="Colonization", col="blue", xlim=c(14,20), pch=16)

plot(ext.num/ext.den ~ CAT_Avg, bp.ext, xlab="Chamber temperature (C)", ylab="Extinction", col="blue", xlim=c(14,20), pch=16)

plot(stasis.num/stasis.den ~ CAT_Avg, bp.stasis, xlab="Chamber temperature (C)", ylab="Persistence" , xlim=c(14,20), col="blue", pch=16)

dev.off()



# revised persistence
tiff("Nest_box_responses_actualT_Bra_chi_persistence.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(per.num/per.den ~ CAT_Avg, bp.per, xlab="Chamber temperature (C)", ylab="Persistence")
dev.off()



################################################################################
# Community responses ##########################################################
################################################################################

dfcomm1<-read.csv("Entire_DF_community.csv", header=TRUE)

# recode the chamber IDs to target deltas
library(car)
dfcomm1$Target_Delta<-recode(dfcomm1$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals<-read.csv("DF_CAT_Avg.csv", header=TRUE)
colnames(temp_vals)[2]<-"ch"

dfcomm<-merge(dfcomm1, temp_vals[,1:3], "ch")

dfcomm.col<-dfcomm[dfcomm$col.den > 0,]
dfcomm.ext<-dfcomm[dfcomm$ext.den > 0,]
dfcomm.occ<-dfcomm[dfcomm$occ.den > 0,]
dfcomm.stasis<-dfcomm[dfcomm$stasis.den > 0 & !is.na(dfcomm$stasis.den),]
dfcomm.per<-dfcomm[dfcomm$per.den > 0 & !is.na(dfcomm$per.den),]

mod.col<-glm(cbind(col.numr,col.denr) ~ CAT_Avg, dfcomm.col, family=quasibinomial)
mod.ext<-glm(cbind(ext.numr,ext.denr) ~ CAT_Avg, dfcomm.ext, family=quasibinomial)
mod.occ<-glm(cbind(occ.numr,occ.denr) ~ CAT_Avg, dfcomm.occ, family=quasibinomial)
mod.sta<-glm(cbind(stasis.numr,stasis.denr) ~ CAT_Avg, dfcomm.stasis, family=quasibinomial)
mod.per<-glm(cbind(per.numr,per.denr) ~ CAT_Avg, dfcomm.per, family=quasibinomial)

# plot the raw proportions for each nest box in each chamber
tiff("Nest_box_responses_all_DF_actualT.tiff", height=10, width=10, res=300, units="in")
par(mfrow=c(2,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(occ.numr/occ.denr ~ CAT_Avg, dfcomm.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy")
lines(exp(predict(mod.occ, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(col.numr/col.denr ~ CAT_Avg, dfcomm.col, xlab="Chamber temperature (C)", ylab="Colonization")
lines(exp(predict(mod.col, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(ext.numr/ext.denr ~ CAT_Avg, dfcomm.ext, xlab="Chamber temperature (C)", ylab="Extinction")
lines(exp(predict(mod.ext, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(stasis.numr/stasis.denr ~ CAT_Avg, dfcomm.stasis, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.sta, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)
dev.off()



# revised persistence
tiff("Nest_box_responses_actualT_all_DF_persistence.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(per.numr/per.denr ~ CAT_Avg, dfcomm.per, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.per, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)
dev.off()



allDF_table<-
rbind(
      cbind("occ", signif(summary(mod.occ)$coefficients[2,1],3), 
                   signif(summary(mod.occ)$coefficients[2,2],3), 
                   signif(anova(mod.occ, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.occ, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("ext", signif(summary(mod.ext)$coefficients[2,1],3), 
                   signif(summary(mod.ext)$coefficients[2,2],3), 
                   signif(anova(mod.ext, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.ext, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("col", signif(summary(mod.col)$coefficients[2,1],3), 
                   signif(summary(mod.col)$coefficients[2,2],3), 
                   signif(anova(mod.col, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.col, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("sta", signif(summary(mod.sta)$coefficients[2,1],3), 
                   signif(summary(mod.sta)$coefficients[2,2],3), 
                   signif(anova(mod.sta, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.sta, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("per", signif(summary(mod.per)$coefficients[2,1],3), 
                   signif(summary(mod.per)$coefficients[2,2],3), 
                   signif(anova(mod.per, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.per, test="Chi")$"Pr(>Chi)"[2],3))
                   )
                   
colnames(allDF_table)<-c("response","estimate","se","deviance","p")                    
write.csv(allDF_table, "AllDF_model_results.csv")

################################################################################
# Community responses - jackknife - minus aphe #################################
################################################################################

dfcomm.wo.aphe1<-read.csv("DF_community_minus_aphe.csv", header=TRUE)

# recode the chamber IDs to target deltas
library(car)
dfcomm.wo.aphe1$Target_Delta<-recode(dfcomm.wo.aphe1$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals<-read.csv("DF_CAT_Avg.csv", header=TRUE)
colnames(temp_vals)[2]<-"ch"

dfcomm.wo.aphe<-merge(dfcomm.wo.aphe1, temp_vals[,1:3], "ch")

dfcomm.wo.aphe.col<-dfcomm.wo.aphe[dfcomm.wo.aphe$col.den > 0,]
dfcomm.wo.aphe.ext<-dfcomm.wo.aphe[dfcomm.wo.aphe$ext.den > 0,]
dfcomm.wo.aphe.occ<-dfcomm.wo.aphe[dfcomm.wo.aphe$occ.den > 0,]
dfcomm.wo.aphe.stasis<-dfcomm.wo.aphe[dfcomm.wo.aphe$stasis.den > 0 & !is.na(dfcomm.wo.aphe$stasis.den),]
dfcomm.wo.aphe.per<-dfcomm.wo.aphe[dfcomm.wo.aphe$per.den > 0 & !is.na(dfcomm.wo.aphe$per.den),]

mod.wo.aphe.col<-glm(cbind(col.numr,col.denr) ~ CAT_Avg, dfcomm.wo.aphe.col, family=quasibinomial)
mod.wo.aphe.ext<-glm(cbind(ext.numr,ext.denr) ~ CAT_Avg, dfcomm.wo.aphe.ext, family=quasibinomial)
mod.wo.aphe.occ<-glm(cbind(occ.numr,occ.denr) ~ CAT_Avg, dfcomm.wo.aphe.occ, family=quasibinomial)
mod.wo.aphe.sta<-glm(cbind(stasis.numr,stasis.denr) ~ CAT_Avg, dfcomm.wo.aphe.stasis, family=quasibinomial)
mod.wo.aphe.per<-glm(cbind(per.numr,per.denr) ~ CAT_Avg, dfcomm.wo.aphe.per, family=quasibinomial)

# plot the raw proportions for each nest box in each chamber
tiff("Nest_box_responses_DF_minus_aphe_actualT.tiff", height=10, width=15, res=300, units="in")
par(mfrow=c(2,3), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(occ.numr/occ.denr ~ CAT_Avg, dfcomm.wo.aphe.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy")
lines(exp(predict(mod.wo.aphe.occ, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(col.numr/col.denr ~ CAT_Avg, dfcomm.wo.aphe.col, xlab="Chamber temperature (C)", ylab="Colonization")
lines(exp(predict(mod.wo.aphe.col, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(ext.numr/ext.denr ~ CAT_Avg, dfcomm.wo.aphe.ext, xlab="Chamber temperature (C)", ylab="Extinction")
lines(exp(predict(mod.wo.aphe.ext, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(stasis.numr/stasis.denr ~ CAT_Avg, dfcomm.wo.aphe.stasis, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.wo.aphe.sta, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(per.numr/per.denr ~ CAT_Avg, dfcomm.wo.aphe.per, xlab="Chamber temperature (C)", ylab="Revised Persistence")
lines(exp(predict(mod.wo.aphe.per, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

dev.off()



DF_minus_aphe<-
rbind(
      cbind("occ", signif(summary(mod.wo.aphe.occ)$coefficients[2,1],3), 
                   signif(summary(mod.wo.aphe.occ)$coefficients[2,2],3), 
                   signif(anova(mod.wo.aphe.occ, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.aphe.occ, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("ext", signif(summary(mod.wo.aphe.ext)$coefficients[2,1],3), 
                   signif(summary(mod.wo.aphe.ext)$coefficients[2,2],3), 
                   signif(anova(mod.wo.aphe.ext, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.aphe.ext, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("col", signif(summary(mod.wo.aphe.col)$coefficients[2,1],3), 
                   signif(summary(mod.wo.aphe.col)$coefficients[2,2],3), 
                   signif(anova(mod.wo.aphe.col, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.aphe.col, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("sta", signif(summary(mod.wo.aphe.sta)$coefficients[2,1],3), 
                   signif(summary(mod.wo.aphe.sta)$coefficients[2,2],3), 
                   signif(anova(mod.wo.aphe.sta, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.aphe.sta, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("per", signif(summary(mod.wo.aphe.per)$coefficients[2,1],3), 
                   signif(summary(mod.wo.aphe.per)$coefficients[2,2],3), 
                   signif(anova(mod.wo.aphe.per, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.aphe.per, test="Chi")$"Pr(>Chi)"[2],3))
                   )
                   
colnames(DF_minus_aphe)<-c("response","estimate","se","deviance","p")                    
write.csv(DF_minus_aphe, "DF_minus_aphe_model_results.csv")

################################################################################
# Community responses - jackknife - minus crli #################################
################################################################################

dfcomm.wo.crli1<-read.csv("DF_community_minus_crli.csv", header=TRUE)

# recode the chamber IDs to target deltas
library(car)
dfcomm.wo.crli1$Target_Delta<-recode(dfcomm.wo.crli1$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals<-read.csv("DF_CAT_Avg.csv", header=TRUE)
colnames(temp_vals)[2]<-"ch"

dfcomm.wo.crli<-merge(dfcomm.wo.crli1, temp_vals[,1:3], "ch")

dfcomm.wo.crli.col<-dfcomm.wo.crli[dfcomm.wo.crli$col.den > 0,]
dfcomm.wo.crli.ext<-dfcomm.wo.crli[dfcomm.wo.crli$ext.den > 0,]
dfcomm.wo.crli.occ<-dfcomm.wo.crli[dfcomm.wo.crli$occ.den > 0,]
dfcomm.wo.crli.stasis<-dfcomm.wo.crli[dfcomm.wo.crli$stasis.den > 0 & !is.na(dfcomm.wo.crli$stasis.den),]
dfcomm.wo.crli.per<-dfcomm.wo.crli[dfcomm.wo.crli$per.den > 0 & !is.na(dfcomm.wo.crli$per.den),]

mod.wo.crli.col<-glm(cbind(col.numr,col.denr) ~ CAT_Avg, dfcomm.wo.crli.col, family=quasibinomial)
mod.wo.crli.ext<-glm(cbind(ext.numr,ext.denr) ~ CAT_Avg, dfcomm.wo.crli.ext, family=quasibinomial)
mod.wo.crli.occ<-glm(cbind(occ.numr,occ.denr) ~ CAT_Avg, dfcomm.wo.crli.occ, family=quasibinomial)
mod.wo.crli.sta<-glm(cbind(stasis.numr,stasis.denr) ~ CAT_Avg, dfcomm.wo.crli.stasis, family=quasibinomial)
mod.wo.crli.per<-glm(cbind(per.numr,per.denr) ~ CAT_Avg, dfcomm.wo.crli.per, family=quasibinomial)

# plot the raw proportions for each nest box in each chamber
tiff("Nest_box_responses_DF_minus_crli_actualT.tiff", height=10, width=15, res=300, units="in")
par(mfrow=c(2,3), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(occ.numr/occ.denr ~ CAT_Avg, dfcomm.wo.crli.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy")
lines(exp(predict(mod.wo.crli.occ, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(col.numr/col.denr ~ CAT_Avg, dfcomm.wo.crli.col, xlab="Chamber temperature (C)", ylab="Colonization")
lines(exp(predict(mod.wo.crli.col, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(ext.numr/ext.denr ~ CAT_Avg, dfcomm.wo.crli.ext, xlab="Chamber temperature (C)", ylab="Extinction")
lines(exp(predict(mod.wo.crli.ext, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(stasis.numr/stasis.denr ~ CAT_Avg, dfcomm.wo.crli.stasis, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.wo.crli.sta, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(per.numr/per.denr ~ CAT_Avg, dfcomm.wo.crli.per, xlab="Chamber temperature (C)", ylab="Revised Persistence")
lines(exp(predict(mod.wo.crli.per, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

dev.off()



DF_minus_crli<-
rbind(
      cbind("occ", signif(summary(mod.wo.crli.occ)$coefficients[2,1],3), 
                   signif(summary(mod.wo.crli.occ)$coefficients[2,2],3), 
                   signif(anova(mod.wo.crli.occ, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.crli.occ, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("ext", signif(summary(mod.wo.crli.ext)$coefficients[2,1],3), 
                   signif(summary(mod.wo.crli.ext)$coefficients[2,2],3), 
                   signif(anova(mod.wo.crli.ext, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.crli.ext, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("col", signif(summary(mod.wo.crli.col)$coefficients[2,1],3), 
                   signif(summary(mod.wo.crli.col)$coefficients[2,2],3), 
                   signif(anova(mod.wo.crli.col, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.crli.col, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("sta", signif(summary(mod.wo.crli.sta)$coefficients[2,1],3), 
                   signif(summary(mod.wo.crli.sta)$coefficients[2,2],3), 
                   signif(anova(mod.wo.crli.sta, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.crli.sta, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("per", signif(summary(mod.wo.crli.per)$coefficients[2,1],3), 
                   signif(summary(mod.wo.crli.per)$coefficients[2,2],3), 
                   signif(anova(mod.wo.crli.per, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.crli.per, test="Chi")$"Pr(>Chi)"[2],3))
                   )
                   
colnames(DF_minus_crli)<-c("response","estimate","se","deviance","p")                    
write.csv(DF_minus_crli, "DF_minus_crli_model_results.csv")

################################################################################
# Community responses - jackknife - minus tecu #################################
################################################################################

dfcomm.wo.tecu1<-read.csv("DF_community_minus_tecu.csv", header=TRUE)

# recode the chamber IDs to target deltas
library(car)
dfcomm.wo.tecu1$Target_Delta<-recode(dfcomm.wo.tecu1$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals<-read.csv("DF_CAT_Avg.csv", header=TRUE)
colnames(temp_vals)[2]<-"ch"

dfcomm.wo.tecu<-merge(dfcomm.wo.tecu1, temp_vals[,1:3], "ch")

dfcomm.wo.tecu.col<-dfcomm.wo.tecu[dfcomm.wo.tecu$col.den > 0,]
dfcomm.wo.tecu.ext<-dfcomm.wo.tecu[dfcomm.wo.tecu$ext.den > 0,]
dfcomm.wo.tecu.occ<-dfcomm.wo.tecu[dfcomm.wo.tecu$occ.den > 0,]
dfcomm.wo.tecu.stasis<-dfcomm.wo.tecu[dfcomm.wo.tecu$stasis.den > 0 & !is.na(dfcomm.wo.tecu$stasis.den),]
dfcomm.wo.tecu.per<-dfcomm.wo.tecu[dfcomm.wo.tecu$per.den > 0 & !is.na(dfcomm.wo.tecu$per.den),]

mod.wo.tecu.col<-glm(cbind(col.numr,col.denr) ~ CAT_Avg, dfcomm.wo.tecu.col, family=quasibinomial)
mod.wo.tecu.ext<-glm(cbind(ext.numr,ext.denr) ~ CAT_Avg, dfcomm.wo.tecu.ext, family=quasibinomial)
mod.wo.tecu.occ<-glm(cbind(occ.numr,occ.denr) ~ CAT_Avg, dfcomm.wo.tecu.occ, family=quasibinomial)
mod.wo.tecu.sta<-glm(cbind(stasis.numr,stasis.denr) ~ CAT_Avg, dfcomm.wo.tecu.stasis, family=quasibinomial)
mod.wo.tecu.per<-glm(cbind(per.numr,per.denr) ~ CAT_Avg, dfcomm.wo.tecu.per, family=quasibinomial)

# plot the raw proportions for each nest box in each chamber
tiff("Nest_box_responses_DF_minus_tecu_actualT.tiff", height=10, width=15, res=300, units="in")
par(mfrow=c(2,3), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(occ.numr/occ.denr ~ CAT_Avg, dfcomm.wo.tecu.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy")
lines(exp(predict(mod.wo.tecu.occ, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(col.numr/col.denr ~ CAT_Avg, dfcomm.wo.tecu.col, xlab="Chamber temperature (C)", ylab="Colonization")
lines(exp(predict(mod.wo.tecu.col, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(ext.numr/ext.denr ~ CAT_Avg, dfcomm.wo.tecu.ext, xlab="Chamber temperature (C)", ylab="Extinction")
lines(exp(predict(mod.wo.tecu.ext, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(stasis.numr/stasis.denr ~ CAT_Avg, dfcomm.wo.tecu.stasis, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.wo.tecu.sta, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(per.numr/per.denr ~ CAT_Avg, dfcomm.wo.tecu.per, xlab="Chamber temperature (C)", ylab="Revised Persistence")
lines(exp(predict(mod.wo.tecu.per, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

dev.off()



DF_minus_tecu<-
rbind(
      cbind("occ", signif(summary(mod.wo.tecu.occ)$coefficients[2,1],3), 
                   signif(summary(mod.wo.tecu.occ)$coefficients[2,2],3), 
                   signif(anova(mod.wo.tecu.occ, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.tecu.occ, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("ext", signif(summary(mod.wo.tecu.ext)$coefficients[2,1],3), 
                   signif(summary(mod.wo.tecu.ext)$coefficients[2,2],3), 
                   signif(anova(mod.wo.tecu.ext, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.tecu.ext, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("col", signif(summary(mod.wo.tecu.col)$coefficients[2,1],3), 
                   signif(summary(mod.wo.tecu.col)$coefficients[2,2],3), 
                   signif(anova(mod.wo.tecu.col, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.tecu.col, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("sta", signif(summary(mod.wo.tecu.sta)$coefficients[2,1],3), 
                   signif(summary(mod.wo.tecu.sta)$coefficients[2,2],3), 
                   signif(anova(mod.wo.tecu.sta, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.tecu.sta, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("per", signif(summary(mod.wo.tecu.per)$coefficients[2,1],3), 
                   signif(summary(mod.wo.tecu.per)$coefficients[2,2],3), 
                   signif(anova(mod.wo.tecu.per, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.tecu.per, test="Chi")$"Pr(>Chi)"[2],3))
                   )
                   
colnames(DF_minus_tecu)<-c("response","estimate","se","deviance","p")                    
write.csv(DF_minus_tecu, "DF_minus_tecu_model_results.csv")

################################################################################
# Community responses - jackknife - minus brch #################################
################################################################################

dfcomm.wo.brch1<-read.csv("DF_community_minus_brch.csv", header=TRUE)

# recode the chamber IDs to target deltas
library(car)
dfcomm.wo.brch1$Target_Delta<-recode(dfcomm.wo.brch1$ch, c("1 = 3.5; 2 = 0; 3 = 4.5; 4 = 2; 5 = 0; 6 = 1.5; 7 = 3; 8 = 5; 9 = 5.5; 10 = 2.5; 11 = 0; 12 = 4; 13 = 0; 14 = 0; 15 = 0"))

temp_vals<-read.csv("DF_CAT_Avg.csv", header=TRUE)
colnames(temp_vals)[2]<-"ch"

dfcomm.wo.brch<-merge(dfcomm.wo.brch1, temp_vals[,1:3], "ch")

dfcomm.wo.brch.col<-dfcomm.wo.brch[dfcomm.wo.brch$col.den > 0,]
dfcomm.wo.brch.ext<-dfcomm.wo.brch[dfcomm.wo.brch$ext.den > 0,]
dfcomm.wo.brch.occ<-dfcomm.wo.brch[dfcomm.wo.brch$occ.den > 0,]
dfcomm.wo.brch.stasis<-dfcomm.wo.brch[dfcomm.wo.brch$stasis.den > 0 & !is.na(dfcomm.wo.brch$stasis.den),]
dfcomm.wo.brch.per<-dfcomm.wo.brch[dfcomm.wo.brch$per.den > 0 & !is.na(dfcomm.wo.brch$per.den),]

mod.wo.brch.col<-glm(cbind(col.numr,col.denr) ~ CAT_Avg, dfcomm.wo.brch.col, family=quasibinomial)
mod.wo.brch.ext<-glm(cbind(ext.numr,ext.denr) ~ CAT_Avg, dfcomm.wo.brch.ext, family=quasibinomial)
mod.wo.brch.occ<-glm(cbind(occ.numr,occ.denr) ~ CAT_Avg, dfcomm.wo.brch.occ, family=quasibinomial)
mod.wo.brch.sta<-glm(cbind(stasis.numr,stasis.denr) ~ CAT_Avg, dfcomm.wo.brch.stasis, family=quasibinomial)
mod.wo.brch.per<-glm(cbind(per.numr,per.denr) ~ CAT_Avg, dfcomm.wo.brch.per, family=quasibinomial)

# plot the raw proportions for each nest box in each chamber
tiff("Nest_box_responses_DF_minus_brch_actualT.tiff", height=10, width=15, res=300, units="in")
par(mfrow=c(2,3), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(occ.numr/occ.denr ~ CAT_Avg, dfcomm.wo.brch.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy")
lines(exp(predict(mod.wo.brch.occ, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(col.numr/col.denr ~ CAT_Avg, dfcomm.wo.brch.col, xlab="Chamber temperature (C)", ylab="Colonization")
lines(exp(predict(mod.wo.brch.col, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(ext.numr/ext.denr ~ CAT_Avg, dfcomm.wo.brch.ext, xlab="Chamber temperature (C)", ylab="Extinction")
lines(exp(predict(mod.wo.brch.ext, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(stasis.numr/stasis.denr ~ CAT_Avg, dfcomm.wo.brch.stasis, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.wo.brch.sta, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

plot(per.numr/per.denr ~ CAT_Avg, dfcomm.wo.brch.per, xlab="Chamber temperature (C)", ylab="Revised Persistence")
lines(exp(predict(mod.wo.brch.per, newdata=data.frame(CAT_Avg=seq(14,20,length.out=1000)))) ~ seq(14,20,length.out=1000), col="blue", lwd=2)

dev.off()



DF_minus_brch<-
rbind(
      cbind("occ", signif(summary(mod.wo.brch.occ)$coefficients[2,1],3), 
                   signif(summary(mod.wo.brch.occ)$coefficients[2,2],3), 
                   signif(anova(mod.wo.brch.occ, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.brch.occ, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("ext", signif(summary(mod.wo.brch.ext)$coefficients[2,1],3), 
                   signif(summary(mod.wo.brch.ext)$coefficients[2,2],3), 
                   signif(anova(mod.wo.brch.ext, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.brch.ext, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("col", signif(summary(mod.wo.brch.col)$coefficients[2,1],3), 
                   signif(summary(mod.wo.brch.col)$coefficients[2,2],3), 
                   signif(anova(mod.wo.brch.col, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.brch.col, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("sta", signif(summary(mod.wo.brch.sta)$coefficients[2,1],3), 
                   signif(summary(mod.wo.brch.sta)$coefficients[2,2],3), 
                   signif(anova(mod.wo.brch.sta, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.brch.sta, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("per", signif(summary(mod.wo.brch.per)$coefficients[2,1],3), 
                   signif(summary(mod.wo.brch.per)$coefficients[2,2],3), 
                   signif(anova(mod.wo.brch.per, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.brch.per, test="Chi")$"Pr(>Chi)"[2],3))
                   )
                   
colnames(DF_minus_brch)<-c("response","estimate","se","deviance","p")                    
write.csv(DF_minus_brch, "DF_minus_brch_model_results.csv")

################################################################################
# non-focal spp as predictors of focal spp; set up for Markov models ###########
################################################################################

################################################################################
# cr on ap #####################################################################
################################################################################

cr$cr.pres.abs<-recode(cr$occ.num, "lo:0=0;1:hi=1")

cr.s<-cr[,c("cr.pres.abs","ch","Nest")]

ap.cr<-merge(cr.s,ap,all=T)

# does the presence of Crematogaster influence Aphaenogaster colonization?
intrxn.mod.apcr1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, ap.cr, family=quasibinomial)
intrxn.mod.apcr2c<-glm(cbind(col.num,col.den) ~ cr.pres.abs, ap.cr, family=quasibinomial)
intrxn.mod.apcr3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + cr.pres.abs, ap.cr, family=quasibinomial)
intrxn.mod.apcr4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * cr.pres.abs, ap.cr, family=quasibinomial)

summary(intrxn.mod.apcr1c)
summary(intrxn.mod.apcr2c)
summary(intrxn.mod.apcr3c)
summary(intrxn.mod.apcr4c)

# does the presence of Crematogaster influence Aphaenogaster extinction?
intrxn.mod.apcr1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, ap.cr, family=quasibinomial)
intrxn.mod.apcr2e<-glm(cbind(ext.num,ext.den) ~ cr.pres.abs, ap.cr, family=quasibinomial)
intrxn.mod.apcr3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + cr.pres.abs, ap.cr, family=quasibinomial)
intrxn.mod.apcr4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * cr.pres.abs, ap.cr, family=quasibinomial)

summary(intrxn.mod.apcr1e)
summary(intrxn.mod.apcr2e)
summary(intrxn.mod.apcr3e)
summary(intrxn.mod.apcr4e)

# does the presence of Crematogaster influence Aphaenogaster occupancy?
intrxn.mod.apcr1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, ap.cr, family=quasibinomial)
intrxn.mod.apcr2o<-glm(cbind(occ.num,occ.den) ~ cr.pres.abs, ap.cr, family=quasibinomial)
intrxn.mod.apcr3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + cr.pres.abs, ap.cr, family=quasibinomial)
intrxn.mod.apcr4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * cr.pres.abs, ap.cr, family=quasibinomial)

summary(intrxn.mod.apcr1o)
summary(intrxn.mod.apcr2o)
summary(intrxn.mod.apcr3o)
summary(intrxn.mod.apcr4o)

# does the presence of Crematogaster influence Aphaenogaster persistence?
intrxn.mod.apcr1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, ap.cr, family=quasibinomial, na.action=na.omit)
intrxn.mod.apcr2s<-glm(cbind(stasis.num,stasis.den) ~ cr.pres.abs, ap.cr, family=quasibinomial, na.action=na.omit)
intrxn.mod.apcr3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + cr.pres.abs, ap.cr, family=quasibinomial, na.action=na.omit)
intrxn.mod.apcr4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * cr.pres.abs, ap.cr, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.apcr1s)
summary(intrxn.mod.apcr2s)
summary(intrxn.mod.apcr3s)
summary(intrxn.mod.apcr4s)

# does the presence of Crematogaster influence Aphaenogaster revised persistence?
intrxn.mod.apcr1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, ap.cr, family=quasibinomial, na.action=na.omit)
intrxn.mod.apcr2p<-glm(cbind(per.num,per.den) ~ cr.pres.abs, ap.cr, family=quasibinomial, na.action=na.omit)
intrxn.mod.apcr3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + cr.pres.abs, ap.cr, family=quasibinomial, na.action=na.omit)
intrxn.mod.apcr4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * cr.pres.abs, ap.cr, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.apcr1p)
summary(intrxn.mod.apcr2p)
summary(intrxn.mod.apcr3p)
summary(intrxn.mod.apcr4p)

cr.on.ap<-
signif(rbind(
summary(intrxn.mod.apcr1c)$coefficients,
summary(intrxn.mod.apcr2c)$coefficients,
summary(intrxn.mod.apcr3c)$coefficients,
summary(intrxn.mod.apcr4c)$coefficients,
summary(intrxn.mod.apcr1e)$coefficients,
summary(intrxn.mod.apcr2e)$coefficients,
summary(intrxn.mod.apcr3e)$coefficients,
summary(intrxn.mod.apcr4e)$coefficients,
summary(intrxn.mod.apcr1o)$coefficients,
summary(intrxn.mod.apcr2o)$coefficients,
summary(intrxn.mod.apcr3o)$coefficients,
summary(intrxn.mod.apcr4o)$coefficients,
summary(intrxn.mod.apcr1s)$coefficients,
summary(intrxn.mod.apcr2s)$coefficients,
summary(intrxn.mod.apcr3s)$coefficients,
summary(intrxn.mod.apcr4s)$coefficients,
summary(intrxn.mod.apcr1p)$coefficients,
summary(intrxn.mod.apcr2p)$coefficients,
summary(intrxn.mod.apcr3p)$coefficients,
summary(intrxn.mod.apcr4p)$coefficients
), digits=3)


write.csv(cr.on.ap, "cr.on.ap.csv")

################################################################################
# ap on cr #####################################################################
################################################################################

ap$ap.pres.abs<-recode(ap$occ.num, "lo:0=0;1:hi=1")

ap.s<-ap[,c("ap.pres.abs","ch","Nest")]

cr.ap<-merge(ap.s,cr,all=T)


# does the presence of Aphaenogaster influence Crematogaster colonization?
intrxn.mod.crap1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, cr.ap, family=quasibinomial)
intrxn.mod.crap2c<-glm(cbind(col.num,col.den) ~ ap.pres.abs, cr.ap, family=quasibinomial)
intrxn.mod.crap3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + ap.pres.abs, cr.ap, family=quasibinomial)
intrxn.mod.crap4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * ap.pres.abs, cr.ap, family=quasibinomial)

summary(intrxn.mod.crap1c)
summary(intrxn.mod.crap2c)
summary(intrxn.mod.crap3c)
summary(intrxn.mod.crap4c)

# does the presence of Aphaenogaster influence Crematogaster extinction?
intrxn.mod.crap1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, cr.ap, family=quasibinomial)
intrxn.mod.crap2e<-glm(cbind(ext.num,ext.den) ~ ap.pres.abs, cr.ap, family=quasibinomial)
intrxn.mod.crap3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + ap.pres.abs, cr.ap, family=quasibinomial)
intrxn.mod.crap4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * ap.pres.abs, cr.ap, family=quasibinomial)

summary(intrxn.mod.crap1e)
summary(intrxn.mod.crap2e)
summary(intrxn.mod.crap3e)
summary(intrxn.mod.crap4e)

# does the presence of Aphaenogaster influence Crematogaster occupancy?
intrxn.mod.crap1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, cr.ap, family=quasibinomial)
intrxn.mod.crap2o<-glm(cbind(occ.num,occ.den) ~ ap.pres.abs, cr.ap, family=quasibinomial)
intrxn.mod.crap3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + ap.pres.abs, cr.ap, family=quasibinomial)
intrxn.mod.crap4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * ap.pres.abs, cr.ap, family=quasibinomial)

summary(intrxn.mod.crap1o)
summary(intrxn.mod.crap2o)
summary(intrxn.mod.crap3o)
summary(intrxn.mod.crap4o)

# does the presence of Aphaenogaster influence Crematogaster persistence?
intrxn.mod.crap1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, cr.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.crap2s<-glm(cbind(stasis.num,stasis.den) ~ ap.pres.abs, cr.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.crap3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + ap.pres.abs, cr.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.crap4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * ap.pres.abs, cr.ap, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.crap1s)
summary(intrxn.mod.crap2s)
summary(intrxn.mod.crap3s)
summary(intrxn.mod.crap4s)

# does the presence of Aphaenogaster influence Crematogaster persistence?
intrxn.mod.crap1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, cr.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.crap2p<-glm(cbind(per.num,per.den) ~ ap.pres.abs, cr.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.crap3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + ap.pres.abs, cr.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.crap4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * ap.pres.abs, cr.ap, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.crap1p)
summary(intrxn.mod.crap2p)
summary(intrxn.mod.crap3p)
summary(intrxn.mod.crap4p)

ap.on.cr<-
signif(rbind(
summary(intrxn.mod.crap1c)$coefficients,
summary(intrxn.mod.crap2c)$coefficients,
summary(intrxn.mod.crap3c)$coefficients,
summary(intrxn.mod.crap4c)$coefficients,
summary(intrxn.mod.crap1e)$coefficients,
summary(intrxn.mod.crap2e)$coefficients,
summary(intrxn.mod.crap3e)$coefficients,
summary(intrxn.mod.crap4e)$coefficients,
summary(intrxn.mod.crap1o)$coefficients,
summary(intrxn.mod.crap2o)$coefficients,
summary(intrxn.mod.crap3o)$coefficients,
summary(intrxn.mod.crap4o)$coefficients,
summary(intrxn.mod.crap1s)$coefficients,
summary(intrxn.mod.crap2s)$coefficients,
summary(intrxn.mod.crap3s)$coefficients,
summary(intrxn.mod.crap4s)$coefficients,
summary(intrxn.mod.crap1p)$coefficients,
summary(intrxn.mod.crap2p)$coefficients,
summary(intrxn.mod.crap3p)$coefficients,
summary(intrxn.mod.crap4p)$coefficients
), digits=3)


write.csv(ap.on.cr, "ap.on.cr.csv")

################################################################################
# cr on te #####################################################################
################################################################################

cr$cr.pres.abs<-recode(cr$occ.num, "lo:0=0;1:hi=1")

cr.s<-cr[,c("cr.pres.abs","ch","Nest")]

te.cr<-merge(cr.s,te,all=T)


# does the presence of Crematogaster influence Temnothorax colonization?
intrxn.mod.tecr1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, te.cr, family=quasibinomial)
intrxn.mod.tecr2c<-glm(cbind(col.num,col.den) ~ cr.pres.abs, te.cr, family=quasibinomial)
intrxn.mod.tecr3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + cr.pres.abs, te.cr, family=quasibinomial)
intrxn.mod.tecr4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * cr.pres.abs, te.cr, family=quasibinomial)

summary(intrxn.mod.tecr1c)
summary(intrxn.mod.tecr2c)
summary(intrxn.mod.tecr3c)
summary(intrxn.mod.tecr4c)

# does the presence of Crematogaster influence Temnothorax extinction?
intrxn.mod.tecr1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, te.cr, family=quasibinomial)
intrxn.mod.tecr2e<-glm(cbind(ext.num,ext.den) ~ cr.pres.abs, te.cr, family=quasibinomial)
intrxn.mod.tecr3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + cr.pres.abs, te.cr, family=quasibinomial)
intrxn.mod.tecr4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * cr.pres.abs, te.cr, family=quasibinomial)

summary(intrxn.mod.tecr1e)
summary(intrxn.mod.tecr2e)
summary(intrxn.mod.tecr3e)
summary(intrxn.mod.tecr4e)

# does the presence of Crematogaster influence Temnothorax occupancy?
intrxn.mod.tecr1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, te.cr, family=quasibinomial)
intrxn.mod.tecr2o<-glm(cbind(occ.num,occ.den) ~ cr.pres.abs, te.cr, family=quasibinomial)
intrxn.mod.tecr3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + cr.pres.abs, te.cr, family=quasibinomial)
intrxn.mod.tecr4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * cr.pres.abs, te.cr, family=quasibinomial)

summary(intrxn.mod.tecr1o)
summary(intrxn.mod.tecr2o)
summary(intrxn.mod.tecr3o)
summary(intrxn.mod.tecr4o)

# does the presence of Crematogaster influence Temnothorax persistence?
intrxn.mod.tecr1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, te.cr, family=quasibinomial, na.action=na.omit)
intrxn.mod.tecr2s<-glm(cbind(stasis.num,stasis.den) ~ cr.pres.abs, te.cr, family=quasibinomial, na.action=na.omit)
intrxn.mod.tecr3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + cr.pres.abs, te.cr, family=quasibinomial, na.action=na.omit)
intrxn.mod.tecr4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * cr.pres.abs, te.cr, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.tecr1s)
summary(intrxn.mod.tecr2s)
summary(intrxn.mod.tecr3s)
summary(intrxn.mod.tecr4s)

# does the presence of Crematogaster influence Temnothorax persistence?
intrxn.mod.tecr1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, te.cr, family=quasibinomial, na.action=na.omit)
intrxn.mod.tecr2p<-glm(cbind(per.num,per.den) ~ cr.pres.abs, te.cr, family=quasibinomial, na.action=na.omit)
intrxn.mod.tecr3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + cr.pres.abs, te.cr, family=quasibinomial, na.action=na.omit)
intrxn.mod.tecr4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * cr.pres.abs, te.cr, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.tecr1p)
summary(intrxn.mod.tecr2p)
summary(intrxn.mod.tecr3p)
summary(intrxn.mod.tecr4p)

cr.on.te<-
signif(rbind(
summary(intrxn.mod.tecr1c)$coefficients,
summary(intrxn.mod.tecr2c)$coefficients,
summary(intrxn.mod.tecr3c)$coefficients,
summary(intrxn.mod.tecr4c)$coefficients,
summary(intrxn.mod.tecr1e)$coefficients,
summary(intrxn.mod.tecr2e)$coefficients,
summary(intrxn.mod.tecr3e)$coefficients,
summary(intrxn.mod.tecr4e)$coefficients,
summary(intrxn.mod.tecr1o)$coefficients,
summary(intrxn.mod.tecr2o)$coefficients,
summary(intrxn.mod.tecr3o)$coefficients,
summary(intrxn.mod.tecr4o)$coefficients,
summary(intrxn.mod.tecr1s)$coefficients,
summary(intrxn.mod.tecr2s)$coefficients,
summary(intrxn.mod.tecr3s)$coefficients,
summary(intrxn.mod.tecr4s)$coefficients,
summary(intrxn.mod.tecr1p)$coefficients,
summary(intrxn.mod.tecr2p)$coefficients,
summary(intrxn.mod.tecr3p)$coefficients,
summary(intrxn.mod.tecr4p)$coefficients
), digits=3)


write.csv(cr.on.te, "cr.on.te.csv")

################################################################################
# te on cr #####################################################################
################################################################################

te$te.pres.abs<-recode(te$occ.num, "lo:0=0;1:hi=1")

te.s<-te[,c("te.pres.abs","ch","Nest")]

cr.te<-merge(te.s,cr,all=T)

# does the presence of Temnothorax influence Crematogaster colonization?
intrxn.mod.crte1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, cr.te, family=quasibinomial)
intrxn.mod.crte2c<-glm(cbind(col.num,col.den) ~ te.pres.abs, cr.te, family=quasibinomial)
intrxn.mod.crte3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + te.pres.abs, cr.te, family=quasibinomial)
intrxn.mod.crte4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * te.pres.abs, cr.te, family=quasibinomial)

summary(intrxn.mod.crte1c)
summary(intrxn.mod.crte2c)
summary(intrxn.mod.crte3c)
summary(intrxn.mod.crte4c)

# does the presence of Temnothorax influence Crematogaster extinction?
intrxn.mod.crte1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, cr.te, family=quasibinomial)
intrxn.mod.crte2e<-glm(cbind(ext.num,ext.den) ~ te.pres.abs, cr.te, family=quasibinomial)
intrxn.mod.crte3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + te.pres.abs, cr.te, family=quasibinomial)
intrxn.mod.crte4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * te.pres.abs, cr.te, family=quasibinomial)

summary(intrxn.mod.crte1e)
summary(intrxn.mod.crte2e)
summary(intrxn.mod.crte3e)
summary(intrxn.mod.crte4e)

# does the presence of Temnothorax influence Crematogaster occupancy?
intrxn.mod.crte1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, cr.te, family=quasibinomial)
intrxn.mod.crte2o<-glm(cbind(occ.num,occ.den) ~ te.pres.abs, cr.te, family=quasibinomial)
intrxn.mod.crte3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + te.pres.abs, cr.te, family=quasibinomial)
intrxn.mod.crte4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * te.pres.abs, cr.te, family=quasibinomial)

summary(intrxn.mod.crte1o)
summary(intrxn.mod.crte2o)
summary(intrxn.mod.crte3o)
summary(intrxn.mod.crte4o)

# does the presence of Temnothorax influence Crematogaster persistence?
intrxn.mod.crte1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, cr.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.crte2s<-glm(cbind(stasis.num,stasis.den) ~ te.pres.abs, cr.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.crte3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + te.pres.abs, cr.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.crte4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * te.pres.abs, cr.te, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.crte1s)
summary(intrxn.mod.crte2s)
summary(intrxn.mod.crte3s)
summary(intrxn.mod.crte4s)

# does the presence of Temnothorax influence Crematogaster persistence?
intrxn.mod.crte1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, cr.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.crte2p<-glm(cbind(per.num,per.den) ~ te.pres.abs, cr.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.crte3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + te.pres.abs, cr.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.crte4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * te.pres.abs, cr.te, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.crte1p)
summary(intrxn.mod.crte2p)
summary(intrxn.mod.crte3p)
summary(intrxn.mod.crte4p)

te.on.cr<-
signif(rbind(
summary(intrxn.mod.crte1c)$coefficients,
summary(intrxn.mod.crte2c)$coefficients,
summary(intrxn.mod.crte3c)$coefficients,
summary(intrxn.mod.crte4c)$coefficients,
summary(intrxn.mod.crte1e)$coefficients,
summary(intrxn.mod.crte2e)$coefficients,
summary(intrxn.mod.crte3e)$coefficients,
summary(intrxn.mod.crte4e)$coefficients,
summary(intrxn.mod.crte1o)$coefficients,
summary(intrxn.mod.crte2o)$coefficients,
summary(intrxn.mod.crte3o)$coefficients,
summary(intrxn.mod.crte4o)$coefficients,
summary(intrxn.mod.crte1s)$coefficients,
summary(intrxn.mod.crte2s)$coefficients,
summary(intrxn.mod.crte3s)$coefficients,
summary(intrxn.mod.crte4s)$coefficients,
summary(intrxn.mod.crte1p)$coefficients,
summary(intrxn.mod.crte2p)$coefficients,
summary(intrxn.mod.crte3p)$coefficients,
summary(intrxn.mod.crte4p)$coefficients
), digits=3)


write.csv(te.on.cr, "te.on.cr.csv")

################################################################################
# ap on te #####################################################################
################################################################################

ap$ap.pres.abs<-recode(ap$occ.num, "lo:0=0;1:hi=1")

ap.s<-ap[,c("ap.pres.abs","ch","Nest")]

te.ap<-merge(ap.s,te,all=T)


# does the presence of Aphaenogaster influence Temnothorax colonization?
intrxn.mod.teap1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, te.ap, family=quasibinomial)
intrxn.mod.teap2c<-glm(cbind(col.num,col.den) ~ ap.pres.abs, te.ap, family=quasibinomial)
intrxn.mod.teap3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + ap.pres.abs, te.ap, family=quasibinomial)
intrxn.mod.teap4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * ap.pres.abs, te.ap, family=quasibinomial)

summary(intrxn.mod.teap1c)
summary(intrxn.mod.teap2c)
summary(intrxn.mod.teap3c)
summary(intrxn.mod.teap4c)

# does the presence of Aphaenogaster influence Temnothorax extinction?
intrxn.mod.teap1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, te.ap, family=quasibinomial)
intrxn.mod.teap2e<-glm(cbind(ext.num,ext.den) ~ ap.pres.abs, te.ap, family=quasibinomial)
intrxn.mod.teap3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + ap.pres.abs, te.ap, family=quasibinomial)
intrxn.mod.teap4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * ap.pres.abs, te.ap, family=quasibinomial)

summary(intrxn.mod.teap1e)
summary(intrxn.mod.teap2e)
summary(intrxn.mod.teap3e)
summary(intrxn.mod.teap4e)

# does the presence of Aphaenogaster influence Temnothorax occupancy?
intrxn.mod.teap1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, te.ap, family=quasibinomial)
intrxn.mod.teap2o<-glm(cbind(occ.num,occ.den) ~ ap.pres.abs, te.ap, family=quasibinomial)
intrxn.mod.teap3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + ap.pres.abs, te.ap, family=quasibinomial)
intrxn.mod.teap4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * ap.pres.abs, te.ap, family=quasibinomial)

summary(intrxn.mod.teap1o)
summary(intrxn.mod.teap2o)
summary(intrxn.mod.teap3o)
summary(intrxn.mod.teap4o)

# does the presence of Aphaenogaster influence Temnothorax persistence?
intrxn.mod.teap1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, te.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.teap2s<-glm(cbind(stasis.num,stasis.den) ~ ap.pres.abs, te.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.teap3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + ap.pres.abs, te.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.teap4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * ap.pres.abs, te.ap, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.teap1s)
summary(intrxn.mod.teap2s)
summary(intrxn.mod.teap3s)
summary(intrxn.mod.teap4s)

# does the presence of Aphaenogaster influence Temnothorax persistence?
intrxn.mod.teap1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, te.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.teap2p<-glm(cbind(per.num,per.den) ~ ap.pres.abs, te.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.teap3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + ap.pres.abs, te.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.teap4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * ap.pres.abs, te.ap, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.teap1p)
summary(intrxn.mod.teap2p)
summary(intrxn.mod.teap3p)
summary(intrxn.mod.teap4p)

ap.on.te<-
signif(rbind(
summary(intrxn.mod.teap1c)$coefficients,
summary(intrxn.mod.teap2c)$coefficients,
summary(intrxn.mod.teap3c)$coefficients,
summary(intrxn.mod.teap4c)$coefficients,
summary(intrxn.mod.teap1e)$coefficients,
summary(intrxn.mod.teap2e)$coefficients,
summary(intrxn.mod.teap3e)$coefficients,
summary(intrxn.mod.teap4e)$coefficients,
summary(intrxn.mod.teap1o)$coefficients,
summary(intrxn.mod.teap2o)$coefficients,
summary(intrxn.mod.teap3o)$coefficients,
summary(intrxn.mod.teap4o)$coefficients,
summary(intrxn.mod.teap1s)$coefficients,
summary(intrxn.mod.teap2s)$coefficients,
summary(intrxn.mod.teap3s)$coefficients,
summary(intrxn.mod.teap4s)$coefficients,
summary(intrxn.mod.teap1p)$coefficients,
summary(intrxn.mod.teap2p)$coefficients,
summary(intrxn.mod.teap3p)$coefficients,
summary(intrxn.mod.teap4p)$coefficients
), digits=3)


write.csv(ap.on.te, "ap.on.te.csv")

################################################################################
# te on ap #####################################################################
################################################################################

te$te.pres.abs<-recode(te$occ.num, "lo:0=0;1:hi=1")

te.s<-te[,c("te.pres.abs","ch","Nest")]

ap.te<-merge(te.s,ap,all=T)

# does the presence of Temnothorax influence Aphaenogaster colonization?
intrxn.mod.apte1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, ap.te, family=quasibinomial)
intrxn.mod.apte2c<-glm(cbind(col.num,col.den) ~ te.pres.abs, ap.te, family=quasibinomial)
intrxn.mod.apte3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + te.pres.abs, ap.te, family=quasibinomial)
intrxn.mod.apte4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * te.pres.abs, ap.te, family=quasibinomial)

summary(intrxn.mod.apte1c)
summary(intrxn.mod.apte2c)
summary(intrxn.mod.apte3c)
summary(intrxn.mod.apte4c)

# does the presence of Temnothorax influence Aphaenogaster extinction?
intrxn.mod.apte1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, ap.te, family=quasibinomial)
intrxn.mod.apte2e<-glm(cbind(ext.num,ext.den) ~ te.pres.abs, ap.te, family=quasibinomial)
intrxn.mod.apte3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + te.pres.abs, ap.te, family=quasibinomial)
intrxn.mod.apte4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * te.pres.abs, ap.te, family=quasibinomial)

summary(intrxn.mod.apte1e)
summary(intrxn.mod.apte2e)
summary(intrxn.mod.apte3e)
summary(intrxn.mod.apte4e)

# does the presence of Temnothorax influence Aphaenogaster occupancy?
intrxn.mod.apte1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, ap.te, family=quasibinomial)
intrxn.mod.apte2o<-glm(cbind(occ.num,occ.den) ~ te.pres.abs, ap.te, family=quasibinomial)
intrxn.mod.apte3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + te.pres.abs, ap.te, family=quasibinomial)
intrxn.mod.apte4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * te.pres.abs, ap.te, family=quasibinomial)

summary(intrxn.mod.apte1o)
summary(intrxn.mod.apte2o)
summary(intrxn.mod.apte3o)
summary(intrxn.mod.apte4o)

# does the presence of Temnothorax influence Aphaenogaster persistence?
intrxn.mod.apte1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, ap.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.apte2s<-glm(cbind(stasis.num,stasis.den) ~ te.pres.abs, ap.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.apte3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + te.pres.abs, ap.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.apte4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * te.pres.abs, ap.te, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.apte1s)
summary(intrxn.mod.apte2s)
summary(intrxn.mod.apte3s)
summary(intrxn.mod.apte4s)

# does the presence of Temnothorax influence Aphaenogaster persistence?
intrxn.mod.apte1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, ap.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.apte2p<-glm(cbind(per.num,per.den) ~ te.pres.abs, ap.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.apte3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + te.pres.abs, ap.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.apte4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * te.pres.abs, ap.te, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.apte1p)
summary(intrxn.mod.apte2p)
summary(intrxn.mod.apte3p)
summary(intrxn.mod.apte4p)

te.on.ap<-
signif(rbind(
summary(intrxn.mod.apte1c)$coefficients,
summary(intrxn.mod.apte2c)$coefficients,
summary(intrxn.mod.apte3c)$coefficients,
summary(intrxn.mod.apte4c)$coefficients,
summary(intrxn.mod.apte1e)$coefficients,
summary(intrxn.mod.apte2e)$coefficients,
summary(intrxn.mod.apte3e)$coefficients,
summary(intrxn.mod.apte4e)$coefficients,
summary(intrxn.mod.apte1o)$coefficients,
summary(intrxn.mod.apte2o)$coefficients,
summary(intrxn.mod.apte3o)$coefficients,
summary(intrxn.mod.apte4o)$coefficients,
summary(intrxn.mod.apte1s)$coefficients,
summary(intrxn.mod.apte2s)$coefficients,
summary(intrxn.mod.apte3s)$coefficients,
summary(intrxn.mod.apte4s)$coefficients,
summary(intrxn.mod.apte1p)$coefficients,
summary(intrxn.mod.apte2p)$coefficients,
summary(intrxn.mod.apte3p)$coefficients,
summary(intrxn.mod.apte4p)$coefficients
), digits=3)


write.csv(te.on.ap, "te.on.ap.csv")

################################################################################
# br on ap #####################################################################
################################################################################

bp$bp.pres.abs<-recode(bp$occ.num, "lo:0=0;1:hi=1")

bp.s<-bp[,c("bp.pres.abs","ch","Nest")]

ap.bp<-merge(bp.s,ap,all=T)


# does the presence of Brachyponera influence Aphaenogaster colonization?
intrxn.mod.apbp1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, ap.bp, family=quasibinomial)
intrxn.mod.apbp2c<-glm(cbind(col.num,col.den) ~ bp.pres.abs, ap.bp, family=quasibinomial)
intrxn.mod.apbp3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + bp.pres.abs, ap.bp, family=quasibinomial)
intrxn.mod.apbp4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * bp.pres.abs, ap.bp, family=quasibinomial)

summary(intrxn.mod.apbp1c)
summary(intrxn.mod.apbp2c)
summary(intrxn.mod.apbp3c)
summary(intrxn.mod.apbp4c)

# does the presence of Brachyponera influence Aphaenogaster extinction?
intrxn.mod.apbp1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, ap.bp, family=quasibinomial)
intrxn.mod.apbp2e<-glm(cbind(ext.num,ext.den) ~ bp.pres.abs, ap.bp, family=quasibinomial)
intrxn.mod.apbp3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + bp.pres.abs, ap.bp, family=quasibinomial)
intrxn.mod.apbp4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * bp.pres.abs, ap.bp, family=quasibinomial)

summary(intrxn.mod.apbp1e)
summary(intrxn.mod.apbp2e)
summary(intrxn.mod.apbp3e)
summary(intrxn.mod.apbp4e)

# does the presence of Brachyponera influence Aphaenogaster occupancy?
intrxn.mod.apbp1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, ap.bp, family=quasibinomial)
intrxn.mod.apbp2o<-glm(cbind(occ.num,occ.den) ~ bp.pres.abs, ap.bp, family=quasibinomial)
intrxn.mod.apbp3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + bp.pres.abs, ap.bp, family=quasibinomial)
intrxn.mod.apbp4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * bp.pres.abs, ap.bp, family=quasibinomial)

summary(intrxn.mod.apbp1o)
summary(intrxn.mod.apbp2o)
summary(intrxn.mod.apbp3o)
summary(intrxn.mod.apbp4o)

# does the presence of Brachyponera influence Aphaenogaster persistence?
intrxn.mod.apbp1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, ap.bp, family=quasibinomial, na.action=na.omit)
intrxn.mod.apbp2s<-glm(cbind(stasis.num,stasis.den) ~ bp.pres.abs, ap.bp, family=quasibinomial, na.action=na.omit)
intrxn.mod.apbp3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + bp.pres.abs, ap.bp, family=quasibinomial, na.action=na.omit)
intrxn.mod.apbp4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * bp.pres.abs, ap.bp, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.apbp1s)
summary(intrxn.mod.apbp2s)
summary(intrxn.mod.apbp3s)
summary(intrxn.mod.apbp4s)

# does the presence of Brachyponera influence Aphaenogaster persistence?
intrxn.mod.apbp1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, ap.bp, family=quasibinomial, na.action=na.omit)
intrxn.mod.apbp2p<-glm(cbind(per.num,per.den) ~ bp.pres.abs, ap.bp, family=quasibinomial, na.action=na.omit)
intrxn.mod.apbp3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + bp.pres.abs, ap.bp, family=quasibinomial, na.action=na.omit)
intrxn.mod.apbp4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * bp.pres.abs, ap.bp, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.apbp1p)
summary(intrxn.mod.apbp2p)
summary(intrxn.mod.apbp3p)
summary(intrxn.mod.apbp4p)

bp.on.ap<-
signif(rbind(
summary(intrxn.mod.apbp1c)$coefficients,
summary(intrxn.mod.apbp2c)$coefficients,
summary(intrxn.mod.apbp3c)$coefficients,
summary(intrxn.mod.apbp4c)$coefficients,
summary(intrxn.mod.apbp1e)$coefficients,
summary(intrxn.mod.apbp2e)$coefficients,
summary(intrxn.mod.apbp3e)$coefficients,
summary(intrxn.mod.apbp4e)$coefficients,
summary(intrxn.mod.apbp1o)$coefficients,
summary(intrxn.mod.apbp2o)$coefficients,
summary(intrxn.mod.apbp3o)$coefficients,
summary(intrxn.mod.apbp4o)$coefficients,
summary(intrxn.mod.apbp1s)$coefficients,
summary(intrxn.mod.apbp2s)$coefficients,
summary(intrxn.mod.apbp3s)$coefficients,
summary(intrxn.mod.apbp4s)$coefficients,
summary(intrxn.mod.apbp1p)$coefficients,
summary(intrxn.mod.apbp2p)$coefficients,
summary(intrxn.mod.apbp3p)$coefficients,
summary(intrxn.mod.apbp4p)$coefficients), digits=3)


write.csv(bp.on.ap, "bp.on.ap.csv")

################################################################################
# br on cr #####################################################################
################################################################################

bp$bp.pres.abs<-(bp$occ.num/bp$occ.den)

bp.s<-bp[,c("bp.pres.abs","ch","Nest")]

cr.bp<-merge(bp.s,cr,all=T)

# does the presence of Brachyponera influence Crematogaster colonization?
intrxn.mod.crbp1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, cr.bp, family=quasibinomial)
intrxn.mod.crbp2c<-glm(cbind(col.num,col.den) ~ bp.pres.abs, cr.bp, family=quasibinomial)
intrxn.mod.crbp3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + bp.pres.abs, cr.bp, family=quasibinomial)
intrxn.mod.crbp4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * bp.pres.abs, cr.bp, family=quasibinomial)

summary(intrxn.mod.crbp1c)
summary(intrxn.mod.crbp2c)
summary(intrxn.mod.crbp3c)
summary(intrxn.mod.crbp4c)

# does the presence of Brachyponera influence Crematogaster extinction?
intrxn.mod.crbp1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, cr.bp, family=quasibinomial)
intrxn.mod.crbp2e<-glm(cbind(ext.num,ext.den) ~ bp.pres.abs, cr.bp, family=quasibinomial)
intrxn.mod.crbp3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + bp.pres.abs, cr.bp, family=quasibinomial)
intrxn.mod.crbp4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * bp.pres.abs, cr.bp, family=quasibinomial)

summary(intrxn.mod.crbp1e)
summary(intrxn.mod.crbp2e)
summary(intrxn.mod.crbp3e)
summary(intrxn.mod.crbp4e)

# does the presence of Brachyponera influence Crematogaster occupancy?
intrxn.mod.crbp1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, cr.bp, family=quasibinomial)
intrxn.mod.crbp2o<-glm(cbind(occ.num,occ.den) ~ bp.pres.abs, cr.bp, family=quasibinomial)
intrxn.mod.crbp3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + bp.pres.abs, cr.bp, family=quasibinomial)
intrxn.mod.crbp4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * bp.pres.abs, cr.bp, family=quasibinomial)

summary(intrxn.mod.crbp1o)
summary(intrxn.mod.crbp2o)
summary(intrxn.mod.crbp3o)
summary(intrxn.mod.crbp4o)

# does the presence of Brachyponera influence Crematogaster persistence?
intrxn.mod.crbp1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, cr.bp, family=quasibinomial, na.action=na.omit)
intrxn.mod.crbp2s<-glm(cbind(stasis.num,stasis.den) ~ bp.pres.abs, cr.bp, family=quasibinomial, na.action=na.omit)
intrxn.mod.crbp3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + bp.pres.abs, cr.bp, family=quasibinomial, na.action=na.omit)
intrxn.mod.crbp4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * bp.pres.abs, cr.bp, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.crbp1s)
summary(intrxn.mod.crbp2s)
summary(intrxn.mod.crbp3s)
summary(intrxn.mod.crbp4s)

# does the presence of Brachyponera influence Crematogaster persistence?
intrxn.mod.crbp1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, cr.bp, family=quasibinomial, na.action=na.omit)
intrxn.mod.crbp2p<-glm(cbind(per.num,per.den) ~ bp.pres.abs, cr.bp, family=quasibinomial, na.action=na.omit)
intrxn.mod.crbp3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + bp.pres.abs, cr.bp, family=quasibinomial, na.action=na.omit)
intrxn.mod.crbp4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * bp.pres.abs, cr.bp, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.crbp1p)
summary(intrxn.mod.crbp2p)
summary(intrxn.mod.crbp3p)
summary(intrxn.mod.crbp4p)

bp.on.cr<-
signif(rbind(
summary(intrxn.mod.crbp1c)$coefficients,
summary(intrxn.mod.crbp2c)$coefficients,
summary(intrxn.mod.crbp3c)$coefficients,
summary(intrxn.mod.crbp4c)$coefficients,
summary(intrxn.mod.crbp1e)$coefficients,
summary(intrxn.mod.crbp2e)$coefficients,
summary(intrxn.mod.crbp3e)$coefficients,
summary(intrxn.mod.crbp4e)$coefficients,
summary(intrxn.mod.crbp1o)$coefficients,
summary(intrxn.mod.crbp2o)$coefficients,
summary(intrxn.mod.crbp3o)$coefficients,
summary(intrxn.mod.crbp4o)$coefficients,
summary(intrxn.mod.crbp1s)$coefficients,
summary(intrxn.mod.crbp2s)$coefficients,
summary(intrxn.mod.crbp3s)$coefficients,
summary(intrxn.mod.crbp4s)$coefficients,
summary(intrxn.mod.crbp1p)$coefficients,
summary(intrxn.mod.crbp2p)$coefficients,
summary(intrxn.mod.crbp3p)$coefficients,
summary(intrxn.mod.crbp4p)$coefficients
), digits=3)


write.csv(bp.on.cr, "bp.on.cr.csv")

################################################################################
# br on te #####################################################################
################################################################################

bp$bp.pres.abs<-recode(bp$occ.num, "lo:0=0;1:hi=1")

bp.s<-bp[,c("bp.pres.abs","ch","Nest")]

te.bp<-merge(bp.s,te,all=T)

# does the presence of Brachyponera influence Temnothorax colonization?
intrxn.mod.tebp1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, te.bp, family=quasibinomial)
intrxn.mod.tebp2c<-glm(cbind(col.num,col.den) ~ bp.pres.abs, te.bp, family=quasibinomial)
intrxn.mod.tebp3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + bp.pres.abs, te.bp, family=quasibinomial)
intrxn.mod.tebp4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * bp.pres.abs, te.bp, family=quasibinomial)

summary(intrxn.mod.tebp1c)
summary(intrxn.mod.tebp2c)
summary(intrxn.mod.tebp3c)
summary(intrxn.mod.tebp4c)

# does the presence of Brachyponera influence Temnothorax extinction?
intrxn.mod.tebp1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, te.bp, family=quasibinomial)
intrxn.mod.tebp2e<-glm(cbind(ext.num,ext.den) ~ bp.pres.abs, te.bp, family=quasibinomial)
intrxn.mod.tebp3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + bp.pres.abs, te.bp, family=quasibinomial)
intrxn.mod.tebp4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * bp.pres.abs, te.bp, family=quasibinomial)

summary(intrxn.mod.tebp1e)
summary(intrxn.mod.tebp2e)
summary(intrxn.mod.tebp3e)
summary(intrxn.mod.tebp4e)

# does the presence of Brachyponera influence Temnothorax occupancy?
intrxn.mod.tebp1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, te.bp, family=quasibinomial)
intrxn.mod.tebp2o<-glm(cbind(occ.num,occ.den) ~ bp.pres.abs, te.bp, family=quasibinomial)
intrxn.mod.tebp3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + bp.pres.abs, te.bp, family=quasibinomial)
intrxn.mod.tebp4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * bp.pres.abs, te.bp, family=quasibinomial)

summary(intrxn.mod.tebp1o)
summary(intrxn.mod.tebp2o)
summary(intrxn.mod.tebp3o)
summary(intrxn.mod.tebp4o)

# does the presence of Brachyponera influence Temnothorax persistence?
intrxn.mod.tebp1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, te.bp, family=quasibinomial, na.action=na.omit)
intrxn.mod.tebp2s<-glm(cbind(stasis.num,stasis.den) ~ bp.pres.abs, te.bp, family=quasibinomial, na.action=na.omit)
intrxn.mod.tebp3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + bp.pres.abs, te.bp, family=quasibinomial, na.action=na.omit)
intrxn.mod.tebp4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * bp.pres.abs, te.bp, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.tebp1s)
summary(intrxn.mod.tebp2s)
summary(intrxn.mod.tebp3s)
summary(intrxn.mod.tebp4s)

# does the presence of Brachyponera influence Temnothorax persistence?
intrxn.mod.tebp1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, te.bp, family=quasibinomial, na.action=na.omit)
intrxn.mod.tebp2p<-glm(cbind(per.num,per.den) ~ bp.pres.abs, te.bp, family=quasibinomial, na.action=na.omit)
intrxn.mod.tebp3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + bp.pres.abs, te.bp, family=quasibinomial, na.action=na.omit)
intrxn.mod.tebp4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * bp.pres.abs, te.bp, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.tebp1p)
summary(intrxn.mod.tebp2p)
summary(intrxn.mod.tebp3p)
summary(intrxn.mod.tebp4p)

bp.on.te<-
signif(rbind(
summary(intrxn.mod.tebp1c)$coefficients,
summary(intrxn.mod.tebp2c)$coefficients,
summary(intrxn.mod.tebp3c)$coefficients,
summary(intrxn.mod.tebp4c)$coefficients,
summary(intrxn.mod.tebp1e)$coefficients,
summary(intrxn.mod.tebp2e)$coefficients,
summary(intrxn.mod.tebp3e)$coefficients,
summary(intrxn.mod.tebp4e)$coefficients,
summary(intrxn.mod.tebp1o)$coefficients,
summary(intrxn.mod.tebp2o)$coefficients,
summary(intrxn.mod.tebp3o)$coefficients,
summary(intrxn.mod.tebp4o)$coefficients,
summary(intrxn.mod.tebp1s)$coefficients,
summary(intrxn.mod.tebp2s)$coefficients,
summary(intrxn.mod.tebp3s)$coefficients,
summary(intrxn.mod.tebp4s)$coefficients,
summary(intrxn.mod.tebp1p)$coefficients,
summary(intrxn.mod.tebp2p)$coefficients,
summary(intrxn.mod.tebp3p)$coefficients,
summary(intrxn.mod.tebp4p)$coefficients
), digits=3)


write.csv(bp.on.te, "bp.on.te.csv")

