dat1<-read.csv("HF_NestBox_responses_alldates_20150818.csv",header=T)

# recode the chamber IDs to target deltas
library(car)
dat1$Target_Delta<-recode(dat1$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

dat<-merge(dat1, temp_vals[,1:3], "ch")
dat<-dat[dat$ch != 5,]

# Species
my<-dat[dat$Sp=="Myrmica_sp",]
ap<-dat[dat$Sp=="Aphaenogaster_sp",]
te<-dat[dat$Sp=="Temnothorax_longispinosus",]
ca<-dat[dat$Sp=="Camponotus_sp",]
la<-dat[dat$Sp=="Lasius_alienus",]

################################################################################
# quasibinomial models - myrm ##################################################
################################################################################

my.col<-my[my$col.den > 0,]
my.ext<-my[my$ext.den > 0,]
my.occ<-my[my$occ.den > 0,]
my.stasis<-my[my$stasis.den > 0 & !is.na(my$stasis.den),]
my.per<-my[my$per.den > 0 & !is.na(my$per.den),]

mod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, my.col, family=quasibinomial)
mod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, my.ext, family=quasibinomial)
mod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, my.occ, family=quasibinomial)
mod.sta<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, my.stasis, family=quasibinomial)
mod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, my.per, family=quasibinomial)

anova(mod.col, test="Chi")
anova(mod.ext, test="Chi")
anova(mod.occ, test="Chi")
anova(mod.sta, test="Chi")
anova(mod.per, test="Chi")

my_table<-
rbind(
      cbind("occ", signif(summary(mod.occ)$coefficients[2,1],3), 
                   signif(summary(mod.occ)$coefficients[2,2],3), 
                   signif(anova(mod.occ, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.occ, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("ext", signif(summary(mod.ext)$coefficients[2,1],3), 
                   signif(summary(mod.ext)$coefficients[2,2],3), 
                   signif(anova(mod.ext, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.ext, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("col", signif(summary(mod.col)$coefficients[2,1],3), 
                   signif(summary(mod.col)$coefficients[2,2],3), 
                   signif(anova(mod.col, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.col, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("sta", signif(summary(mod.sta)$coefficients[2,1],3), 
                   signif(summary(mod.sta)$coefficients[2,2],3), 
                   signif(anova(mod.sta, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.sta, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("per", signif(summary(mod.per)$coefficients[2,1],3), 
                   signif(summary(mod.per)$coefficients[2,2],3), 
                   signif(anova(mod.per, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.per, test="Chi")$"Pr(>Chi)"[2],3))                   
                   )
                   
colnames(my_table)<-c("response","estimate","se","deviance","p")                    
write.csv(my_table, "Myr_sp_model_results.csv")

################################################################################
# quasibinomial models - aphe ##################################################
################################################################################

ap.col<-ap[ap$col.den > 0,]
ap.ext<-ap[ap$ext.den > 0,]
ap.occ<-ap[ap$occ.den > 0,]
ap.stasis<-ap[ap$stasis.den > 0 & !is.na(ap$stasis.den),]
ap.per<-ap[ap$per.den > 0 & !is.na(ap$per.den),]

mod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, ap.col, family=quasibinomial)
mod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, ap.ext, family=quasibinomial)
mod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, ap.occ, family=quasibinomial)
mod.sta<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, ap.stasis, family=quasibinomial)
mod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, ap.per, family=quasibinomial)

anova(mod.col, test="Chi")
anova(mod.ext, test="Chi")
anova(mod.occ, test="Chi")
anova(mod.sta, test="Chi")
anova(mod.per, test="Chi")

ap_table<-
rbind(
      cbind("occ", signif(summary(mod.occ)$coefficients[2,1],3), 
                   signif(summary(mod.occ)$coefficients[2,2],3), 
                   signif(anova(mod.occ, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.occ, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("ext", signif(summary(mod.ext)$coefficients[2,1],3), 
                   signif(summary(mod.ext)$coefficients[2,2],3), 
                   signif(anova(mod.ext, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.ext, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("col", signif(summary(mod.col)$coefficients[2,1],3), 
                   signif(summary(mod.col)$coefficients[2,2],3), 
                   signif(anova(mod.col, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.col, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("sta", signif(summary(mod.sta)$coefficients[2,1],3), 
                   signif(summary(mod.sta)$coefficients[2,2],3), 
                   signif(anova(mod.sta, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.sta, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("per", signif(summary(mod.per)$coefficients[2,1],3), 
                   signif(summary(mod.per)$coefficients[2,2],3), 
                   signif(anova(mod.per, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.per, test="Chi")$"Pr(>Chi)"[2],3))                   
                   )
                   
colnames(ap_table)<-c("response","estimate","se","deviance","p") 
write.csv(ap_table, "Aph_sp_model_results.csv")

################################################################################
# quasibinomial models - telo ##################################################
################################################################################

te.col<-te[te$col.den > 0,]
te.ext<-te[te$ext.den > 0,]
te.occ<-te[te$occ.den > 0,]
te.stasis<-te[te$stasis.den > 0 & !is.na(te$stasis.den),]
te.per<-te[te$per.den > 0 & !is.na(te$per.den),]

mod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, te.col, family=quasibinomial)
mod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, te.ext, family=quasibinomial)
mod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, te.occ, family=quasibinomial)
mod.sta<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, te.stasis, family=quasibinomial)
mod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, te.per, family=quasibinomial)

anova(mod.col, test="Chi")
anova(mod.ext, test="Chi")
anova(mod.occ, test="Chi")
anova(mod.sta, test="Chi")
anova(mod.per, test="Chi")

te_table<-
rbind(
      cbind("occ", signif(summary(mod.occ)$coefficients[2,1],3), 
                   signif(summary(mod.occ)$coefficients[2,2],3), 
                   signif(anova(mod.occ, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.occ, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("ext", signif(summary(mod.ext)$coefficients[2,1],3), 
                   signif(summary(mod.ext)$coefficients[2,2],3), 
                   signif(anova(mod.ext, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.ext, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("col", signif(summary(mod.col)$coefficients[2,1],3), 
                   signif(summary(mod.col)$coefficients[2,2],3), 
                   signif(anova(mod.col, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.col, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("sta", signif(summary(mod.sta)$coefficients[2,1],3), 
                   signif(summary(mod.sta)$coefficients[2,2],3), 
                   signif(anova(mod.sta, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.sta, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("per", signif(summary(mod.per)$coefficients[2,1],3), 
                   signif(summary(mod.per)$coefficients[2,2],3), 
                   signif(anova(mod.per, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.per, test="Chi")$"Pr(>Chi)"[2],3))                   
                   )
                   
colnames(te_table)<-c("response","estimate","se","deviance","p") 
write.csv(te_table, "Tem_lon_model_results.csv")

################################################################################
# quasibinomial models - camp ##################################################
################################################################################

ca.col<-ca[ca$col.den > 0,]
ca.ext<-ca[ca$ext.den > 0,]
ca.occ<-ca[ca$occ.den > 0,]
ca.stasis<-ca[ca$stasis.den > 0 & !is.na(ca$stasis.den),]
ca.per<-ca[ca$per.den > 0 & !is.na(ca$per.den),]

mod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, ca.col, family=quasibinomial)
mod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, ca.ext, family=quasibinomial)
mod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, ca.occ, family=quasibinomial)
mod.sta<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, ca.stasis, family=quasibinomial)
mod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, ca.per, family=quasibinomial)

anova(mod.col, test="Chi")
anova(mod.ext, test="Chi")
anova(mod.occ, test="Chi")
anova(mod.sta, test="Chi")
anova(mod.per, test="Chi")

ca_table<-
rbind(
      cbind("occ", signif(summary(mod.occ)$coefficients[2,1],3), 
                   signif(summary(mod.occ)$coefficients[2,2],3), 
                   signif(anova(mod.occ, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.occ, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("ext", signif(summary(mod.ext)$coefficients[2,1],3), 
                   signif(summary(mod.ext)$coefficients[2,2],3), 
                   signif(anova(mod.ext, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.ext, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("col", signif(summary(mod.col)$coefficients[2,1],3), 
                   signif(summary(mod.col)$coefficients[2,2],3), 
                   signif(anova(mod.col, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.col, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("sta", signif(summary(mod.sta)$coefficients[2,1],3), 
                   signif(summary(mod.sta)$coefficients[2,2],3), 
                   signif(anova(mod.sta, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.sta, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("per", signif(summary(mod.per)$coefficients[2,1],3), 
                   signif(summary(mod.per)$coefficients[2,2],3), 
                   signif(anova(mod.per, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.per, test="Chi")$"Pr(>Chi)"[2],3))
                   )
                   
colnames(ca_table)<-c("response","estimate","se","deviance","p") 
write.csv(ca_table, "Cam_sp_model_results.csv")

################################################################################
# quasibinomial models - laal ##################################################
################################################################################

la.col<-la[la$col.den > 0,]
la.ext<-la[la$ext.den > 0,]
la.occ<-la[la$occ.den > 0,]
la.stasis<-la[la$stasis.den > 0 & !is.na(la$stasis.den),]
la.per<-la[la$per.den > 0 & !is.na(la$per.den),]

mod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, la.col, family=quasibinomial)
mod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, la.ext, family=quasibinomial)
mod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, la.occ, family=quasibinomial)
mod.sta<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, la.stasis, family=quasibinomial)
mod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, la.per, family=quasibinomial)

anova(mod.col, test="Chi")
anova(mod.ext, test="Chi")
anova(mod.occ, test="Chi")
anova(mod.sta, test="Chi")
anova(mod.per, test="Chi")

la_table<-
rbind(
      cbind("occ", signif(summary(mod.occ)$coefficients[2,1],3), 
                   signif(summary(mod.occ)$coefficients[2,2],3), 
                   signif(anova(mod.occ, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.occ, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("ext", signif(summary(mod.ext)$coefficients[2,1],3), 
                   signif(summary(mod.ext)$coefficients[2,2],3), 
                   signif(anova(mod.ext, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.ext, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("col", signif(summary(mod.col)$coefficients[2,1],3), 
                   signif(summary(mod.col)$coefficients[2,2],3), 
                   signif(anova(mod.col, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.col, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("sta", signif(summary(mod.sta)$coefficients[2,1],3), 
                   signif(summary(mod.sta)$coefficients[2,2],3), 
                   signif(anova(mod.sta, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.sta, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("per", signif(summary(mod.per)$coefficients[2,1],3), 
                   signif(summary(mod.per)$coefficients[2,2],3), 
                   signif(anova(mod.per, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.per, test="Chi")$"Pr(>Chi)"[2],3))                   
                   )
                   
colnames(la_table)<-c("response","estimate","se","deviance","p") 
write.csv(la_table, "Las_ali_model_results.csv")


################################################################################

ap.occ<-ap[ap$occ.den > 0,]
ca.occ<-ca[ca$occ.den > 0,]
la.occ<-la[la$occ.den > 0,]
my.occ<-my[my$occ.den > 0,]
te.occ<-te[te$occ.den > 0,]

# Occupancy
tiff("HF_Occupancy.tiff", height=8, width=12, res=300, units="in")
par(mfrow=c(2,3), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2), mgp=c(3,.6,0))

hfmod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, ap.occ, family=quasibinomial)
plot(occ.num/occ.den ~ CAT_Avg, ap.occ, xlab="Chamber temperature (C)", ylab="Occupancy", type="n", ylim=c(0,0.25))

hf.occ.agg<-as.data.frame(aggregate(cbind(occ.num,occ.den) ~ ch, ap.occ, sum))
hf.occ.agg.ci<-binom.confint(hf.occ.agg$occ.num, hf.occ.agg$occ.den, methods="exact")
colnames(hf.occ.agg.ci)[2]<-"occ.num"
colnames(hf.occ.agg.ci)[3]<-"occ.den"

hf.sum<-merge(hf.occ.agg.ci, hf.occ.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$pchs<-recode(hf.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
points(mean ~ CAT_Avg, hf.sum2, col="darkolivegreen", pch=hf.sum2$pchs, cex=2.25)
lines(exp(predict(hfmod.occ, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Aphaenogaster"), " sp.")), cex=1.2)




hfmod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, ca.occ, family=quasibinomial)
plot(occ.num/occ.den ~ CAT_Avg, ca.occ, xlab="Chamber temperature (C)", ylab="Occupancy", type="n", ylim=c(0,0.25))

hf.occ.agg<-as.data.frame(aggregate(cbind(occ.num,occ.den) ~ ch, ca.occ, sum))
hf.occ.agg.ci<-binom.confint(hf.occ.agg$occ.num, hf.occ.agg$occ.den, methods="exact")
colnames(hf.occ.agg.ci)[2]<-"occ.num"
colnames(hf.occ.agg.ci)[3]<-"occ.den"

hf.sum<-merge(hf.occ.agg.ci, hf.occ.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$pchs<-recode(hf.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
points(mean ~ CAT_Avg, hf.sum2, col="darkolivegreen", pch=hf.sum2$pchs, cex=2.25)
lines(exp(predict(hfmod.occ, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Camponotus"), " sp.")), cex=1.2)




hfmod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, la.occ, family=quasibinomial)
plot(occ.num/occ.den ~ CAT_Avg, la.occ, xlab="Chamber temperature (C)", ylab="Occupancy", type="n", ylim=c(0,0.1))

hf.occ.agg<-as.data.frame(aggregate(cbind(occ.num,occ.den) ~ ch, la.occ, sum))
hf.occ.agg.ci<-binom.confint(hf.occ.agg$occ.num, hf.occ.agg$occ.den, methods="exact")
colnames(hf.occ.agg.ci)[2]<-"occ.num"
colnames(hf.occ.agg.ci)[3]<-"occ.den"

hf.sum<-merge(hf.occ.agg.ci, hf.occ.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$pchs<-recode(hf.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
points(mean ~ CAT_Avg, hf.sum2, col="darkolivegreen", pch=hf.sum2$pchs, cex=2.25)
lines(exp(predict(hfmod.occ, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Lasius"), " sp.")), cex=1.2)



hfmod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, my.occ, family=quasibinomial)
plot(occ.num/occ.den ~ CAT_Avg, my.occ, xlab="Chamber temperature (C)", ylab="Occupancy", type="n", ylim=c(0,0.3))

hf.occ.agg<-as.data.frame(aggregate(cbind(occ.num,occ.den) ~ ch, my.occ, sum))
hf.occ.agg.ci<-binom.confint(hf.occ.agg$occ.num, hf.occ.agg$occ.den, methods="exact")
colnames(hf.occ.agg.ci)[2]<-"occ.num"
colnames(hf.occ.agg.ci)[3]<-"occ.den"

hf.sum<-merge(hf.occ.agg.ci, hf.occ.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$pchs<-recode(hf.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
points(mean ~ CAT_Avg, hf.sum2, col="darkolivegreen", pch=hf.sum2$pchs, cex=2.25)
lines(exp(predict(hfmod.occ, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Myrmica"), " sp.")), cex=1.2)




hfmod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, te.occ, family=quasibinomial)
plot(occ.num/occ.den ~ CAT_Avg, te.occ, xlab="Chamber temperature (C)", ylab="Occupancy", type="n", ylim=c(0,0.15))

hf.occ.agg<-as.data.frame(aggregate(cbind(occ.num,occ.den) ~ ch, te.occ, sum))
hf.occ.agg.ci<-binom.confint(hf.occ.agg$occ.num, hf.occ.agg$occ.den, methods="exact")
colnames(hf.occ.agg.ci)[2]<-"occ.num"
colnames(hf.occ.agg.ci)[3]<-"occ.den"

hf.sum<-merge(hf.occ.agg.ci, hf.occ.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$pchs<-recode(hf.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
points(mean ~ CAT_Avg, hf.sum2, col="darkolivegreen", pch=hf.sum2$pchs, cex=2.25)
lines(exp(predict(hfmod.occ, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Temnothorax longispinosus"))), cex=1.2)


dev.off()





ap.col<-ap[ap$col.den > 0,]
ca.col<-ca[ca$col.den > 0,]
la.col<-la[la$col.den > 0,]
my.col<-my[my$col.den > 0,]
te.col<-te[te$col.den > 0,]

# Colonization
tiff("HF_Colonization.tiff", height=8, width=12, res=300, units="in")
par(mfrow=c(2,3), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2), mgp=c(3,.6,0))

hfmod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, ap.col, family=quasibinomial)
plot(col.num/col.den ~ CAT_Avg, ap.col, xlab="Chamber temperature (C)", ylab="Colonization", type="n", ylim=c(0,0.2))

hf.col.agg<-as.data.frame(aggregate(cbind(col.num,col.den) ~ ch, ap.col, sum))
hf.col.agg.ci<-binom.confint(hf.col.agg$col.num, hf.col.agg$col.den, methods="exact")
colnames(hf.col.agg.ci)[2]<-"col.num"
colnames(hf.col.agg.ci)[3]<-"col.den"

hf.sum<-merge(hf.col.agg.ci, hf.col.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$pchs<-recode(hf.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
points(mean ~ CAT_Avg, hf.sum2, col="darkolivegreen", pch=hf.sum2$pchs, cex=2.25)
lines(exp(predict(hfmod.col, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Aphaenogaster"), " sp.")), cex=1.2)




hfmod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, ca.col, family=quasibinomial)
plot(col.num/col.den ~ CAT_Avg, ca.col, xlab="Chamber temperature (C)", ylab="Colonization", type="n", ylim=c(0,0.1))

hf.col.agg<-as.data.frame(aggregate(cbind(col.num,col.den) ~ ch, ca.col, sum))
hf.col.agg.ci<-binom.confint(hf.col.agg$col.num, hf.col.agg$col.den, methods="exact")
colnames(hf.col.agg.ci)[2]<-"col.num"
colnames(hf.col.agg.ci)[3]<-"col.den"

hf.sum<-merge(hf.col.agg.ci, hf.col.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$pchs<-recode(hf.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
points(mean ~ CAT_Avg, hf.sum2, col="darkolivegreen", pch=hf.sum2$pchs, cex=2.25)
lines(exp(predict(hfmod.col, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Camponotus"), " sp.")), cex=1.2)




hfmod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, la.col, family=quasibinomial)
plot(col.num/col.den ~ CAT_Avg, la.col, xlab="Chamber temperature (C)", ylab="Colonization", type="n", ylim=c(0,0.1))

hf.col.agg<-as.data.frame(aggregate(cbind(col.num,col.den) ~ ch, la.col, sum))
hf.col.agg.ci<-binom.confint(hf.col.agg$col.num, hf.col.agg$col.den, methods="exact")
colnames(hf.col.agg.ci)[2]<-"col.num"
colnames(hf.col.agg.ci)[3]<-"col.den"

hf.sum<-merge(hf.col.agg.ci, hf.col.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$pchs<-recode(hf.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
points(mean ~ CAT_Avg, hf.sum2, col="darkolivegreen", pch=hf.sum2$pchs, cex=2.25)
lines(exp(predict(hfmod.col, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Lasius"), " sp.")), cex=1.2)



hfmod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, my.col, family=quasibinomial)
plot(col.num/col.den ~ CAT_Avg, my.col, xlab="Chamber temperature (C)", ylab="Colonization", type="n", ylim=c(0,0.25))

hf.col.agg<-as.data.frame(aggregate(cbind(col.num,col.den) ~ ch, my.col, sum))
hf.col.agg.ci<-binom.confint(hf.col.agg$col.num, hf.col.agg$col.den, methods="exact")
colnames(hf.col.agg.ci)[2]<-"col.num"
colnames(hf.col.agg.ci)[3]<-"col.den"

hf.sum<-merge(hf.col.agg.ci, hf.col.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$pchs<-recode(hf.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
points(mean ~ CAT_Avg, hf.sum2, col="darkolivegreen", pch=hf.sum2$pchs, cex=2.25)
lines(exp(predict(hfmod.col, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Myrmica"), " sp.")), cex=1.2)




hfmod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, te.col, family=quasibinomial)
plot(col.num/col.den ~ CAT_Avg, te.col, xlab="Chamber temperature (C)", ylab="Colonization", type="n", ylim=c(0,0.1))

hf.col.agg<-as.data.frame(aggregate(cbind(col.num,col.den) ~ ch, te.col, sum))
hf.col.agg.ci<-binom.confint(hf.col.agg$col.num, hf.col.agg$col.den, methods="exact")
colnames(hf.col.agg.ci)[2]<-"col.num"
colnames(hf.col.agg.ci)[3]<-"col.den"

hf.sum<-merge(hf.col.agg.ci, hf.col.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$pchs<-recode(hf.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
points(mean ~ CAT_Avg, hf.sum2, col="darkolivegreen", pch=hf.sum2$pchs, cex=2.25)
lines(exp(predict(hfmod.col, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Temnothorax longispinosus"))), cex=1.2)


dev.off()




ap.ext<-ap[ap$ext.den > 0,]
ca.ext<-ca[ca$ext.den > 0,]
la.ext<-la[la$ext.den > 0,]
my.ext<-my[my$ext.den > 0,]
te.ext<-te[te$ext.den > 0,]

# Extinction
tiff("HF_Extinction.tiff", height=8, width=12, res=300, units="in")
par(mfrow=c(2,3), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2), mgp=c(3,.6,0))

hfmod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, ap.ext, family=quasibinomial)
plot(ext.num/ext.den ~ CAT_Avg, ap.ext, xlab="Chamber temperature (C)", ylab="Extinction", type="n", ylim=c(0,1.15), xlim=c(8.810171, 14.014484))

hf.ext.agg<-as.data.frame(aggregate(cbind(ext.num,ext.den) ~ ch, ap.ext, sum))
hf.ext.agg.ci<-binom.confint(hf.ext.agg$ext.num, hf.ext.agg$ext.den, methods="exact")
colnames(hf.ext.agg.ci)[2]<-"ext.num"
colnames(hf.ext.agg.ci)[3]<-"ext.den"

hf.sum<-merge(hf.ext.agg.ci, hf.ext.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$pchs<-recode(hf.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
points(mean ~ CAT_Avg, hf.sum2, col="darkolivegreen", pch=hf.sum2$pchs, cex=2.25)
lines(exp(predict(hfmod.ext, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Aphaenogaster"), " sp.")), cex=1.2)




hfmod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, ca.ext, family=quasibinomial)
plot(ext.num/ext.den ~ CAT_Avg, ca.ext, xlab="Chamber temperature (C)", ylab="Extinction", type="n", ylim=c(0,1.15), xlim=c(8.810171, 14.014484))

hf.ext.agg<-as.data.frame(aggregate(cbind(ext.num,ext.den) ~ ch, ca.ext, sum))
hf.ext.agg.ci<-binom.confint(hf.ext.agg$ext.num, hf.ext.agg$ext.den, methods="exact")
colnames(hf.ext.agg.ci)[2]<-"ext.num"
colnames(hf.ext.agg.ci)[3]<-"ext.den"

hf.sum<-merge(hf.ext.agg.ci, hf.ext.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$pchs<-recode(hf.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
points(mean ~ CAT_Avg, hf.sum2, col="darkolivegreen", pch=hf.sum2$pchs, cex=2.25)
lines(exp(predict(hfmod.ext, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Camponotus"), " sp.")), cex=1.2)




hfmod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, la.ext, family=quasibinomial)
plot(ext.num/ext.den ~ CAT_Avg, la.ext, xlab="Chamber temperature (C)", ylab="Extinction", type="n", ylim=c(0,1.15), xlim=c(8.810171, 14.014484))

hf.ext.agg<-as.data.frame(aggregate(cbind(ext.num,ext.den) ~ ch, la.ext, sum))
hf.ext.agg.ci<-binom.confint(hf.ext.agg$ext.num, hf.ext.agg$ext.den, methods="exact")
colnames(hf.ext.agg.ci)[2]<-"ext.num"
colnames(hf.ext.agg.ci)[3]<-"ext.den"

hf.sum<-merge(hf.ext.agg.ci, hf.ext.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$pchs<-recode(hf.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
points(mean ~ CAT_Avg, hf.sum2, col="darkolivegreen", pch=hf.sum2$pchs, cex=2.25)
#lines(exp(predict(hfmod.ext, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Lasius"), " sp.")), cex=1.2)



hfmod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, my.ext, family=quasibinomial)
plot(ext.num/ext.den ~ CAT_Avg, my.ext, xlab="Chamber temperature (C)", ylab="Extinction", type="n", ylim=c(0,1), xlim=c(8.810171, 14.014484))

hf.ext.agg<-as.data.frame(aggregate(cbind(ext.num,ext.den) ~ ch, my.ext, sum))
hf.ext.agg.ci<-binom.confint(hf.ext.agg$ext.num, hf.ext.agg$ext.den, methods="exact")
colnames(hf.ext.agg.ci)[2]<-"ext.num"
colnames(hf.ext.agg.ci)[3]<-"ext.den"

hf.sum<-merge(hf.ext.agg.ci, hf.ext.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$pchs<-recode(hf.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
points(mean ~ CAT_Avg, hf.sum2, col="darkolivegreen", pch=hf.sum2$pchs, cex=2.25)
lines(exp(predict(hfmod.ext, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Myrmica"), " sp.")), cex=1.2)




hfmod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, te.ext, family=quasibinomial)
plot(ext.num/ext.den ~ CAT_Avg, te.ext, xlab="Chamber temperature (C)", ylab="Extinction", type="n", ylim=c(0,1.15), xlim=c(8.810171, 14.014484))

hf.ext.agg<-as.data.frame(aggregate(cbind(ext.num,ext.den) ~ ch, te.ext, sum))
hf.ext.agg.ci<-binom.confint(hf.ext.agg$ext.num, hf.ext.agg$ext.den, methods="exact")
colnames(hf.ext.agg.ci)[2]<-"ext.num"
colnames(hf.ext.agg.ci)[3]<-"ext.den"

hf.sum<-merge(hf.ext.agg.ci, hf.ext.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$pchs<-recode(hf.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
points(mean ~ CAT_Avg, hf.sum2, col="darkolivegreen", pch=hf.sum2$pchs, cex=2.25)
lines(exp(predict(hfmod.ext, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Temnothorax longispinosus"))), cex=1.2)


dev.off()




ap.per<-ap[ap$per.den > 0 & !is.na(ap$per.den),]
ca.per<-ca[ca$per.den > 0 & !is.na(ca$per.den),]
la.per<-la[la$per.den > 0 & !is.na(la$per.den),]
my.per<-my[my$per.den > 0 & !is.na(my$per.den),]
te.per<-te[te$per.den > 0 & !is.na(te$per.den),]

# Persistence
tiff("HF_Persistence.tiff", height=8, width=12, res=300, units="in")
par(mfrow=c(2,3), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2), mgp=c(3,.6,0))

hfmod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, ap.per, family=quasibinomial)
plot(per.num/per.den ~ CAT_Avg, ap.per, xlab="Chamber temperature (C)", ylab="Persistence", type="n", ylim=c(0,1.15), xlim=c(8.810171, 14.014484))

hf.per.agg<-as.data.frame(aggregate(cbind(per.num,per.den) ~ ch, ap.per, sum))
hf.per.agg.ci<-binom.confint(hf.per.agg$per.num, hf.per.agg$per.den, methods="exact")
colnames(hf.per.agg.ci)[2]<-"per.num"
colnames(hf.per.agg.ci)[3]<-"per.den"

hf.sum<-merge(hf.per.agg.ci, hf.per.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$pchs<-recode(hf.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
points(mean ~ CAT_Avg, hf.sum2, col="darkolivegreen", pch=hf.sum2$pchs, cex=2.25)
lines(exp(predict(hfmod.per, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Aphaenogaster"), " sp.")), cex=1.2)




hfmod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, ca.per, family=quasibinomial)
plot(per.num/per.den ~ CAT_Avg, ca.per, xlab="Chamber temperature (C)", ylab="Persistence", type="n", ylim=c(0,1.15), xlim=c(8.810171, 14.014484))

hf.per.agg<-as.data.frame(aggregate(cbind(per.num,per.den) ~ ch, ca.per, sum))
hf.per.agg.ci<-binom.confint(hf.per.agg$per.num, hf.per.agg$per.den, methods="exact")
colnames(hf.per.agg.ci)[2]<-"per.num"
colnames(hf.per.agg.ci)[3]<-"per.den"

hf.sum<-merge(hf.per.agg.ci, hf.per.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$pchs<-recode(hf.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
points(mean ~ CAT_Avg, hf.sum2, col="darkolivegreen", pch=hf.sum2$pchs, cex=2.25)
lines(exp(predict(hfmod.per, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Camponotus"), " sp.")), cex=1.2)




hfmod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, la.per, family=quasibinomial)
plot(per.num/per.den ~ CAT_Avg, la.per, xlab="Chamber temperature (C)", ylab="Persistence", type="n", ylim=c(0,1.15), xlim=c(8.810171, 14.014484))

hf.per.agg<-as.data.frame(aggregate(cbind(per.num,per.den) ~ ch, la.per, sum))
hf.per.agg.ci<-binom.confint(hf.per.agg$per.num, hf.per.agg$per.den, methods="exact")
colnames(hf.per.agg.ci)[2]<-"per.num"
colnames(hf.per.agg.ci)[3]<-"per.den"

hf.sum<-merge(hf.per.agg.ci, hf.per.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$pchs<-recode(hf.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
points(mean ~ CAT_Avg, hf.sum2, col="darkolivegreen", pch=hf.sum2$pchs, cex=2.25)
#lines(exp(predict(hfmod.per, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Lasius"), " sp.")), cex=1.2)



hfmod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, my.per, family=quasibinomial)
plot(per.num/per.den ~ CAT_Avg, my.per, xlab="Chamber temperature (C)", ylab="Persistence", type="n", ylim=c(0,1.15), xlim=c(8.810171, 14.014484))

hf.per.agg<-as.data.frame(aggregate(cbind(per.num,per.den) ~ ch, my.per, sum))
hf.per.agg.ci<-binom.confint(hf.per.agg$per.num, hf.per.agg$per.den, methods="exact")
colnames(hf.per.agg.ci)[2]<-"per.num"
colnames(hf.per.agg.ci)[3]<-"per.den"

hf.sum<-merge(hf.per.agg.ci, hf.per.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$pchs<-recode(hf.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
points(mean ~ CAT_Avg, hf.sum2, col="darkolivegreen", pch=hf.sum2$pchs, cex=2.25)
lines(exp(predict(hfmod.per, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Myrmica"), " sp.")), cex=1.2)




hfmod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, te.per, family=quasibinomial)
plot(per.num/per.den ~ CAT_Avg, te.per, xlab="Chamber temperature (C)", ylab="Persistence", type="n", ylim=c(0,1.15), xlim=c(8.810171, 14.014484))

hf.per.agg<-as.data.frame(aggregate(cbind(per.num,per.den) ~ ch, te.per, sum))
hf.per.agg.ci<-binom.confint(hf.per.agg$per.num, hf.per.agg$per.den, methods="exact")
colnames(hf.per.agg.ci)[2]<-"per.num"
colnames(hf.per.agg.ci)[3]<-"per.den"

hf.sum<-merge(hf.per.agg.ci, hf.per.agg, all=TRUE)

hf.sum$Target_Delta<-recode(hf.sum$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals1<-as.matrix(read.csv("HF_CAT_Avg.csv", header=TRUE))
temp_vals<-rbind(temp_vals1, cbind(c(13,14,15),c(13,14,15),rep(9.000468, times=3),rep(0, times=3)), deparse.level=0)
colnames(temp_vals)[2]<-"ch"

hf.sum2<-merge(hf.sum, temp_vals[,1:3], "ch")
hf.sum2$pchs<-recode(hf.sum2$ch, "lo:12=16; 13:hi=21")

segments(x0 = hf.sum2$CAT_Avg, x1 = hf.sum2$CAT_Avg, y0=hf.sum2$lower, y1=hf.sum2$upper, col="darkolivegreen")
points(mean ~ CAT_Avg, hf.sum2, col="darkolivegreen", pch=hf.sum2$pchs, cex=2.25)
lines(exp(predict(hfmod.per, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Temnothorax longispinosus"))), cex=1.2)


dev.off()



# Levins model

tiff("HF_Levins.tiff", height=8, width=12, res=300, units="in")
par(mfrow=c(2,3), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2), mgp=c(3,.6,0))
ap$pchs<-recode(ap$ch, "lo:12=16; 13:hi=21")
ap$p.occ.hat=(ap$col.num/ap$col.den)/((ap$col.num/ap$col.den)+(ap$ext.num/ap$ext.den)) 
plot(p.occ.hat ~ CAT_Avg, ap, xlab="Chamber temperature (C)", ylab="Estimated occupancy", type="n", ylim=c(0,0.4))
points(ap$p.occ.hat ~ ap$CAT_Avg, col="darkolivegreen", pch=ap$pchs, cex=2.25)
mod.occ.hat<-glm(p.occ.hat ~ CAT_Avg, ap, family=quasibinomial, na.action=na.omit)
lines(exp(predict(mod.occ.hat, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Aphaenogaster"), " sp.")), cex=1.2)

anova(mod.occ.hat, test="Chi")
summary(mod.occ.hat)

ca$pchs<-recode(ca$ch, "lo:12=16; 13:hi=21")
ca$p.occ.hat=(ca$col.num/ca$col.den)/((ca$col.num/ca$col.den)+(ca$ext.num/ca$ext.den)) 
plot(p.occ.hat ~ CAT_Avg, ca, xlab="Chamber temperature (C)", ylab="Estimated occupancy", type="n", ylim=c(0,1.15))
points(ca$p.occ.hat ~ ca$CAT_Avg, col="darkolivegreen", pch=ca$pchs, cex=2.25)
mod.occ.hat<-glm(p.occ.hat ~ CAT_Avg, ca, family=quasibinomial, na.action=na.omit)
lines(exp(predict(mod.occ.hat, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484, length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Camponotus"), " sp.")), cex=1.2)

anova(mod.occ.hat, test="Chi")
summary(mod.occ.hat)

la$pchs<-recode(la$ch, "lo:12=16; 13:hi=21")
la$p.occ.hat=(la$col.num/la$col.den)/((la$col.num/la$col.den)+(la$ext.num/la$ext.den)) 
plot(p.occ.hat ~ CAT_Avg, la, xlab="Chamber temperature (C)", ylab="Estimated occupancy", type="n", ylim=c(0,0.1))
points(la$p.occ.hat ~ la$CAT_Avg, col="darkolivegreen", pch=la$pchs, cex=2.25)
mod.occ.hat<-glm(p.occ.hat ~ CAT_Avg, la, family=quasibinomial, na.action=na.omit)
lines(exp(predict(mod.occ.hat, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Lasius"), " sp.")), cex=1.2)

anova(mod.occ.hat, test="Chi")
summary(mod.occ.hat)

my$pchs<-recode(my$ch, "lo:12=16; 13:hi=21")
my$p.occ.hat=(my$col.num/my$col.den)/((my$col.num/my$col.den)+(my$ext.num/my$ext.den)) 
plot(p.occ.hat ~ CAT_Avg, my, xlab="Chamber temperature (C)", ylab="Estimated occupancy", type="n", ylim=c(0,1.15))
points(my$p.occ.hat ~ my$CAT_Avg, col="darkolivegreen", pch=my$pchs, cex=2.25)
mod.occ.hat<-glm(p.occ.hat ~ CAT_Avg, my, family=quasibinomial, na.action=na.omit)
lines(exp(predict(mod.occ.hat, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Myrmica"), " sp.")), cex=1.2)

anova(mod.occ.hat, test="Chi")
summary(mod.occ.hat)

te$pchs<-recode(te$ch, "lo:12=16; 13:hi=21")
te$p.occ.hat=(te$col.num/te$col.den)/((te$col.num/te$col.den)+(te$ext.num/te$ext.den)) 
plot(p.occ.hat ~ CAT_Avg, te, xlab="Chamber temperature (C)", ylab="Estimated occupancy", type="n", ylim=c(0,1.15))
points(te$p.occ.hat ~ te$CAT_Avg, col="darkolivegreen", pch=te$pchs, cex=2.25)
mod.occ.hat<-glm(p.occ.hat ~ CAT_Avg, te, family=quasibinomial, na.action=na.omit)
lines(exp(predict(mod.occ.hat, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Temnothorax longispinosus"))), cex=1.2)

anova(mod.occ.hat, test="Chi")
summary(mod.occ.hat)

dev.off()



# Turnover

tiff("HF_Turnover.tiff", height=8, width=12, res=300, units="in")
par(mfrow=c(2,3), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2), mgp=c(3,.6,0))

ap0<-ap[ap$ext.den > 0 & ap$col.den > 0,]
ap0$p.turn<-((ap0$col.num/ap0$col.den)*(ap0$ext.num/ap0$ext.den))/((ap0$col.num/ap0$col.den)+(ap0$ext.num/ap0$ext.den))
ap0$pchs<-recode(ap0$ch, "lo:12=16; 13:hi=21")
plot(p.turn ~ CAT_Avg, ap0, xlab="Chamber temperature (C)", ylab="Turnover", col="darkolivegreen", pch=ap0$pchs, cex=2.25, ylim=c(0,.25), xlim=c(8.810171, 14.014484))
mod.p.turn<-glm(p.turn ~ CAT_Avg, ap0, family=quasibinomial)
lines(exp(predict(mod.p.turn, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Aphaenogaster"), " sp.")), cex=1.2)

anova(mod.p.turn, test="Chi")
summary(mod.p.turn)


ca0<-ca[ca$ext.den > 0 & ca$col.den > 0,]
ca0$p.turn<-((ca0$col.num/ca0$col.den)*(ca0$ext.num/ca0$ext.den))/((ca0$col.num/ca0$col.den)+(ca0$ext.num/ca0$ext.den))
ca0$pchs<-recode(ca0$ch, "lo:12=16; 13:hi=21")
plot(p.turn ~ CAT_Avg, ca0, xlab="Chamber temperature (C)", ylab="Turnover", col="darkolivegreen", pch=ca0$pchs, cex=2.25, ylim=c(0,.15), xlim=c(8.810171, 14.014484))
mod.p.turn<-glm(p.turn ~ CAT_Avg, ca0, family=quasibinomial)
lines(exp(predict(mod.p.turn, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Camponotus"), " sp.")), cex=1.2)

anova(mod.p.turn, test="Chi")
summary(mod.p.turn)


la0<-la[la$ext.den > 0 & la$col.den > 0,]
la0$p.turn<-((la0$col.num/la0$col.den)*(la0$ext.num/la0$ext.den))/((la0$col.num/la0$col.den)+(la0$ext.num/la0$ext.den))
la0$pchs<-recode(la0$ch, "lo:12=16; 13:hi=21")
plot(p.turn ~ CAT_Avg, la0, xlab="Chamber temperature (C)", ylab="Turnover", col="darkolivegreen", pch=la0$pchs, cex=2.25, ylim=c(0,.1), xlim=c(8.810171, 14.014484))
mod.p.turn<-glm(p.turn ~ CAT_Avg, la0, family=quasibinomial)
lines(exp(predict(mod.p.turn, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Lasius"), " sp.")), cex=1.2)

anova(mod.p.turn, test="Chi")
summary(mod.p.turn)


my0<-my[my$ext.den > 0 & my$col.den > 0,]
my0$p.turn<-((my0$col.num/my0$col.den)*(my0$ext.num/my0$ext.den))/((my0$col.num/my0$col.den)+(my0$ext.num/my0$ext.den))
my0$pchs<-recode(my0$ch, "lo:12=16; 13:hi=21")
plot(p.turn ~ CAT_Avg, my0, xlab="Chamber temperature (C)", ylab="Turnover", col="darkolivegreen", pch=my0$pchs, cex=2.25, ylim=c(0,.3), xlim=c(8.810171, 14.014484))
mod.p.turn<-glm(p.turn ~ CAT_Avg, my0, family=quasibinomial)
lines(exp(predict(mod.p.turn, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Myrmica"), " sp.")), cex=1.2)

anova(mod.p.turn, test="Chi")
summary(mod.p.turn)


te0<-te[te$ext.den > 0 & te$col.den > 0,]
te0$p.turn<-((te0$col.num/te0$col.den)*(te0$ext.num/te0$ext.den))/((te0$col.num/te0$col.den)+(te0$ext.num/te0$ext.den))
te0$pchs<-recode(te0$ch, "lo:12=16; 13:hi=21")
plot(p.turn ~ CAT_Avg, te0, xlab="Chamber temperature (C)", ylab="Turnover", col="darkolivegreen", pch=te0$pchs, cex=2.25, ylim=c(0,.15), xlim=c(8.810171, 14.014484))
mod.p.turn<-glm(p.turn ~ CAT_Avg, te0, family=quasibinomial)
lines(exp(predict(mod.p.turn, newdata=data.frame(CAT_Avg=seq(8.810171, 14.014484,length.out=1000)))) ~ seq(8.810171, 14.014484,length.out=1000), col="darkolivegreen", lwd=1.5, lty=2)
mtext(side=3, line=-2.5,  expression(paste(italic("Temnothorax longispinosus"))), cex=1.2)

anova(mod.p.turn, test="Chi")
summary(mod.p.turn)

dev.off()


################################################################################                   
# myrm plots ###################################################################
################################################################################                   

my.col<-my[my$col.den > 0,]
my.ext<-my[my$ext.den > 0,]
my.occ<-my[my$occ.den > 0,]
my.stasis<-my[my$stasis.den > 0 & !is.na(my$stasis.den),]
my.per<-my[my$per.den > 0 & !is.na(my$per.den),]

mod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, my.col, family=quasibinomial)
mod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, my.ext, family=quasibinomial)
mod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, my.occ, family=quasibinomial)
mod.sta<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, my.stasis, family=quasibinomial)
mod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, my.per, family=quasibinomial)



# plot the raw proportions for each nest box in each chamber
tiff("Nest_box_responses_actualT_Myr_sp_HF.tiff", height=10, width=10, res=300, units="in")
par(mfrow=c(2,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(occ.num/occ.den ~ CAT_Avg, my.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy")
lines(exp(predict(mod.occ, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(col.num/col.den ~ CAT_Avg, my.col, xlab="Chamber temperature (C)", ylab="Colonization")
lines(exp(predict(mod.col, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(ext.num/ext.den ~ CAT_Avg, my.ext, xlab="Chamber temperature (C)", ylab="Extinction")
lines(exp(predict(mod.ext, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(stasis.num/stasis.den ~ CAT_Avg, my.stasis, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.sta, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

dev.off()



# revised persistence
tiff("Nest_box_responses_actualT_Myr_sp_persistence.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(per.num/per.den ~ CAT_Avg, my.per, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.per, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)
dev.off()



# colonization-extinction predicted occupancy
tiff("Nest_box_responses_actualT_Myr_sp_occ_obs_exp.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))

plot(occ.num/occ.den ~ CAT_Avg, my.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy", ylim=c(0,1), col="blue", pch=16)
lines(exp(predict(mod.occ, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

#my$p.occ.hat=recode((my$col.num/my$col.den)/((my$col.num/my$col.den)+(my$ext.num/my$ext.den)), "NaN=0")  
my$p.occ.hat=(my$col.num/my$col.den)/((my$col.num/my$col.den)+(my$ext.num/my$ext.den)) 

points(my$p.occ.hat ~ my$CAT_Avg, col="red", pch=16)
mod.occ.hat<-glm(p.occ.hat ~ CAT_Avg, my, family=quasibinomial, na.action=na.omit)
lines(exp(predict(mod.occ.hat, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="red", lwd=2)

legend("topleft", c("GLM", "Col-Ext Model"), col=c("blue", "red"), lty=1, bty="n", lwd=2)

dev.off()



# MacArthur-Wilson model: turnover
my0<-my[my$ext.den > 0 & my$col.den > 0,]
my0$p.turn<-((my0$col.num/my0$col.den)*(my0$ext.num/my0$ext.den))/((my0$col.num/my0$col.den)+(my0$ext.num/my0$ext.den))

tiff("Nest_box_responses_actualT_Myr_sp_MW_turnover.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))

plot(p.turn ~ CAT_Avg, my0, xlab="Chamber temperature (C)", ylab="Turnover", ylim=c(0,.4), col="blue", pch=16)
mod.p.turn<-glm(p.turn ~ CAT_Avg, my0, family=quasibinomial)
lines(exp(predict(mod.p.turn, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

dev.off()



write.csv(summary(mod.occ.hat)$coefficients, "Myr_sp_col_ext_mod.csv")
write.csv(summary(mod.p.turn)$coefficients, "Myr_sp_turnover_mod.csv")


 
################################################################################
# aphe plots ###################################################################
################################################################################

ap.col<-ap[ap$col.den > 0,]
ap.ext<-ap[ap$ext.den > 0,]
ap.occ<-ap[ap$occ.den > 0,]
ap.stasis<-ap[ap$stasis.den > 0 & !is.na(ap$stasis.den),]
ap.per<-ap[ap$per.den > 0 & !is.na(ap$per.den),]

mod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, ap.col, family=quasibinomial)
mod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, ap.ext, family=quasibinomial)
mod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, ap.occ, family=quasibinomial)
mod.sta<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, ap.stasis, family=quasibinomial)
mod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, ap.per, family=quasibinomial)



# plot the raw proportions for each nest box in each chamber
tiff("Nest_box_responses_actualT_Aph_sp_HF.tiff", height=10, width=10, res=300, units="in")
par(mfrow=c(2,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(occ.num/occ.den ~ CAT_Avg, ap.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy")
lines(exp(predict(mod.occ, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(col.num/col.den ~ CAT_Avg, ap.col, xlab="Chamber temperature (C)", ylab="Colonization")
lines(exp(predict(mod.col, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(ext.num/ext.den ~ CAT_Avg, ap.ext, xlab="Chamber temperature (C)", ylab="Extinction")
lines(exp(predict(mod.ext, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(stasis.num/stasis.den ~ CAT_Avg, ap.stasis, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.sta, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)
dev.off()



# revised persistence
tiff("Nest_box_responses_actualT_Aph_sp_persistence.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(per.num/per.den ~ CAT_Avg, ap.per, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.per, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)
dev.off()



# colonization-extinction predicted occupancy
tiff("Nest_box_responses_actualT_Aph_sp_occ_obs_exp.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))

plot(occ.num/occ.den ~ CAT_Avg, ap.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy", ylim=c(0,1), col="blue", pch=16)
lines(exp(predict(mod.occ, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

ap$p.occ.hat=(ap$col.num/ap$col.den)/((ap$col.num/ap$col.den)+(ap$ext.num/ap$ext.den)) 

points(ap$p.occ.hat ~ ap$CAT_Avg, col="red", pch=16)
mod.occ.hat<-glm(p.occ.hat ~ CAT_Avg, ap, family=quasibinomial, na.action=na.omit)
lines(exp(predict(mod.occ.hat, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="red", lwd=2)

legend("topleft", c("GLM", "Col-Ext Model"), col=c("blue", "red"), lty=1, bty="n", lwd=2)

dev.off()



# MacArthur-Wilson model: turnover
ap0<-ap[ap$ext.den > 0 & ap$col.den > 0,]
ap0$p.turn<-((ap0$col.num/ap0$col.den)*(ap0$ext.num/ap0$ext.den))/((ap0$col.num/ap0$col.den)+(ap0$ext.num/ap0$ext.den))

tiff("Nest_box_responses_actualT_Aph_sp_MW_turnover.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))

plot(p.turn ~ CAT_Avg, ap0, xlab="Chamber temperature (C)", ylab="Turnover", ylim=c(0,.4), col="blue", pch=16)
mod.p.turn<-glm(p.turn ~ CAT_Avg, ap0, family=quasibinomial)
lines(exp(predict(mod.p.turn, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

dev.off()



write.csv(summary(mod.occ.hat)$coefficients, "Aph_sp_col_ext_mod.csv")
write.csv(summary(mod.p.turn)$coefficients, "Aph_sp_turnover_mod.csv")



################################################################################
# telo plots ###################################################################
################################################################################

te.col<-te[te$col.den > 0,]
te.ext<-te[te$ext.den > 0,]
te.occ<-te[te$occ.den > 0,]
te.stasis<-te[te$stasis.den > 0 & !is.na(te$stasis.den),]
te.per<-te[te$per.den > 0 & !is.na(te$per.den),]

mod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, te.col, family=quasibinomial)
mod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, te.ext, family=quasibinomial)
mod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, te.occ, family=quasibinomial)
mod.sta<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, te.stasis, family=quasibinomial)
mod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, te.per, family=quasibinomial)



# plot the raw proportions for each nest box in each chamber
tiff("Nest_box_responses_actualT_Tem_lon_HF.tiff", height=10, width=10, res=300, units="in")
par(mfrow=c(2,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(occ.num/occ.den ~ CAT_Avg, te.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy")
lines(exp(predict(mod.occ, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(col.num/col.den ~ CAT_Avg, te.col, xlab="Chamber temperature (C)", ylab="Colonization")
lines(exp(predict(mod.col, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(ext.num/ext.den ~ CAT_Avg, te.ext, xlab="Chamber temperature (C)", ylab="Extinction")
lines(exp(predict(mod.ext, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(stasis.num/stasis.den ~ CAT_Avg, te.stasis, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.sta, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)
dev.off()



# revised persistence
tiff("Nest_box_responses_actualT_Tem_lon_persistence.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(per.num/per.den ~ CAT_Avg, te.per, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.per, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)
dev.off()



# colonization-extinction predicted occupancy
tiff("Nest_box_responses_actualT_Tem_lon_occ_obs_exp.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))

plot(occ.num/occ.den ~ CAT_Avg, te.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy", ylim=c(0,1), col="blue", pch=16)
lines(exp(predict(mod.occ, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

te$p.occ.hat=(te$col.num/te$col.den)/((te$col.num/te$col.den)+(te$ext.num/te$ext.den)) 

points(te$p.occ.hat ~ te$CAT_Avg, col="red", pch=16)
mod.occ.hat<-glm(p.occ.hat ~ CAT_Avg, te, family=quasibinomial, na.action=na.omit)
lines(exp(predict(mod.occ.hat, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="red", lwd=2)

legend("topleft", c("GLM", "Col-Ext Model"), col=c("blue", "red"), lty=1, bty="n", lwd=2)

dev.off()



# MacArthur-Wilson model: turnover
te0<-te[te$ext.den > 0 & te$col.den > 0,]
te0$p.turn<-((te0$col.num/te0$col.den)*(te0$ext.num/te0$ext.den))/((te0$col.num/te0$col.den)+(te0$ext.num/te0$ext.den))

tiff("Nest_box_responses_actualT_Tem_lon_MW_turnover.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))

plot(p.turn ~ CAT_Avg, te0, xlab="Chamber temperature (C)", ylab="Turnover", ylim=c(0,.4), col="blue", pch=16)
mod.p.turn<-glm(p.turn ~ CAT_Avg, te0, family=quasibinomial)
lines(exp(predict(mod.p.turn, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

dev.off()



write.csv(summary(mod.occ.hat)$coefficients, "Tem_lon_col_ext_mod.csv")
write.csv(summary(mod.p.turn)$coefficients, "Tem_lon_turnover_mod.csv")



################################################################################
# camp plots ###################################################################
################################################################################

ca.col<-ca[ca$col.den > 0,]
ca.ext<-ca[ca$ext.den > 0,]
ca.occ<-ca[ca$occ.den > 0,]
ca.stasis<-ca[ca$stasis.den > 0 & !is.na(ca$stasis.den),]
ca.per<-ca[ca$per.den > 0 & !is.na(ca$per.den),]

mod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, ca.col, family=quasibinomial)
mod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, ca.ext, family=quasibinomial)
mod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, ca.occ, family=quasibinomial)
mod.sta<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, ca.stasis, family=quasibinomial)
mod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, ca.per, family=quasibinomial)



# plot the raw proportions for each nest box in each chamber
tiff("Nest_box_responses_actualT_Cam_sp_HF.tiff", height=10, width=10, res=300, units="in")
par(mfrow=c(2,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(occ.num/occ.den ~ CAT_Avg, ca.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy")
lines(exp(predict(mod.occ, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(col.num/col.den ~ CAT_Avg, ca.col, xlab="Chamber temperature (C)", ylab="Colonization")
lines(exp(predict(mod.col, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(ext.num/ext.den ~ CAT_Avg, ca.ext, xlab="Chamber temperature (C)", ylab="Extinction")
lines(exp(predict(mod.ext, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(stasis.num/stasis.den ~ CAT_Avg, ca.stasis, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.sta, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)
dev.off()



# revised persistence
tiff("Nest_box_responses_actualT_Cam_sp_persistence.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(per.num/per.den ~ CAT_Avg, ca.per, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.per, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)
dev.off()



# colonization-extinction predicted occupancy
tiff("Nest_box_responses_actualT_Cam_sp_occ_obs_exp.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))

plot(occ.num/occ.den ~ CAT_Avg, ca.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy", ylim=c(0,1), col="blue", pch=16)
lines(exp(predict(mod.occ, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

ca$p.occ.hat=(ca$col.num/ca$col.den)/((ca$col.num/ca$col.den)+(ca$ext.num/ca$ext.den)) 

points(ca$p.occ.hat ~ ca$CAT_Avg, col="red", pch=16)
mod.occ.hat<-glm(p.occ.hat ~ CAT_Avg, ca, family=quasibinomial, na.action=na.omit)
lines(exp(predict(mod.occ.hat, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="red", lwd=2)

legend("topleft", c("GLM", "Col-Ext Model"), col=c("blue", "red"), lty=1, bty="n", lwd=2)

dev.off()



# MacArthur-Wilson model: turnover
ca0<-ca[ca$ext.den > 0 & ca$col.den > 0,]
ca0$p.turn<-((ca0$col.num/ca0$col.den)*(ca0$ext.num/ca0$ext.den))/((ca0$col.num/ca0$col.den)+(ca0$ext.num/ca0$ext.den))

tiff("Nest_box_responses_actualT_Cam_sp_MW_turnover.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))

plot(p.turn ~ CAT_Avg, ca0, xlab="Chamber temperature (C)", ylab="Turnover", ylim=c(0,.4), col="blue", pch=16)
mod.p.turn<-glm(p.turn ~ CAT_Avg, ca0, family=quasibinomial)
lines(exp(predict(mod.p.turn, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

dev.off()



write.csv(summary(mod.occ.hat)$coefficients, "Cam_sp_col_ext_mod.csv")
write.csv(summary(mod.p.turn)$coefficients, "Cam_sp_turnover_mod.csv")



################################################################################
# laal plots ###################################################################
################################################################################

la.col<-la[la$col.den > 0,]
la.ext<-la[la$ext.den > 0,]
la.occ<-la[la$occ.den > 0,]
la.stasis<-la[la$stasis.den > 0 & !is.na(la$stasis.den),]
la.per<-la[la$per.den > 0 & !is.na(la$per.den),]

mod.col<-glm(cbind(col.num,col.den) ~ CAT_Avg, la.col, family=quasibinomial)
mod.ext<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, la.ext, family=quasibinomial)
mod.occ<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, la.occ, family=quasibinomial)
mod.sta<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, la.stasis, family=quasibinomial)
mod.per<-glm(cbind(per.num,per.den) ~ CAT_Avg, la.per, family=quasibinomial)



# plot the raw proportions for each nest box in each chamber
tiff("Nest_box_responses_actualT_Las_ali_HF.tiff", height=10, width=10, res=300, units="in")
par(mfrow=c(2,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(occ.num/occ.den ~ CAT_Avg, la.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy")
lines(exp(predict(mod.occ, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(col.num/col.den ~ CAT_Avg, la.col, xlab="Chamber temperature (C)", ylab="Colonization")
lines(exp(predict(mod.col, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(ext.num/ext.den ~ CAT_Avg, la.ext, xlab="Chamber temperature (C)", ylab="Extinction")
lines(exp(predict(mod.ext, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(stasis.num/stasis.den ~ CAT_Avg, la.stasis, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.sta, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)
dev.off()



# revised persistence
tiff("Nest_box_responses_actualT_Las_sp_persistence.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(per.num/per.den ~ CAT_Avg, la.per, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.per, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)
dev.off()



# colonization-extinction predicted occupancy
tiff("Nest_box_responses_actualT_Las_ali_occ_obs_exp.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))

plot(occ.num/occ.den ~ CAT_Avg, la.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy", ylim=c(0,1), col="blue", pch=16)
lines(exp(predict(mod.occ, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

la$p.occ.hat=(la$col.num/la$col.den)/((la$col.num/la$col.den)+(la$ext.num/la$ext.den)) 

points(la$p.occ.hat ~ la$CAT_Avg, col="red", pch=16)
mod.occ.hat<-glm(p.occ.hat ~ CAT_Avg, la, family=quasibinomial, na.action=na.omit)
lines(exp(predict(mod.occ.hat, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="red", lwd=2)

legend("topleft", c("GLM", "Col-Ext Model"), col=c("blue", "red"), lty=1, bty="n", lwd=2)

dev.off()



# MacArthur-Wilson model: turnover
la0<-la[la$ext.den > 0 & la$col.den > 0,]
la0$p.turn<-((la0$col.num/la0$col.den)*(la0$ext.num/la0$ext.den))/((la0$col.num/la0$col.den)+(la0$ext.num/la0$ext.den))

tiff("Nest_box_responses_actualT_Las_ali_MW_turnover.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))

plot(p.turn ~ CAT_Avg, ca0, xlab="Chamber temperature (C)", ylab="Turnover", ylim=c(0,.4), col="blue", pch=16)
mod.p.turn<-glm(p.turn ~ CAT_Avg, la0, family=quasibinomial)
lines(exp(predict(mod.p.turn, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

dev.off()



write.csv(summary(mod.occ.hat)$coefficients, "Las_sp_col_ext_mod.csv")
write.csv(summary(mod.p.turn)$coefficients, "Las_sp_turnover_mod.csv")



################################################################################
# Community responses ##########################################################
################################################################################

hfcomm1<-read.csv("Entire_HF_community.csv", header=TRUE)

# recode the chamber IDs to target deltas
library(car)
hfcomm1$Target_Delta<-recode(hfcomm1$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals<-read.csv("HF_CAT_Avg.csv", header=TRUE)
colnames(temp_vals)[2]<-"ch"

hfcomm<-merge(hfcomm1, temp_vals[,1:3], "ch")

hfcomm.col<-hfcomm[hfcomm$col.den > 0,]
hfcomm.ext<-hfcomm[hfcomm$ext.den > 0,]
hfcomm.occ<-hfcomm[hfcomm$occ.den > 0,]
hfcomm.stasis<-hfcomm[hfcomm$stasis.den > 0 & !is.na(hfcomm$stasis.den),]
hfcomm.per<-hfcomm[hfcomm$per.den > 0 & !is.na(hfcomm$per.den),]

mod.col<-glm(cbind(col.numr,col.denr) ~ CAT_Avg, hfcomm.col, family=quasibinomial)
mod.ext<-glm(cbind(ext.numr,ext.denr) ~ CAT_Avg, hfcomm.ext, family=quasibinomial)
mod.occ<-glm(cbind(occ.numr,occ.denr) ~ CAT_Avg, hfcomm.occ, family=quasibinomial)
mod.sta<-glm(cbind(stasis.numr,stasis.denr) ~ CAT_Avg, hfcomm.stasis, family=quasibinomial)
mod.per<-glm(cbind(per.numr,per.denr) ~ CAT_Avg, hfcomm.per, family=quasibinomial)

# plot the raw proportions for each nest box in each chamber
tiff("Nest_box_responses_all_HF_actualT.tiff", height=10, width=10, res=300, units="in")
par(mfrow=c(2,2), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(occ.numr/occ.denr ~ CAT_Avg, hfcomm.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy")
lines(exp(predict(mod.occ, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(col.numr/col.denr ~ CAT_Avg, hfcomm.col, xlab="Chamber temperature (C)", ylab="Colonization")
lines(exp(predict(mod.col, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(ext.numr/ext.denr ~ CAT_Avg, hfcomm.ext, xlab="Chamber temperature (C)", ylab="Extinction")
lines(exp(predict(mod.ext, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(stasis.numr/stasis.denr ~ CAT_Avg, hfcomm.stasis, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.sta, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)
dev.off()



# revised persistence
tiff("Nest_box_responses_actualT_all_HF_persistence.tiff", height=5, width=5, res=300, units="in")
par(mfrow=c(1,1), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(per.numr/per.denr ~ CAT_Avg, hfcomm.per, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.per, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)
dev.off()



allHF_table<-
rbind(
      cbind("occ", signif(summary(mod.occ)$coefficients[2,1],3), 
                   signif(summary(mod.occ)$coefficients[2,2],3), 
                   signif(anova(mod.occ, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.occ, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("ext", signif(summary(mod.ext)$coefficients[2,1],3), 
                   signif(summary(mod.ext)$coefficients[2,2],3), 
                   signif(anova(mod.ext, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.ext, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("col", signif(summary(mod.col)$coefficients[2,1],3), 
                   signif(summary(mod.col)$coefficients[2,2],3), 
                   signif(anova(mod.col, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.col, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("sta", signif(summary(mod.sta)$coefficients[2,1],3), 
                   signif(summary(mod.sta)$coefficients[2,2],3), 
                   signif(anova(mod.sta, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.sta, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("per", signif(summary(mod.per)$coefficients[2,1],3), 
                   signif(summary(mod.per)$coefficients[2,2],3), 
                   signif(anova(mod.per, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.per, test="Chi")$"Pr(>Chi)"[2],3))                   
                   )
                   
colnames(allHF_table)<-c("response","estimate","se","deviance","p")                    
write.csv(allHF_table, "AllHF_model_results.csv")

################################################################################
# Community responses - jackknife - minus aphe #################################
################################################################################

hfcomm.wo.aphe1<-read.csv("HF_community_minus_aphe.csv", header=TRUE)

# recode the chamber IDs to target deltas
library(car)
hfcomm.wo.aphe1$Target_Delta<-recode(hfcomm.wo.aphe1$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals<-read.csv("HF_CAT_Avg.csv", header=TRUE)
colnames(temp_vals)[2]<-"ch"

hfcomm.wo.aphe<-merge(hfcomm.wo.aphe1, temp_vals[,1:3], "ch")

hfcomm.wo.aphe.col<-hfcomm.wo.aphe[hfcomm.wo.aphe$col.den > 0,]
hfcomm.wo.aphe.ext<-hfcomm.wo.aphe[hfcomm.wo.aphe$ext.den > 0,]
hfcomm.wo.aphe.occ<-hfcomm.wo.aphe[hfcomm.wo.aphe$occ.den > 0,]
hfcomm.wo.aphe.stasis<-hfcomm.wo.aphe[hfcomm.wo.aphe$stasis.den > 0 & !is.na(hfcomm.wo.aphe$stasis.den),]
hfcomm.wo.aphe.per<-hfcomm.wo.aphe[hfcomm.wo.aphe$per.den > 0 & !is.na(hfcomm.wo.aphe$per.den),]

mod.wo.aphe.col<-glm(cbind(col.numr,col.denr) ~ CAT_Avg, hfcomm.wo.aphe.col, family=quasibinomial)
mod.wo.aphe.ext<-glm(cbind(ext.numr,ext.denr) ~ CAT_Avg, hfcomm.wo.aphe.ext, family=quasibinomial)
mod.wo.aphe.occ<-glm(cbind(occ.numr,occ.denr) ~ CAT_Avg, hfcomm.wo.aphe.occ, family=quasibinomial)
mod.wo.aphe.sta<-glm(cbind(stasis.numr,stasis.denr) ~ CAT_Avg, hfcomm.wo.aphe.stasis, family=quasibinomial)
mod.wo.aphe.per<-glm(cbind(per.numr,per.denr) ~ CAT_Avg, hfcomm.wo.aphe.per, family=quasibinomial)

# plot the raw proportions for each nest box in each chamber
tiff("Nest_box_responses_HF_minus_aphe_actualT.tiff", height=10, width=15, res=300, units="in")
par(mfrow=c(2,3), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(occ.numr/occ.denr ~ CAT_Avg, hfcomm.wo.aphe.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy")
lines(exp(predict(mod.wo.aphe.occ, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(col.numr/col.denr ~ CAT_Avg, hfcomm.wo.aphe.col, xlab="Chamber temperature (C)", ylab="Colonization")
lines(exp(predict(mod.wo.aphe.col, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(ext.numr/ext.denr ~ CAT_Avg, hfcomm.wo.aphe.ext, xlab="Chamber temperature (C)", ylab="Extinction")
lines(exp(predict(mod.wo.aphe.ext, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(stasis.numr/stasis.denr ~ CAT_Avg, hfcomm.wo.aphe.stasis, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.wo.aphe.sta, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(per.numr/per.denr ~ CAT_Avg, hfcomm.wo.aphe.per, xlab="Chamber temperature (C)", ylab="Revised persistence")
lines(exp(predict(mod.wo.aphe.per, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

dev.off()


HF_minus_aphe<-
rbind(
      cbind("occ", signif(summary(mod.wo.aphe.occ)$coefficients[2,1],3), 
                   signif(summary(mod.wo.aphe.occ)$coefficients[2,2],3), 
                   signif(anova(mod.wo.aphe.occ, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.aphe.occ, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("ext", signif(summary(mod.wo.aphe.ext)$coefficients[2,1],3), 
                   signif(summary(mod.wo.aphe.ext)$coefficients[2,2],3), 
                   signif(anova(mod.wo.aphe.ext, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.aphe.ext, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("col", signif(summary(mod.wo.aphe.col)$coefficients[2,1],3), 
                   signif(summary(mod.wo.aphe.col)$coefficients[2,2],3), 
                   signif(anova(mod.wo.aphe.col, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.aphe.col, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("sta", signif(summary(mod.wo.aphe.sta)$coefficients[2,1],3), 
                   signif(summary(mod.wo.aphe.sta)$coefficients[2,2],3), 
                   signif(anova(mod.wo.aphe.sta, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.aphe.sta, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("per", signif(summary(mod.wo.aphe.per)$coefficients[2,1],3), 
                   signif(summary(mod.wo.aphe.per)$coefficients[2,2],3), 
                   signif(anova(mod.wo.aphe.per, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.aphe.per, test="Chi")$"Pr(>Chi)"[2],3))
                   )
                   
colnames(HF_minus_aphe)<-c("response","estimate","se","deviance","p")                    
write.csv(HF_minus_aphe, "HF_minus_aphe_model_results.csv")

################################################################################
# Community responses - jackknife - minus camp #################################
################################################################################

hfcomm.wo.camp1<-read.csv("HF_community_minus_camp.csv", header=TRUE)

# recode the chamber IDs to target deltas
library(car)
hfcomm.wo.camp1$Target_Delta<-recode(hfcomm.wo.camp1$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals<-read.csv("HF_CAT_Avg.csv", header=TRUE)
colnames(temp_vals)[2]<-"ch"

hfcomm.wo.camp<-merge(hfcomm.wo.camp1, temp_vals[,1:3], "ch")

hfcomm.wo.camp.col<-hfcomm.wo.camp[hfcomm.wo.camp$col.den > 0,]
hfcomm.wo.camp.ext<-hfcomm.wo.camp[hfcomm.wo.camp$ext.den > 0,]
hfcomm.wo.camp.occ<-hfcomm.wo.camp[hfcomm.wo.camp$occ.den > 0,]
hfcomm.wo.camp.stasis<-hfcomm.wo.camp[hfcomm.wo.camp$stasis.den > 0 & !is.na(hfcomm.wo.camp$stasis.den),]
hfcomm.wo.camp.per<-hfcomm.wo.camp[hfcomm.wo.camp$per.den > 0 & !is.na(hfcomm.wo.camp$per.den),]

mod.wo.camp.col<-glm(cbind(col.numr,col.denr) ~ CAT_Avg, hfcomm.wo.camp.col, family=quasibinomial)
mod.wo.camp.ext<-glm(cbind(ext.numr,ext.denr) ~ CAT_Avg, hfcomm.wo.camp.ext, family=quasibinomial)
mod.wo.camp.occ<-glm(cbind(occ.numr,occ.denr) ~ CAT_Avg, hfcomm.wo.camp.occ, family=quasibinomial)
mod.wo.camp.sta<-glm(cbind(stasis.numr,stasis.denr) ~ CAT_Avg, hfcomm.wo.camp.stasis, family=quasibinomial)
mod.wo.camp.per<-glm(cbind(per.numr,per.denr) ~ CAT_Avg, hfcomm.wo.camp.per, family=quasibinomial)

# plot the raw proportions for each nest box in each chamber
tiff("Nest_box_responses_HF_minus_camp_actualT.tiff", height=10, width=15, res=300, units="in")
par(mfrow=c(2,3), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(occ.numr/occ.denr ~ CAT_Avg, hfcomm.wo.camp.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy")
lines(exp(predict(mod.wo.camp.occ, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(col.numr/col.denr ~ CAT_Avg, hfcomm.wo.camp.col, xlab="Chamber temperature (C)", ylab="Colonization")
lines(exp(predict(mod.wo.camp.col, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(ext.numr/ext.denr ~ CAT_Avg, hfcomm.wo.camp.ext, xlab="Chamber temperature (C)", ylab="Extinction")
lines(exp(predict(mod.wo.camp.ext, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(stasis.numr/stasis.denr ~ CAT_Avg, hfcomm.wo.camp.stasis, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.wo.camp.sta, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(per.numr/per.denr ~ CAT_Avg, hfcomm.wo.camp.per, xlab="Chamber temperature (C)", ylab="Revised persistence")
lines(exp(predict(mod.wo.camp.per, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

dev.off()



HF_minus_camp<-
rbind(
      cbind("occ", signif(summary(mod.wo.camp.occ)$coefficients[2,1],3), 
                   signif(summary(mod.wo.camp.occ)$coefficients[2,2],3), 
                   signif(anova(mod.wo.camp.occ, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.camp.occ, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("ext", signif(summary(mod.wo.camp.ext)$coefficients[2,1],3), 
                   signif(summary(mod.wo.camp.ext)$coefficients[2,2],3), 
                   signif(anova(mod.wo.camp.ext, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.camp.ext, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("col", signif(summary(mod.wo.camp.col)$coefficients[2,1],3), 
                   signif(summary(mod.wo.camp.col)$coefficients[2,2],3), 
                   signif(anova(mod.wo.camp.col, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.camp.col, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("sta", signif(summary(mod.wo.camp.sta)$coefficients[2,1],3), 
                   signif(summary(mod.wo.camp.sta)$coefficients[2,2],3), 
                   signif(anova(mod.wo.camp.sta, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.camp.sta, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("per", signif(summary(mod.wo.camp.per)$coefficients[2,1],3), 
                   signif(summary(mod.wo.camp.per)$coefficients[2,2],3), 
                   signif(anova(mod.wo.camp.per, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.camp.per, test="Chi")$"Pr(>Chi)"[2],3))
                   )
                   
colnames(HF_minus_camp)<-c("response","estimate","se","deviance","p")                    
write.csv(HF_minus_camp, "HF_minus_camp_model_results.csv")

################################################################################
# Community responses - jackknife - minus laal #################################
################################################################################

hfcomm.wo.laal1<-read.csv("HF_community_minus_laal.csv", header=TRUE)

# recode the chamber IDs to target deltas
library(car)
hfcomm.wo.laal1$Target_Delta<-recode(hfcomm.wo.laal1$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals<-read.csv("HF_CAT_Avg.csv", header=TRUE)
colnames(temp_vals)[2]<-"ch"

hfcomm.wo.laal<-merge(hfcomm.wo.laal1, temp_vals[,1:3], "ch")

hfcomm.wo.laal.col<-hfcomm.wo.laal[hfcomm.wo.laal$col.den > 0,]
hfcomm.wo.laal.ext<-hfcomm.wo.laal[hfcomm.wo.laal$ext.den > 0,]
hfcomm.wo.laal.occ<-hfcomm.wo.laal[hfcomm.wo.laal$occ.den > 0,]
hfcomm.wo.laal.stasis<-hfcomm.wo.laal[hfcomm.wo.laal$stasis.den > 0 & !is.na(hfcomm.wo.laal$stasis.den),]
hfcomm.wo.laal.per<-hfcomm.wo.laal[hfcomm.wo.laal$per.den > 0 & !is.na(hfcomm.wo.laal$per.den),]

mod.wo.laal.col<-glm(cbind(col.numr,col.denr) ~ CAT_Avg, hfcomm.wo.laal.col, family=quasibinomial)
mod.wo.laal.ext<-glm(cbind(ext.numr,ext.denr) ~ CAT_Avg, hfcomm.wo.laal.ext, family=quasibinomial)
mod.wo.laal.occ<-glm(cbind(occ.numr,occ.denr) ~ CAT_Avg, hfcomm.wo.laal.occ, family=quasibinomial)
mod.wo.laal.sta<-glm(cbind(stasis.numr,stasis.denr) ~ CAT_Avg, hfcomm.wo.laal.stasis, family=quasibinomial)
mod.wo.laal.per<-glm(cbind(per.numr,per.denr) ~ CAT_Avg, hfcomm.wo.laal.per, family=quasibinomial)

# plot the raw proportions for each nest box in each chamber
tiff("Nest_box_responses_HF_minus_laal_actualT.tiff", height=10, width=15, res=300, units="in")
par(mfrow=c(2,3), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(occ.numr/occ.denr ~ CAT_Avg, hfcomm.wo.laal.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy")
lines(exp(predict(mod.wo.laal.occ, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(col.numr/col.denr ~ CAT_Avg, hfcomm.wo.laal.col, xlab="Chamber temperature (C)", ylab="Colonization")
lines(exp(predict(mod.wo.laal.col, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(ext.numr/ext.denr ~ CAT_Avg, hfcomm.wo.laal.ext, xlab="Chamber temperature (C)", ylab="Extinction")
lines(exp(predict(mod.wo.laal.ext, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(stasis.numr/stasis.denr ~ CAT_Avg, hfcomm.wo.laal.stasis, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.wo.laal.sta, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(per.numr/per.denr ~ CAT_Avg, hfcomm.wo.laal.per, xlab="Chamber temperature (C)", ylab="Revised persistence")
lines(exp(predict(mod.wo.laal.per, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

dev.off()



HF_minus_laal<-
rbind(
      cbind("occ", signif(summary(mod.wo.laal.occ)$coefficients[2,1],3), 
                   signif(summary(mod.wo.laal.occ)$coefficients[2,2],3), 
                   signif(anova(mod.wo.laal.occ, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.laal.occ, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("ext", signif(summary(mod.wo.laal.ext)$coefficients[2,1],3), 
                   signif(summary(mod.wo.laal.ext)$coefficients[2,2],3), 
                   signif(anova(mod.wo.laal.ext, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.laal.ext, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("col", signif(summary(mod.wo.laal.col)$coefficients[2,1],3), 
                   signif(summary(mod.wo.laal.col)$coefficients[2,2],3), 
                   signif(anova(mod.wo.laal.col, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.laal.col, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("sta", signif(summary(mod.wo.laal.sta)$coefficients[2,1],3), 
                   signif(summary(mod.wo.laal.sta)$coefficients[2,2],3), 
                   signif(anova(mod.wo.laal.sta, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.laal.sta, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("per", signif(summary(mod.wo.laal.per)$coefficients[2,1],3), 
                   signif(summary(mod.wo.laal.per)$coefficients[2,2],3), 
                   signif(anova(mod.wo.laal.per, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.laal.per, test="Chi")$"Pr(>Chi)"[2],3))
                   )
                   
colnames(HF_minus_laal)<-c("response","estimate","se","deviance","p")                    
write.csv(HF_minus_laal, "HF_minus_laal_model_results.csv")




################################################################################
# Community responses - jackknife - minus myrm #################################
################################################################################

hfcomm.wo.myrm1<-read.csv("HF_community_minus_myrm.csv", header=TRUE)

# recode the chamber IDs to target deltas
library(car)
hfcomm.wo.myrm1$Target_Delta<-recode(hfcomm.wo.myrm1$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals<-read.csv("HF_CAT_Avg.csv", header=TRUE)
colnames(temp_vals)[2]<-"ch"

hfcomm.wo.myrm<-merge(hfcomm.wo.myrm1, temp_vals[,1:3], "ch")

hfcomm.wo.myrm.col<-hfcomm.wo.myrm[hfcomm.wo.myrm$col.den > 0,]
hfcomm.wo.myrm.ext<-hfcomm.wo.myrm[hfcomm.wo.myrm$ext.den > 0,]
hfcomm.wo.myrm.occ<-hfcomm.wo.myrm[hfcomm.wo.myrm$occ.den > 0,]
hfcomm.wo.myrm.stasis<-hfcomm.wo.myrm[hfcomm.wo.myrm$stasis.den > 0 & !is.na(hfcomm.wo.myrm$stasis.den),]
hfcomm.wo.myrm.per<-hfcomm.wo.myrm[hfcomm.wo.myrm$per.den > 0 & !is.na(hfcomm.wo.myrm$per.den),]

mod.wo.myrm.col<-glm(cbind(col.numr,col.denr) ~ CAT_Avg, hfcomm.wo.myrm.col, family=quasibinomial)
mod.wo.myrm.ext<-glm(cbind(ext.numr,ext.denr) ~ CAT_Avg, hfcomm.wo.myrm.ext, family=quasibinomial)
mod.wo.myrm.occ<-glm(cbind(occ.numr,occ.denr) ~ CAT_Avg, hfcomm.wo.myrm.occ, family=quasibinomial)
mod.wo.myrm.sta<-glm(cbind(stasis.numr,stasis.denr) ~ CAT_Avg, hfcomm.wo.myrm.stasis, family=quasibinomial)
mod.wo.myrm.per<-glm(cbind(per.numr,per.denr) ~ CAT_Avg, hfcomm.wo.myrm.per, family=quasibinomial)

# plot the raw proportions for each nest box in each chamber
tiff("Nest_box_responses_HF_minus_myrm_actualT.tiff", height=10, width=15, res=300, units="in")
par(mfrow=c(2,3), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(occ.numr/occ.denr ~ CAT_Avg, hfcomm.wo.myrm.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy")
lines(exp(predict(mod.wo.myrm.occ, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(col.numr/col.denr ~ CAT_Avg, hfcomm.wo.myrm.col, xlab="Chamber temperature (C)", ylab="Colonization")
lines(exp(predict(mod.wo.myrm.col, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(ext.numr/ext.denr ~ CAT_Avg, hfcomm.wo.myrm.ext, xlab="Chamber temperature (C)", ylab="Extinction")
lines(exp(predict(mod.wo.myrm.ext, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(stasis.numr/stasis.denr ~ CAT_Avg, hfcomm.wo.myrm.stasis, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.wo.myrm.sta, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(per.numr/per.denr ~ CAT_Avg, hfcomm.wo.myrm.per, xlab="Chamber temperature (C)", ylab="Revised persistence")
lines(exp(predict(mod.wo.myrm.per, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

dev.off()



HF_minus_myrm<-
rbind(
      cbind("occ", signif(summary(mod.wo.myrm.occ)$coefficients[2,1],3), 
                   signif(summary(mod.wo.myrm.occ)$coefficients[2,2],3), 
                   signif(anova(mod.wo.myrm.occ, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.myrm.occ, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("ext", signif(summary(mod.wo.myrm.ext)$coefficients[2,1],3), 
                   signif(summary(mod.wo.myrm.ext)$coefficients[2,2],3), 
                   signif(anova(mod.wo.myrm.ext, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.myrm.ext, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("col", signif(summary(mod.wo.myrm.col)$coefficients[2,1],3), 
                   signif(summary(mod.wo.myrm.col)$coefficients[2,2],3), 
                   signif(anova(mod.wo.myrm.col, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.myrm.col, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("sta", signif(summary(mod.wo.myrm.sta)$coefficients[2,1],3), 
                   signif(summary(mod.wo.myrm.sta)$coefficients[2,2],3), 
                   signif(anova(mod.wo.myrm.sta, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.myrm.sta, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("per", signif(summary(mod.wo.myrm.per)$coefficients[2,1],3), 
                   signif(summary(mod.wo.myrm.per)$coefficients[2,2],3), 
                   signif(anova(mod.wo.myrm.per, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.myrm.per, test="Chi")$"Pr(>Chi)"[2],3))
                   )
                   
colnames(HF_minus_myrm)<-c("response","estimate","se","deviance","p")                    
write.csv(HF_minus_myrm, "HF_minus_myrm_model_results.csv")


################################################################################
# Community responses - jackknife - minus telo #################################
################################################################################

hfcomm.wo.telo1<-read.csv("HF_community_minus_telo.csv", header=TRUE)

# recode the chamber IDs to target deltas
library(car)
hfcomm.wo.telo1$Target_Delta<-recode(hfcomm.wo.telo1$ch, c("1 = 5.5; 2 = 4; 3 = 2; 4 = 0; 5 = 5; 6 = 0; 7 = 3; 8 = 1.5; 9 = 2.5; 10 = 4.5; 11 = 0; 12 = 3.5; 13 = 0; 14 = 0; 15 = 0"))

temp_vals<-read.csv("HF_CAT_Avg.csv", header=TRUE)
colnames(temp_vals)[2]<-"ch"

hfcomm.wo.telo<-merge(hfcomm.wo.telo1, temp_vals[,1:3], "ch")

hfcomm.wo.telo.col<-hfcomm.wo.telo[hfcomm.wo.telo$col.den > 0,]
hfcomm.wo.telo.ext<-hfcomm.wo.telo[hfcomm.wo.telo$ext.den > 0,]
hfcomm.wo.telo.occ<-hfcomm.wo.telo[hfcomm.wo.telo$occ.den > 0,]
hfcomm.wo.telo.stasis<-hfcomm.wo.telo[hfcomm.wo.telo$stasis.den > 0 & !is.na(hfcomm.wo.telo$stasis.den),]
hfcomm.wo.telo.per<-hfcomm.wo.telo[hfcomm.wo.telo$per.den > 0 & !is.na(hfcomm.wo.telo$per.den),]

mod.wo.telo.col<-glm(cbind(col.numr,col.denr) ~ CAT_Avg, hfcomm.wo.telo.col, family=quasibinomial)
mod.wo.telo.ext<-glm(cbind(ext.numr,ext.denr) ~ CAT_Avg, hfcomm.wo.telo.ext, family=quasibinomial)
mod.wo.telo.occ<-glm(cbind(occ.numr,occ.denr) ~ CAT_Avg, hfcomm.wo.telo.occ, family=quasibinomial)
mod.wo.telo.sta<-glm(cbind(stasis.numr,stasis.denr) ~ CAT_Avg, hfcomm.wo.telo.stasis, family=quasibinomial)
mod.wo.telo.per<-glm(cbind(per.numr,per.denr) ~ CAT_Avg, hfcomm.wo.telo.per, family=quasibinomial)

# plot the raw proportions for each nest box in each chamber
tiff("Nest_box_responses_HF_minus_telo_actualT.tiff", height=10, width=15, res=300, units="in")
par(mfrow=c(2,3), las=1, tcl=.2, cex.lab=1.6, cex.axis=1.3, mar=c(5,5,2,2))
plot(occ.numr/occ.denr ~ CAT_Avg, hfcomm.wo.telo.occ, xlab="Chamber temperature (C)", ylab="Nest occupancy")
lines(exp(predict(mod.wo.telo.occ, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(col.numr/col.denr ~ CAT_Avg, hfcomm.wo.telo.col, xlab="Chamber temperature (C)", ylab="Colonization")
lines(exp(predict(mod.wo.telo.col, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(ext.numr/ext.denr ~ CAT_Avg, hfcomm.wo.telo.ext, xlab="Chamber temperature (C)", ylab="Extinction")
lines(exp(predict(mod.wo.telo.ext, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(stasis.numr/stasis.denr ~ CAT_Avg, hfcomm.wo.telo.stasis, xlab="Chamber temperature (C)", ylab="Persistence")
lines(exp(predict(mod.wo.telo.sta, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

plot(per.numr/per.denr ~ CAT_Avg, hfcomm.wo.telo.per, xlab="Chamber temperature (C)", ylab="Revised persistence")
lines(exp(predict(mod.wo.telo.per, newdata=data.frame(CAT_Avg=seq(8,15,length.out=1000)))) ~ seq(8,15,length.out=1000), col="blue", lwd=2)

dev.off()



HF_minus_telo<-
rbind(
      cbind("occ", signif(summary(mod.wo.telo.occ)$coefficients[2,1],3), 
                   signif(summary(mod.wo.telo.occ)$coefficients[2,2],3), 
                   signif(anova(mod.wo.telo.occ, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.telo.occ, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("ext", signif(summary(mod.wo.telo.ext)$coefficients[2,1],3), 
                   signif(summary(mod.wo.telo.ext)$coefficients[2,2],3), 
                   signif(anova(mod.wo.telo.ext, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.telo.ext, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("col", signif(summary(mod.wo.telo.col)$coefficients[2,1],3), 
                   signif(summary(mod.wo.telo.col)$coefficients[2,2],3), 
                   signif(anova(mod.wo.telo.col, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.telo.col, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("sta", signif(summary(mod.wo.telo.sta)$coefficients[2,1],3), 
                   signif(summary(mod.wo.telo.sta)$coefficients[2,2],3), 
                   signif(anova(mod.wo.telo.sta, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.telo.sta, test="Chi")$"Pr(>Chi)"[2],3)),
      cbind("per", signif(summary(mod.wo.telo.per)$coefficients[2,1],3), 
                   signif(summary(mod.wo.telo.per)$coefficients[2,2],3), 
                   signif(anova(mod.wo.telo.per, test="Chi")$Deviance[2],3), 
                   signif(anova(mod.wo.telo.per, test="Chi")$"Pr(>Chi)"[2],3))
                   )
                   
colnames(HF_minus_telo)<-c("response","estimate","se","deviance","p")                    
write.csv(HF_minus_telo, "HF_minus_telo_model_results.csv")

################################################################################
# non-focal spp as predictors of focal spp; set up for Markov models ###########
################################################################################

################################################################################
# ca on ap #####################################################################
################################################################################

ca$ca.pres.abs<-(ca$occ.num/ca$occ.den)

ca.s<-ca[,c("ca.pres.abs","ch","Nest")]

ap.ca<-merge(ca.s,ap,all=T)



# does the presence of Camponotus influence Aphaenogaster colonization?
intrxn.mod.apca1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, ap.ca, family=quasibinomial)
intrxn.mod.apca2c<-glm(cbind(col.num,col.den) ~ ca.pres.abs, ap.ca, family=quasibinomial)
intrxn.mod.apca3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + ca.pres.abs, ap.ca, family=quasibinomial)
intrxn.mod.apca4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * ca.pres.abs, ap.ca, family=quasibinomial)

summary(intrxn.mod.apca1c)
summary(intrxn.mod.apca2c)
summary(intrxn.mod.apca3c)
summary(intrxn.mod.apca4c)

# does the presence of Camponotus influence Aphaenogaster extinction?
intrxn.mod.apca1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, ap.ca, family=quasibinomial)
intrxn.mod.apca2e<-glm(cbind(ext.num,ext.den) ~ ca.pres.abs, ap.ca, family=quasibinomial)
intrxn.mod.apca3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + ca.pres.abs, ap.ca, family=quasibinomial)
intrxn.mod.apca4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * ca.pres.abs, ap.ca, family=quasibinomial)

summary(intrxn.mod.apca1e)
summary(intrxn.mod.apca2e)
summary(intrxn.mod.apca3e)
summary(intrxn.mod.apca4e)

# does the presence of Camponotus influence Aphaenogaster occupancy?
intrxn.mod.apca1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, ap.ca, family=quasibinomial)
intrxn.mod.apca2o<-glm(cbind(occ.num,occ.den) ~ ca.pres.abs, ap.ca, family=quasibinomial)
intrxn.mod.apca3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + ca.pres.abs, ap.ca, family=quasibinomial)
intrxn.mod.apca4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * ca.pres.abs, ap.ca, family=quasibinomial)

summary(intrxn.mod.apca1o)
summary(intrxn.mod.apca2o)
summary(intrxn.mod.apca3o)
summary(intrxn.mod.apca4o)

# does the presence of Camponotus influence Aphaenogaster persistence?
intrxn.mod.apca1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, ap.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.apca2s<-glm(cbind(stasis.num,stasis.den) ~ ca.pres.abs, ap.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.apca3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + ca.pres.abs, ap.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.apca4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * ca.pres.abs, ap.ca, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.apca1s)
summary(intrxn.mod.apca2s)
summary(intrxn.mod.apca3s)
summary(intrxn.mod.apca4s)

# does the presence of Camponotus influence Aphaenogaster persistence?
intrxn.mod.apca1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, ap.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.apca2p<-glm(cbind(per.num,per.den) ~ ca.pres.abs, ap.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.apca3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + ca.pres.abs, ap.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.apca4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * ca.pres.abs, ap.ca, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.apca1p)
summary(intrxn.mod.apca2p)
summary(intrxn.mod.apca3p)
summary(intrxn.mod.apca4p)

ca.on.ap<-
signif(rbind(
summary(intrxn.mod.apca1c)$coefficients,
summary(intrxn.mod.apca2c)$coefficients,
summary(intrxn.mod.apca3c)$coefficients,
summary(intrxn.mod.apca4c)$coefficients,
summary(intrxn.mod.apca1e)$coefficients,
summary(intrxn.mod.apca2e)$coefficients,
summary(intrxn.mod.apca3e)$coefficients,
summary(intrxn.mod.apca4e)$coefficients,
summary(intrxn.mod.apca1o)$coefficients,
summary(intrxn.mod.apca2o)$coefficients,
summary(intrxn.mod.apca3o)$coefficients,
summary(intrxn.mod.apca4o)$coefficients,
summary(intrxn.mod.apca1s)$coefficients,
summary(intrxn.mod.apca2s)$coefficients,
summary(intrxn.mod.apca3s)$coefficients,
summary(intrxn.mod.apca4s)$coefficients,
summary(intrxn.mod.apca1p)$coefficients,
summary(intrxn.mod.apca2p)$coefficients,
summary(intrxn.mod.apca3p)$coefficients,
summary(intrxn.mod.apca4p)$coefficients
), digits=3)


write.csv(ca.on.ap, "Sept.ca.on.ap.csv")

################################################################################
# ca on la #####################################################################
################################################################################

ca$ca.pres.abs<-recode(ca$occ.num, "lo:0=0;1:hi=1")

ca.s<-ca[,c("ca.pres.abs","ch","Nest")]

la.ca<-merge(ca.s,la,all=T)

# does the presence of Camponotus influence Lasius colonization?
intrxn.mod.laca1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, la.ca, family=quasibinomial)
intrxn.mod.laca2c<-glm(cbind(col.num,col.den) ~ ca.pres.abs, la.ca, family=quasibinomial)
intrxn.mod.laca3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + ca.pres.abs, la.ca, family=quasibinomial)
intrxn.mod.laca4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * ca.pres.abs, la.ca, family=quasibinomial)

summary(intrxn.mod.laca1c)
summary(intrxn.mod.laca2c)
summary(intrxn.mod.laca3c)
summary(intrxn.mod.laca4c)

# does the presence of Camponotus influence Lasius extinction?
intrxn.mod.laca1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, la.ca, family=quasibinomial)
intrxn.mod.laca2e<-glm(cbind(ext.num,ext.den) ~ ca.pres.abs, la.ca, family=quasibinomial)
intrxn.mod.laca3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + ca.pres.abs, la.ca, family=quasibinomial)
intrxn.mod.laca4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * ca.pres.abs, la.ca, family=quasibinomial)

summary(intrxn.mod.laca1e)
summary(intrxn.mod.laca2e)
summary(intrxn.mod.laca3e)
summary(intrxn.mod.laca4e)

# does the presence of Camponotus influence Lasius occupancy?
intrxn.mod.laca1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, la.ca, family=quasibinomial)
intrxn.mod.laca2o<-glm(cbind(occ.num,occ.den) ~ ca.pres.abs, la.ca, family=quasibinomial)
intrxn.mod.laca3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + ca.pres.abs, la.ca, family=quasibinomial)
intrxn.mod.laca4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * ca.pres.abs, la.ca, family=quasibinomial)

summary(intrxn.mod.laca1o)
summary(intrxn.mod.laca2o)
summary(intrxn.mod.laca3o)
summary(intrxn.mod.laca4o)

# does the presence of Camponotus influence Lasius persistence?
intrxn.mod.laca1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, la.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.laca2s<-glm(cbind(stasis.num,stasis.den) ~ ca.pres.abs, la.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.laca3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + ca.pres.abs, la.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.laca4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * ca.pres.abs, la.ca, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.laca1s)
summary(intrxn.mod.laca2s)
summary(intrxn.mod.laca3s)
summary(intrxn.mod.laca4s)

# does the presence of Camponotus influence Lasius persistence?
intrxn.mod.laca1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, la.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.laca2p<-glm(cbind(per.num,per.den) ~ ca.pres.abs, la.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.laca3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + ca.pres.abs, la.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.laca4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * ca.pres.abs, la.ca, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.laca1p)
summary(intrxn.mod.laca2p)
summary(intrxn.mod.laca3p)
summary(intrxn.mod.laca4p)

ca.on.la<-
signif(rbind(
summary(intrxn.mod.laca1c)$coefficients,
summary(intrxn.mod.laca2c)$coefficients,
summary(intrxn.mod.laca3c)$coefficients,
summary(intrxn.mod.laca4c)$coefficients,
summary(intrxn.mod.laca1e)$coefficients,
summary(intrxn.mod.laca2e)$coefficients,
summary(intrxn.mod.laca3e)$coefficients,
summary(intrxn.mod.laca4e)$coefficients,
summary(intrxn.mod.laca1o)$coefficients,
summary(intrxn.mod.laca2o)$coefficients,
summary(intrxn.mod.laca3o)$coefficients,
summary(intrxn.mod.laca4o)$coefficients,
summary(intrxn.mod.laca1s)$coefficients,
summary(intrxn.mod.laca2s)$coefficients,
summary(intrxn.mod.laca3s)$coefficients,
summary(intrxn.mod.laca4s)$coefficients,
summary(intrxn.mod.laca1p)$coefficients,
summary(intrxn.mod.laca2p)$coefficients,
summary(intrxn.mod.laca3p)$coefficients,
summary(intrxn.mod.laca4p)$coefficients
), digits=3)


write.csv(ca.on.la, "ca.on.la.csv")

################################################################################
# ca on my #####################################################################
################################################################################

ca$ca.pres.abs<-recode(ca$occ.num, "lo:0=0;1:hi=1")

ca.s<-ca[,c("ca.pres.abs","ch","Nest")]

my.ca<-merge(ca.s,my,all=T)


# does the presence of Camponotus influence Myrmica colonization?
intrxn.mod.myca1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, my.ca, family=quasibinomial)
intrxn.mod.myca2c<-glm(cbind(col.num,col.den) ~ ca.pres.abs, my.ca, family=quasibinomial)
intrxn.mod.myca3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + ca.pres.abs, my.ca, family=quasibinomial)
intrxn.mod.myca4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * ca.pres.abs, my.ca, family=quasibinomial)

summary(intrxn.mod.myca1c)
summary(intrxn.mod.myca2c)
summary(intrxn.mod.myca3c)
summary(intrxn.mod.myca4c)

# does the presence of Camponotus influence Myrmica extinction?
intrxn.mod.myca1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, my.ca, family=quasibinomial)
intrxn.mod.myca2e<-glm(cbind(ext.num,ext.den) ~ ca.pres.abs, my.ca, family=quasibinomial)
intrxn.mod.myca3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + ca.pres.abs, my.ca, family=quasibinomial)
intrxn.mod.myca4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * ca.pres.abs, my.ca, family=quasibinomial)

summary(intrxn.mod.myca1e)
summary(intrxn.mod.myca2e)
summary(intrxn.mod.myca3e)
summary(intrxn.mod.myca4e)

# does the presence of Camponotus influence Myrmica occupancy?
intrxn.mod.myca1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, my.ca, family=quasibinomial)
intrxn.mod.myca2o<-glm(cbind(occ.num,occ.den) ~ ca.pres.abs, my.ca, family=quasibinomial)
intrxn.mod.myca3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + ca.pres.abs, my.ca, family=quasibinomial)
intrxn.mod.myca4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * ca.pres.abs, my.ca, family=quasibinomial)

summary(intrxn.mod.myca1o)
summary(intrxn.mod.myca2o)
summary(intrxn.mod.myca3o)
summary(intrxn.mod.myca4o)

# does the presence of Camponotus influence Myrmica persistence?
intrxn.mod.myca1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, my.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.myca2s<-glm(cbind(stasis.num,stasis.den) ~ ca.pres.abs, my.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.myca3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + ca.pres.abs, my.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.myca4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * ca.pres.abs, my.ca, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.myca1s)
summary(intrxn.mod.myca2s)
summary(intrxn.mod.myca3s)
summary(intrxn.mod.myca4s)

# does the presence of Camponotus influence Myrmica persistence?
intrxn.mod.myca1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, my.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.myca2p<-glm(cbind(per.num,per.den) ~ ca.pres.abs, my.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.myca3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + ca.pres.abs, my.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.myca4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * ca.pres.abs, my.ca, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.myca1p)
summary(intrxn.mod.myca2p)
summary(intrxn.mod.myca3p)
summary(intrxn.mod.myca4p)

ca.on.my<-
signif(rbind(
summary(intrxn.mod.myca1c)$coefficients,
summary(intrxn.mod.myca2c)$coefficients,
summary(intrxn.mod.myca3c)$coefficients,
summary(intrxn.mod.myca4c)$coefficients,
summary(intrxn.mod.myca1e)$coefficients,
summary(intrxn.mod.myca2e)$coefficients,
summary(intrxn.mod.myca3e)$coefficients,
summary(intrxn.mod.myca4e)$coefficients,
summary(intrxn.mod.myca1o)$coefficients,
summary(intrxn.mod.myca2o)$coefficients,
summary(intrxn.mod.myca3o)$coefficients,
summary(intrxn.mod.myca4o)$coefficients,
summary(intrxn.mod.myca1s)$coefficients,
summary(intrxn.mod.myca2s)$coefficients,
summary(intrxn.mod.myca3s)$coefficients,
summary(intrxn.mod.myca4s)$coefficients,
summary(intrxn.mod.myca1p)$coefficients,
summary(intrxn.mod.myca2p)$coefficients,
summary(intrxn.mod.myca3p)$coefficients,
summary(intrxn.mod.myca4p)$coefficients
), digits=3)


write.csv(ca.on.my, "ca.on.my.csv")

################################################################################
# ca on te #####################################################################
################################################################################

ca$ca.pres.abs<-recode(ca$occ.num, "lo:0=0;1:hi=1")

ca.s<-ca[,c("ca.pres.abs","ch","Nest")]

te.ca<-merge(ca.s,te,all=T)


# does the presence of Camponotus influence Temnothorax colonization?
intrxn.mod.teca1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, te.ca, family=quasibinomial)
intrxn.mod.teca2c<-glm(cbind(col.num,col.den) ~ ca.pres.abs, te.ca, family=quasibinomial)
intrxn.mod.teca3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + ca.pres.abs, te.ca, family=quasibinomial)
intrxn.mod.teca4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * ca.pres.abs, te.ca, family=quasibinomial)

summary(intrxn.mod.teca1c)
summary(intrxn.mod.teca2c)
summary(intrxn.mod.teca3c)
summary(intrxn.mod.teca4c)

# does the presence of Camponotus influence Temnothorax extinction?
intrxn.mod.teca1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, te.ca, family=quasibinomial)
intrxn.mod.teca2e<-glm(cbind(ext.num,ext.den) ~ ca.pres.abs, te.ca, family=quasibinomial)
intrxn.mod.teca3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + ca.pres.abs, te.ca, family=quasibinomial)
intrxn.mod.teca4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * ca.pres.abs, te.ca, family=quasibinomial)

summary(intrxn.mod.teca1e)
summary(intrxn.mod.teca2e)
summary(intrxn.mod.teca3e)
summary(intrxn.mod.teca4e)

# does the presence of Camponotus influence Temnothorax occupancy?
intrxn.mod.teca1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, te.ca, family=quasibinomial)
intrxn.mod.teca2o<-glm(cbind(occ.num,occ.den) ~ ca.pres.abs, te.ca, family=quasibinomial)
intrxn.mod.teca3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + ca.pres.abs, te.ca, family=quasibinomial)
intrxn.mod.teca4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * ca.pres.abs, te.ca, family=quasibinomial)

summary(intrxn.mod.teca1o)
summary(intrxn.mod.teca2o)
summary(intrxn.mod.teca3o)
summary(intrxn.mod.teca4o)

# does the presence of Camponotus influence Temnothorax persistence?
intrxn.mod.teca1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, te.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.teca2s<-glm(cbind(stasis.num,stasis.den) ~ ca.pres.abs, te.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.teca3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + ca.pres.abs, te.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.teca4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * ca.pres.abs, te.ca, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.teca1s)
summary(intrxn.mod.teca2s)
summary(intrxn.mod.teca3s)
summary(intrxn.mod.teca4s)

# does the presence of Camponotus influence Temnothorax persistence?
intrxn.mod.teca1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, te.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.teca2p<-glm(cbind(per.num,per.den) ~ ca.pres.abs, te.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.teca3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + ca.pres.abs, te.ca, family=quasibinomial, na.action=na.omit)
intrxn.mod.teca4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * ca.pres.abs, te.ca, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.teca1p)
summary(intrxn.mod.teca2p)
summary(intrxn.mod.teca3p)
summary(intrxn.mod.teca4p)

ca.on.te<-
signif(rbind(
summary(intrxn.mod.teca1c)$coefficients,
summary(intrxn.mod.teca2c)$coefficients,
summary(intrxn.mod.teca3c)$coefficients,
summary(intrxn.mod.teca4c)$coefficients,
summary(intrxn.mod.teca1e)$coefficients,
summary(intrxn.mod.teca2e)$coefficients,
summary(intrxn.mod.teca3e)$coefficients,
summary(intrxn.mod.teca4e)$coefficients,
summary(intrxn.mod.teca1o)$coefficients,
summary(intrxn.mod.teca2o)$coefficients,
summary(intrxn.mod.teca3o)$coefficients,
summary(intrxn.mod.teca4o)$coefficients,
summary(intrxn.mod.teca1s)$coefficients,
summary(intrxn.mod.teca2s)$coefficients,
summary(intrxn.mod.teca3s)$coefficients,
summary(intrxn.mod.teca4s)$coefficients,
summary(intrxn.mod.teca1p)$coefficients,
summary(intrxn.mod.teca2p)$coefficients,
summary(intrxn.mod.teca3p)$coefficients,
summary(intrxn.mod.teca4p)$coefficients
), digits=3)


write.csv(ca.on.te, "ca.on.te.csv")

################################################################################
# ap on te #####################################################################
################################################################################

ap$ap.pres.abs<-recode(ap$occ.num, "lo:0=0;1:hi=1")

ap.s<-ap[,c("ap.pres.abs","ch","Nest")]

te.ap<-merge(ap.s,te,all=T)


# does the presence of Aphaenogaster influence Temnothorax colonization?
intrxn.mod.teap1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, te.ap, family=quasibinomial)
intrxn.mod.teap2c<-glm(cbind(col.num,col.den) ~ ap.pres.abs, te.ap, family=quasibinomial)
intrxn.mod.teap3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + ap.pres.abs, te.ap, family=quasibinomial)
intrxn.mod.teap4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * ap.pres.abs, te.ap, family=quasibinomial)

summary(intrxn.mod.teap1c)
summary(intrxn.mod.teap2c)
summary(intrxn.mod.teap3c)
summary(intrxn.mod.teap4c)

# does the presence of Aphaenogaster influence Temnothorax extinction?
intrxn.mod.teap1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, te.ap, family=quasibinomial)
intrxn.mod.teap2e<-glm(cbind(ext.num,ext.den) ~ ap.pres.abs, te.ap, family=quasibinomial)
intrxn.mod.teap3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + ap.pres.abs, te.ap, family=quasibinomial)
intrxn.mod.teap4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * ap.pres.abs, te.ap, family=quasibinomial)

summary(intrxn.mod.teap1e)
summary(intrxn.mod.teap2e)
summary(intrxn.mod.teap3e)
summary(intrxn.mod.teap4e)

# does the presence of Aphaenogaster influence Temnothorax occupancy?
intrxn.mod.teap1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, te.ap, family=quasibinomial)
intrxn.mod.teap2o<-glm(cbind(occ.num,occ.den) ~ ap.pres.abs, te.ap, family=quasibinomial)
intrxn.mod.teap3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + ap.pres.abs, te.ap, family=quasibinomial)
intrxn.mod.teap4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * ap.pres.abs, te.ap, family=quasibinomial)

summary(intrxn.mod.teap1o)
summary(intrxn.mod.teap2o)
summary(intrxn.mod.teap3o)
summary(intrxn.mod.teap4o)

# does the presence of Aphaenogaster influence Temnothorax persistence?
intrxn.mod.teap1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, te.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.teap2s<-glm(cbind(stasis.num,stasis.den) ~ ap.pres.abs, te.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.teap3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + ap.pres.abs, te.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.teap4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * ap.pres.abs, te.ap, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.teap1s)
summary(intrxn.mod.teap2s)
summary(intrxn.mod.teap3s)
summary(intrxn.mod.teap4s)

# does the presence of Aphaenogaster influence Temnothorax persistence?
intrxn.mod.teap1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, te.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.teap2p<-glm(cbind(per.num,per.den) ~ ap.pres.abs, te.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.teap3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + ap.pres.abs, te.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.teap4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * ap.pres.abs, te.ap, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.teap1p)
summary(intrxn.mod.teap2p)
summary(intrxn.mod.teap3p)
summary(intrxn.mod.teap4p)

ap.on.te<-
signif(rbind(
summary(intrxn.mod.teap1c)$coefficients,
summary(intrxn.mod.teap2c)$coefficients,
summary(intrxn.mod.teap3c)$coefficients,
summary(intrxn.mod.teap4c)$coefficients,
summary(intrxn.mod.teap1e)$coefficients,
summary(intrxn.mod.teap2e)$coefficients,
summary(intrxn.mod.teap3e)$coefficients,
summary(intrxn.mod.teap4e)$coefficients,
summary(intrxn.mod.teap1o)$coefficients,
summary(intrxn.mod.teap2o)$coefficients,
summary(intrxn.mod.teap3o)$coefficients,
summary(intrxn.mod.teap4o)$coefficients,
summary(intrxn.mod.teap1s)$coefficients,
summary(intrxn.mod.teap2s)$coefficients,
summary(intrxn.mod.teap3s)$coefficients,
summary(intrxn.mod.teap4s)$coefficients,
summary(intrxn.mod.teap1p)$coefficients,
summary(intrxn.mod.teap2p)$coefficients,
summary(intrxn.mod.teap3p)$coefficients,
summary(intrxn.mod.teap4p)$coefficients
), digits=3)


write.csv(ap.on.te, "ap.on.te.HF.csv")

################################################################################
# ap on ca #####################################################################
################################################################################

ap$ap.pres.abs<-recode(ap$occ.num, "lo:0=0;1:hi=1")

ap.s<-ap[,c("ap.pres.abs","ch","Nest")]

ca.ap<-merge(ap.s,ca,all=T)
 
 
# does the presence of Aphaenogaster influence Camponotus colonization?
intrxn.mod.caap1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, ca.ap, family=quasibinomial)
intrxn.mod.caap2c<-glm(cbind(col.num,col.den) ~ ap.pres.abs, ca.ap, family=quasibinomial)
intrxn.mod.caap3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + ap.pres.abs, ca.ap, family=quasibinomial)
intrxn.mod.caap4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * ap.pres.abs, ca.ap, family=quasibinomial)

summary(intrxn.mod.caap1c)
summary(intrxn.mod.caap2c)
summary(intrxn.mod.caap3c)
summary(intrxn.mod.caap4c)

# does the presence of Aphaenogaster influence Camponotus extinction?
intrxn.mod.caap1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, ca.ap, family=quasibinomial)
intrxn.mod.caap2e<-glm(cbind(ext.num,ext.den) ~ ap.pres.abs, ca.ap, family=quasibinomial)
intrxn.mod.caap3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + ap.pres.abs, ca.ap, family=quasibinomial)
intrxn.mod.caap4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * ap.pres.abs, ca.ap, family=quasibinomial)

summary(intrxn.mod.caap1e)
summary(intrxn.mod.caap2e)
summary(intrxn.mod.caap3e)
summary(intrxn.mod.caap4e)

# does the presence of Aphaenogaster influence Camponotus occupancy?
intrxn.mod.caap1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, ca.ap, family=quasibinomial)
intrxn.mod.caap2o<-glm(cbind(occ.num,occ.den) ~ ap.pres.abs, ca.ap, family=quasibinomial)
intrxn.mod.caap3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + ap.pres.abs, ca.ap, family=quasibinomial)
intrxn.mod.caap4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * ap.pres.abs, ca.ap, family=quasibinomial)

summary(intrxn.mod.caap1o)
summary(intrxn.mod.caap2o)
summary(intrxn.mod.caap3o)
summary(intrxn.mod.caap4o)

# does the presence of Aphaenogaster influence Camponotus persistence?
intrxn.mod.caap1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, ca.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.caap2s<-glm(cbind(stasis.num,stasis.den) ~ ap.pres.abs, ca.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.caap3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + ap.pres.abs, ca.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.caap4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * ap.pres.abs, ca.ap, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.caap1s)
summary(intrxn.mod.caap2s)
summary(intrxn.mod.caap3s)
summary(intrxn.mod.caap4s)

# does the presence of Aphaenogaster influence Camponotus persistence?
intrxn.mod.caap1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, ca.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.caap2p<-glm(cbind(per.num,per.den) ~ ap.pres.abs, ca.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.caap3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + ap.pres.abs, ca.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.caap4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * ap.pres.abs, ca.ap, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.caap1p)
summary(intrxn.mod.caap2p)
summary(intrxn.mod.caap3p)
summary(intrxn.mod.caap4p)

ap.on.ca<-
signif(rbind(
summary(intrxn.mod.caap1c)$coefficients,
summary(intrxn.mod.caap2c)$coefficients,
summary(intrxn.mod.caap3c)$coefficients,
summary(intrxn.mod.caap4c)$coefficients,
summary(intrxn.mod.caap1e)$coefficients,
summary(intrxn.mod.caap2e)$coefficients,
summary(intrxn.mod.caap3e)$coefficients,
summary(intrxn.mod.caap4e)$coefficients,
summary(intrxn.mod.caap1o)$coefficients,
summary(intrxn.mod.caap2o)$coefficients,
summary(intrxn.mod.caap3o)$coefficients,
summary(intrxn.mod.caap4o)$coefficients,
summary(intrxn.mod.caap1s)$coefficients,
summary(intrxn.mod.caap2s)$coefficients,
summary(intrxn.mod.caap3s)$coefficients,
summary(intrxn.mod.caap4s)$coefficients,
summary(intrxn.mod.caap1p)$coefficients,
summary(intrxn.mod.caap2p)$coefficients,
summary(intrxn.mod.caap3p)$coefficients,
summary(intrxn.mod.caap4p)$coefficients
), digits=3)

write.csv(ap.on.ca, "ap.on.ca.csv")

################################################################################
# ap on la #####################################################################
################################################################################

ap$ap.pres.abs<-recode(ap$occ.num, "lo:0=0;1:hi=1")

ap.s<-ap[,c("ap.pres.abs","ch","Nest")]

la.ap<-merge(ap.s,la,all=T)

# does the presence of Aphaenogaster influence Lasius colonization?
intrxn.mod.laap1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, la.ap, family=quasibinomial)
intrxn.mod.laap2c<-glm(cbind(col.num,col.den) ~ ap.pres.abs, la.ap, family=quasibinomial)
intrxn.mod.laap3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + ap.pres.abs, la.ap, family=quasibinomial)
intrxn.mod.laap4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * ap.pres.abs, la.ap, family=quasibinomial)

summary(intrxn.mod.laap1c)
summary(intrxn.mod.laap2c)
summary(intrxn.mod.laap3c)
summary(intrxn.mod.laap4c)

# does the presence of Aphaenogaster influence Lasius extinction?
intrxn.mod.laap1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, la.ap, family=quasibinomial)
intrxn.mod.laap2e<-glm(cbind(ext.num,ext.den) ~ ap.pres.abs, la.ap, family=quasibinomial)
intrxn.mod.laap3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + ap.pres.abs, la.ap, family=quasibinomial)
intrxn.mod.laap4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * ap.pres.abs, la.ap, family=quasibinomial)

summary(intrxn.mod.laap1e)
summary(intrxn.mod.laap2e)
summary(intrxn.mod.laap3e)
summary(intrxn.mod.laap4e)

# does the presence of Aphaenogaster influence Lasius occupancy?
intrxn.mod.laap1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, la.ap, family=quasibinomial)
intrxn.mod.laap2o<-glm(cbind(occ.num,occ.den) ~ ap.pres.abs, la.ap, family=quasibinomial)
intrxn.mod.laap3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + ap.pres.abs, la.ap, family=quasibinomial)
intrxn.mod.laap4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * ap.pres.abs, la.ap, family=quasibinomial)

summary(intrxn.mod.laap1o)
summary(intrxn.mod.laap2o)
summary(intrxn.mod.laap3o)
summary(intrxn.mod.laap4o)

# does the presence of Aphaenogaster influence Lasius persistence?
intrxn.mod.laap1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, la.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.laap2s<-glm(cbind(stasis.num,stasis.den) ~ ap.pres.abs, la.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.laap3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + ap.pres.abs, la.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.laap4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * ap.pres.abs, la.ap, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.laap1s)
summary(intrxn.mod.laap2s)
summary(intrxn.mod.laap3s)
summary(intrxn.mod.laap4s)

# does the presence of Aphaenogaster influence Lasius persistence?
intrxn.mod.laap1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, la.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.laap2p<-glm(cbind(per.num,per.den) ~ ap.pres.abs, la.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.laap3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + ap.pres.abs, la.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.laap4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * ap.pres.abs, la.ap, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.laap1p)
summary(intrxn.mod.laap2p)
summary(intrxn.mod.laap3p)
summary(intrxn.mod.laap4p)

ap.on.la<-
signif(rbind(
summary(intrxn.mod.laap1c)$coefficients,
summary(intrxn.mod.laap2c)$coefficients,
summary(intrxn.mod.laap3c)$coefficients,
summary(intrxn.mod.laap4c)$coefficients,
summary(intrxn.mod.laap1e)$coefficients,
summary(intrxn.mod.laap2e)$coefficients,
summary(intrxn.mod.laap3e)$coefficients,
summary(intrxn.mod.laap4e)$coefficients,
summary(intrxn.mod.laap1o)$coefficients,
summary(intrxn.mod.laap2o)$coefficients,
summary(intrxn.mod.laap3o)$coefficients,
summary(intrxn.mod.laap4o)$coefficients,
summary(intrxn.mod.laap1s)$coefficients,
summary(intrxn.mod.laap2s)$coefficients,
summary(intrxn.mod.laap3s)$coefficients,
summary(intrxn.mod.laap4s)$coefficients,
summary(intrxn.mod.laap1p)$coefficients,
summary(intrxn.mod.laap2p)$coefficients,
summary(intrxn.mod.laap3p)$coefficients,
summary(intrxn.mod.laap4p)$coefficients
), digits=3)


write.csv(ap.on.la, "ap.on.la.csv")

################################################################################
# ap on my #####################################################################
################################################################################

ap$ap.pres.abs<-recode(ap$occ.num, "lo:0=0;1:hi=1")

ap.s<-ap[,c("ap.pres.abs","ch","Nest")]

my.ap<-merge(ap.s,my,all=T)

# does the presence of Aphaenogaster influence Myrmica colonization?
intrxn.mod.myap1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, my.ap, family=quasibinomial)
intrxn.mod.myap2c<-glm(cbind(col.num,col.den) ~ ap.pres.abs, my.ap, family=quasibinomial)
intrxn.mod.myap3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + ap.pres.abs, my.ap, family=quasibinomial)
intrxn.mod.myap4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * ap.pres.abs, my.ap, family=quasibinomial)

summary(intrxn.mod.myap1c)
summary(intrxn.mod.myap2c)
summary(intrxn.mod.myap3c)
summary(intrxn.mod.myap4c)

# does the presence of Aphaenogaster influence Myrmica extinction?
intrxn.mod.myap1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, my.ap, family=quasibinomial)
intrxn.mod.myap2e<-glm(cbind(ext.num,ext.den) ~ ap.pres.abs, my.ap, family=quasibinomial)
intrxn.mod.myap3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + ap.pres.abs, my.ap, family=quasibinomial)
intrxn.mod.myap4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * ap.pres.abs, my.ap, family=quasibinomial)

summary(intrxn.mod.myap1e)
summary(intrxn.mod.myap2e)
summary(intrxn.mod.myap3e)
summary(intrxn.mod.myap4e)

# does the presence of Aphaenogaster influence Myrmica occupancy?
intrxn.mod.myap1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, my.ap, family=quasibinomial)
intrxn.mod.myap2o<-glm(cbind(occ.num,occ.den) ~ ap.pres.abs, my.ap, family=quasibinomial)
intrxn.mod.myap3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + ap.pres.abs, my.ap, family=quasibinomial)
intrxn.mod.myap4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * ap.pres.abs, my.ap, family=quasibinomial)

summary(intrxn.mod.myap1o)
summary(intrxn.mod.myap2o)
summary(intrxn.mod.myap3o)
summary(intrxn.mod.myap4o)

# does the presence of Aphaenogaster influence Myrmica persistence?
intrxn.mod.myap1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, my.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.myap2s<-glm(cbind(stasis.num,stasis.den) ~ ap.pres.abs, my.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.myap3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + ap.pres.abs, my.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.myap4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * ap.pres.abs, my.ap, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.myap1s)
summary(intrxn.mod.myap2s)
summary(intrxn.mod.myap3s)
summary(intrxn.mod.myap4s)

# does the presence of Aphaenogaster influence Myrmica persistence?
intrxn.mod.myap1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, my.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.myap2p<-glm(cbind(per.num,per.den) ~ ap.pres.abs, my.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.myap3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + ap.pres.abs, my.ap, family=quasibinomial, na.action=na.omit)
intrxn.mod.myap4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * ap.pres.abs, my.ap, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.myap1p)
summary(intrxn.mod.myap2p)
summary(intrxn.mod.myap3p)
summary(intrxn.mod.myap4p)

ap.on.my<-
signif(rbind(
summary(intrxn.mod.myap1c)$coefficients,
summary(intrxn.mod.myap2c)$coefficients,
summary(intrxn.mod.myap3c)$coefficients,
summary(intrxn.mod.myap4c)$coefficients,
summary(intrxn.mod.myap1e)$coefficients,
summary(intrxn.mod.myap2e)$coefficients,
summary(intrxn.mod.myap3e)$coefficients,
summary(intrxn.mod.myap4e)$coefficients,
summary(intrxn.mod.myap1o)$coefficients,
summary(intrxn.mod.myap2o)$coefficients,
summary(intrxn.mod.myap3o)$coefficients,
summary(intrxn.mod.myap4o)$coefficients,
summary(intrxn.mod.myap1s)$coefficients,
summary(intrxn.mod.myap2s)$coefficients,
summary(intrxn.mod.myap3s)$coefficients,
summary(intrxn.mod.myap4s)$coefficients,
summary(intrxn.mod.myap1p)$coefficients,
summary(intrxn.mod.myap2p)$coefficients,
summary(intrxn.mod.myap3p)$coefficients,
summary(intrxn.mod.myap4p)$coefficients
), digits=3)


write.csv(ap.on.my, "ap.on.my.csv")

################################################################################
# te on ap #####################################################################
################################################################################

te$te.pres.abs<-recode(te$occ.num, "lo:0=0;1:hi=1")

te.s<-te[,c("te.pres.abs","ch","Nest")]

ap.te<-merge(te.s,ap,all=T)


# does the presence of Temnothorax influence Aphaenogaster colonization?
intrxn.mod.apte1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, ap.te, family=quasibinomial)
intrxn.mod.apte2c<-glm(cbind(col.num,col.den) ~ te.pres.abs, ap.te, family=quasibinomial)
intrxn.mod.apte3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + te.pres.abs, ap.te, family=quasibinomial)
intrxn.mod.apte4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * te.pres.abs, ap.te, family=quasibinomial)

summary(intrxn.mod.apte1c)
summary(intrxn.mod.apte2c)
summary(intrxn.mod.apte3c)
summary(intrxn.mod.apte4c)

# does the presence of Temnothorax influence Aphaenogaster extinction?
intrxn.mod.apte1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, ap.te, family=quasibinomial)
intrxn.mod.apte2e<-glm(cbind(ext.num,ext.den) ~ te.pres.abs, ap.te, family=quasibinomial)
intrxn.mod.apte3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + te.pres.abs, ap.te, family=quasibinomial)
intrxn.mod.apte4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * te.pres.abs, ap.te, family=quasibinomial)

summary(intrxn.mod.apte1e)
summary(intrxn.mod.apte2e)
summary(intrxn.mod.apte3e)
summary(intrxn.mod.apte4e)

# does the presence of Temnothorax influence Aphaenogaster occupancy?
intrxn.mod.apte1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, ap.te, family=quasibinomial)
intrxn.mod.apte2o<-glm(cbind(occ.num,occ.den) ~ te.pres.abs, ap.te, family=quasibinomial)
intrxn.mod.apte3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + te.pres.abs, ap.te, family=quasibinomial)
intrxn.mod.apte4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * te.pres.abs, ap.te, family=quasibinomial)

summary(intrxn.mod.apte1o)
summary(intrxn.mod.apte2o)
summary(intrxn.mod.apte3o)
summary(intrxn.mod.apte4o)

# does the presence of Temnothorax influence Aphaenogaster persistence?
intrxn.mod.apte1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, ap.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.apte2s<-glm(cbind(stasis.num,stasis.den) ~ te.pres.abs, ap.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.apte3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + te.pres.abs, ap.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.apte4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * te.pres.abs, ap.te, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.apte1s)
summary(intrxn.mod.apte2s)
summary(intrxn.mod.apte3s)
summary(intrxn.mod.apte4s)

# does the presence of Temnothorax influence Aphaenogaster persistence?
intrxn.mod.apte1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, ap.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.apte2p<-glm(cbind(per.num,per.den) ~ te.pres.abs, ap.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.apte3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + te.pres.abs, ap.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.apte4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * te.pres.abs, ap.te, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.apte1p)
summary(intrxn.mod.apte2p)
summary(intrxn.mod.apte3p)
summary(intrxn.mod.apte4p)

te.on.ap<-
signif(rbind(
summary(intrxn.mod.apte1c)$coefficients,
summary(intrxn.mod.apte2c)$coefficients,
summary(intrxn.mod.apte3c)$coefficients,
summary(intrxn.mod.apte4c)$coefficients,
summary(intrxn.mod.apte1e)$coefficients,
summary(intrxn.mod.apte2e)$coefficients,
summary(intrxn.mod.apte3e)$coefficients,
summary(intrxn.mod.apte4e)$coefficients,
summary(intrxn.mod.apte1o)$coefficients,
summary(intrxn.mod.apte2o)$coefficients,
summary(intrxn.mod.apte3o)$coefficients,
summary(intrxn.mod.apte4o)$coefficients,
summary(intrxn.mod.apte1s)$coefficients,
summary(intrxn.mod.apte2s)$coefficients,
summary(intrxn.mod.apte3s)$coefficients,
summary(intrxn.mod.apte4s)$coefficients,
summary(intrxn.mod.apte1p)$coefficients,
summary(intrxn.mod.apte2p)$coefficients,
summary(intrxn.mod.apte3p)$coefficients,
summary(intrxn.mod.apte4p)$coefficients
), digits=3)


write.csv(te.on.ap, "te.on.ap.HF.csv")

################################################################################
# te on ca #####################################################################
################################################################################

te$te.pres.abs<-recode(te$occ.num, "lo:0=0;1:hi=1")

te.s<-te[,c("te.pres.abs","ch","Nest")]

ca.te<-merge(te.s,ca,all=T)


# does the presence of Temnothorax influence Camponotus colonization?
intrxn.mod.cate1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, ca.te, family=quasibinomial)
intrxn.mod.cate2c<-glm(cbind(col.num,col.den) ~ te.pres.abs, ca.te, family=quasibinomial)
intrxn.mod.cate3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + te.pres.abs, ca.te, family=quasibinomial)
intrxn.mod.cate4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * te.pres.abs, ca.te, family=quasibinomial)

summary(intrxn.mod.cate1c)
summary(intrxn.mod.cate2c)
summary(intrxn.mod.cate3c)
summary(intrxn.mod.cate4c)

# does the presence of Temnothorax influence Camponotus extinction?
intrxn.mod.cate1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, ca.te, family=quasibinomial)
intrxn.mod.cate2e<-glm(cbind(ext.num,ext.den) ~ te.pres.abs, ca.te, family=quasibinomial)
intrxn.mod.cate3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + te.pres.abs, ca.te, family=quasibinomial)
intrxn.mod.cate4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * te.pres.abs, ca.te, family=quasibinomial)

summary(intrxn.mod.cate1e)
summary(intrxn.mod.cate2e)
summary(intrxn.mod.cate3e)
summary(intrxn.mod.cate4e)

# does the presence of Temnothorax influence Camponotus occupancy?
intrxn.mod.cate1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, ca.te, family=quasibinomial)
intrxn.mod.cate2o<-glm(cbind(occ.num,occ.den) ~ te.pres.abs, ca.te, family=quasibinomial)
intrxn.mod.cate3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + te.pres.abs, ca.te, family=quasibinomial)
intrxn.mod.cate4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * te.pres.abs, ca.te, family=quasibinomial)

summary(intrxn.mod.cate1o)
summary(intrxn.mod.cate2o)
summary(intrxn.mod.cate3o)
summary(intrxn.mod.cate4o)

# does the presence of Temnothorax influence Camponotus persistence?
intrxn.mod.cate1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, ca.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.cate2s<-glm(cbind(stasis.num,stasis.den) ~ te.pres.abs, ca.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.cate3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + te.pres.abs, ca.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.cate4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * te.pres.abs, ca.te, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.cate1s)
summary(intrxn.mod.cate2s)
summary(intrxn.mod.cate3s)
summary(intrxn.mod.cate4s)

# does the presence of Temnothorax influence Camponotus persistence?
intrxn.mod.cate1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, ca.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.cate2p<-glm(cbind(per.num,per.den) ~ te.pres.abs, ca.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.cate3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + te.pres.abs, ca.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.cate4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * te.pres.abs, ca.te, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.cate1p)
summary(intrxn.mod.cate2p)
summary(intrxn.mod.cate3p)
summary(intrxn.mod.cate4p)

te.on.ca<-
signif(rbind(
summary(intrxn.mod.cate1c)$coefficients,
summary(intrxn.mod.cate2c)$coefficients,
summary(intrxn.mod.cate3c)$coefficients,
summary(intrxn.mod.cate4c)$coefficients,
summary(intrxn.mod.cate1e)$coefficients,
summary(intrxn.mod.cate2e)$coefficients,
summary(intrxn.mod.cate3e)$coefficients,
summary(intrxn.mod.cate4e)$coefficients,
summary(intrxn.mod.cate1o)$coefficients,
summary(intrxn.mod.cate2o)$coefficients,
summary(intrxn.mod.cate3o)$coefficients,
summary(intrxn.mod.cate4o)$coefficients,
summary(intrxn.mod.cate1s)$coefficients,
summary(intrxn.mod.cate2s)$coefficients,
summary(intrxn.mod.cate3s)$coefficients,
summary(intrxn.mod.cate4s)$coefficients,
summary(intrxn.mod.cate1p)$coefficients,
summary(intrxn.mod.cate2p)$coefficients,
summary(intrxn.mod.cate3p)$coefficients,
summary(intrxn.mod.cate4p)$coefficients
), digits=3)


write.csv(te.on.ca, "te.on.ca.csv")

################################################################################
# te on la #####################################################################
################################################################################

te$te.pres.abs<-recode(te$occ.num, "lo:0=0;1:hi=1")

te.s<-te[,c("te.pres.abs","ch","Nest")]

la.te<-merge(te.s,la,all=T)


# does the presence of Temnothorax influence Lasius colonization?
intrxn.mod.late1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, la.te, family=quasibinomial)
intrxn.mod.late2c<-glm(cbind(col.num,col.den) ~ te.pres.abs, la.te, family=quasibinomial)
intrxn.mod.late3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + te.pres.abs, la.te, family=quasibinomial)
intrxn.mod.late4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * te.pres.abs, la.te, family=quasibinomial)

summary(intrxn.mod.late1c)
summary(intrxn.mod.late2c)
summary(intrxn.mod.late3c)
summary(intrxn.mod.late4c)

# does the presence of Temnothorax influence Lasius extinction?
intrxn.mod.late1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, la.te, family=quasibinomial)
intrxn.mod.late2e<-glm(cbind(ext.num,ext.den) ~ te.pres.abs, la.te, family=quasibinomial)
intrxn.mod.late3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + te.pres.abs, la.te, family=quasibinomial)
intrxn.mod.late4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * te.pres.abs, la.te, family=quasibinomial)

summary(intrxn.mod.late1e)
summary(intrxn.mod.late2e)
summary(intrxn.mod.late3e)
summary(intrxn.mod.late4e)

# does the presence of Temnothorax influence Lasius occupancy?
intrxn.mod.late1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, la.te, family=quasibinomial)
intrxn.mod.late2o<-glm(cbind(occ.num,occ.den) ~ te.pres.abs, la.te, family=quasibinomial)
intrxn.mod.late3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + te.pres.abs, la.te, family=quasibinomial)
intrxn.mod.late4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * te.pres.abs, la.te, family=quasibinomial)

summary(intrxn.mod.late1o)
summary(intrxn.mod.late2o)
summary(intrxn.mod.late3o)
summary(intrxn.mod.late4o)

# does the presence of Temnothorax influence Lasius persistence?
intrxn.mod.late1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, la.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.late2s<-glm(cbind(stasis.num,stasis.den) ~ te.pres.abs, la.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.late3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + te.pres.abs, la.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.late4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * te.pres.abs, la.te, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.late1s)
summary(intrxn.mod.late2s)
summary(intrxn.mod.late3s)
summary(intrxn.mod.late4s)

# does the presence of Temnothorax influence Lasius persistence?
intrxn.mod.late1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, la.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.late2p<-glm(cbind(per.num,per.den) ~ te.pres.abs, la.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.late3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + te.pres.abs, la.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.late4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * te.pres.abs, la.te, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.late1p)
summary(intrxn.mod.late2p)
summary(intrxn.mod.late3p)
summary(intrxn.mod.late4p)

te.on.la<-
signif(rbind(
summary(intrxn.mod.late1c)$coefficients,
summary(intrxn.mod.late2c)$coefficients,
summary(intrxn.mod.late3c)$coefficients,
summary(intrxn.mod.late4c)$coefficients,
summary(intrxn.mod.late1e)$coefficients,
summary(intrxn.mod.late2e)$coefficients,
summary(intrxn.mod.late3e)$coefficients,
summary(intrxn.mod.late4e)$coefficients,
summary(intrxn.mod.late1o)$coefficients,
summary(intrxn.mod.late2o)$coefficients,
summary(intrxn.mod.late3o)$coefficients,
summary(intrxn.mod.late4o)$coefficients,
summary(intrxn.mod.late1s)$coefficients,
summary(intrxn.mod.late2s)$coefficients,
summary(intrxn.mod.late3s)$coefficients,
summary(intrxn.mod.late4s)$coefficients,
summary(intrxn.mod.late1p)$coefficients,
summary(intrxn.mod.late2p)$coefficients,
summary(intrxn.mod.late3p)$coefficients,
summary(intrxn.mod.late4p)$coefficients
), digits=3)


write.csv(te.on.la, "te.on.la.csv")

################################################################################
# te on my #####################################################################
################################################################################

te$te.pres.abs<-recode(te$occ.num, "lo:0=0;1:hi=1")

te.s<-te[,c("te.pres.abs","ch","Nest")]

my.te<-merge(te.s,my,all=T)


# does the presence of Temnothorax influence Myrmica colonization?
intrxn.mod.myte1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, my.te, family=quasibinomial)
intrxn.mod.myte2c<-glm(cbind(col.num,col.den) ~ te.pres.abs, my.te, family=quasibinomial)
intrxn.mod.myte3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + te.pres.abs, my.te, family=quasibinomial)
intrxn.mod.myte4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * te.pres.abs, my.te, family=quasibinomial)

summary(intrxn.mod.myte1c)
summary(intrxn.mod.myte2c)
summary(intrxn.mod.myte3c)
summary(intrxn.mod.myte4c)

# does the presence of Temnothorax influence Myrmica extinction?
intrxn.mod.myte1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, my.te, family=quasibinomial)
intrxn.mod.myte2e<-glm(cbind(ext.num,ext.den) ~ te.pres.abs, my.te, family=quasibinomial)
intrxn.mod.myte3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + te.pres.abs, my.te, family=quasibinomial)
intrxn.mod.myte4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * te.pres.abs, my.te, family=quasibinomial)

summary(intrxn.mod.myte1e)
summary(intrxn.mod.myte2e)
summary(intrxn.mod.myte3e)
summary(intrxn.mod.myte4e)

# does the presence of Temnothorax influence Myrmica occupancy?
intrxn.mod.myte1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, my.te, family=quasibinomial)
intrxn.mod.myte2o<-glm(cbind(occ.num,occ.den) ~ te.pres.abs, my.te, family=quasibinomial)
intrxn.mod.myte3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + te.pres.abs, my.te, family=quasibinomial)
intrxn.mod.myte4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * te.pres.abs, my.te, family=quasibinomial)

summary(intrxn.mod.myte1o)
summary(intrxn.mod.myte2o)
summary(intrxn.mod.myte3o)
summary(intrxn.mod.myte4o)

# does the presence of Temnothorax influence Myrmica persistence?
intrxn.mod.myte1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, my.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.myte2s<-glm(cbind(stasis.num,stasis.den) ~ te.pres.abs, my.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.myte3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + te.pres.abs, my.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.myte4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * te.pres.abs, my.te, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.myte1s)
summary(intrxn.mod.myte2s)
summary(intrxn.mod.myte3s)
summary(intrxn.mod.myte4s)

# does the presence of Temnothorax influence Myrmica persistence?
intrxn.mod.myte1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, my.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.myte2p<-glm(cbind(per.num,per.den) ~ te.pres.abs, my.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.myte3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + te.pres.abs, my.te, family=quasibinomial, na.action=na.omit)
intrxn.mod.myte4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * te.pres.abs, my.te, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.myte1p)
summary(intrxn.mod.myte2p)
summary(intrxn.mod.myte3p)
summary(intrxn.mod.myte4p)

te.on.my<-
signif(rbind(
summary(intrxn.mod.myte1c)$coefficients,
summary(intrxn.mod.myte2c)$coefficients,
summary(intrxn.mod.myte3c)$coefficients,
summary(intrxn.mod.myte4c)$coefficients,
summary(intrxn.mod.myte1e)$coefficients,
summary(intrxn.mod.myte2e)$coefficients,
summary(intrxn.mod.myte3e)$coefficients,
summary(intrxn.mod.myte4e)$coefficients,
summary(intrxn.mod.myte1o)$coefficients,
summary(intrxn.mod.myte2o)$coefficients,
summary(intrxn.mod.myte3o)$coefficients,
summary(intrxn.mod.myte4o)$coefficients,
summary(intrxn.mod.myte1s)$coefficients,
summary(intrxn.mod.myte2s)$coefficients,
summary(intrxn.mod.myte3s)$coefficients,
summary(intrxn.mod.myte4s)$coefficients,
summary(intrxn.mod.myte1p)$coefficients,
summary(intrxn.mod.myte2p)$coefficients,
summary(intrxn.mod.myte3p)$coefficients,
summary(intrxn.mod.myte4p)$coefficients
), digits=3)


write.csv(te.on.my, "te.on.my.csv")

################################################################################
# my on ap #####################################################################
################################################################################

my$my.pres.abs<-recode(my$occ.num, "lo:0=0;1:hi=1")

my.s<-my[,c("my.pres.abs","ch","Nest")]

ap.my<-merge(my.s,ap,all=T)


# does the presence of Myrmica influence Aphaenogaster colonization?
intrxn.mod.apmy1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, ap.my, family=quasibinomial)
intrxn.mod.apmy2c<-glm(cbind(col.num,col.den) ~ my.pres.abs, ap.my, family=quasibinomial)
intrxn.mod.apmy3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + my.pres.abs, ap.my, family=quasibinomial)
intrxn.mod.apmy4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * my.pres.abs, ap.my, family=quasibinomial)

summary(intrxn.mod.apmy1c)
summary(intrxn.mod.apmy2c)
summary(intrxn.mod.apmy3c)
summary(intrxn.mod.apmy4c)

# does the presence of Myrmica influence Aphaenogaster extinction?
intrxn.mod.apmy1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, ap.my, family=quasibinomial)
intrxn.mod.apmy2e<-glm(cbind(ext.num,ext.den) ~ my.pres.abs, ap.my, family=quasibinomial)
intrxn.mod.apmy3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + my.pres.abs, ap.my, family=quasibinomial)
intrxn.mod.apmy4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * my.pres.abs, ap.my, family=quasibinomial)

summary(intrxn.mod.apmy1e)
summary(intrxn.mod.apmy2e)
summary(intrxn.mod.apmy3e)
summary(intrxn.mod.apmy4e)

# does the presence of Myrmica influence Aphaenogaster occupancy?
intrxn.mod.apmy1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, ap.my, family=quasibinomial)
intrxn.mod.apmy2o<-glm(cbind(occ.num,occ.den) ~ my.pres.abs, ap.my, family=quasibinomial)
intrxn.mod.apmy3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + my.pres.abs, ap.my, family=quasibinomial)
intrxn.mod.apmy4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * my.pres.abs, ap.my, family=quasibinomial)

summary(intrxn.mod.apmy1o)
summary(intrxn.mod.apmy2o)
summary(intrxn.mod.apmy3o)
summary(intrxn.mod.apmy4o)

# does the presence of Myrmica influence Aphaenogaster persistence?
intrxn.mod.apmy1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, ap.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.apmy2s<-glm(cbind(stasis.num,stasis.den) ~ my.pres.abs, ap.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.apmy3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + my.pres.abs, ap.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.apmy4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * my.pres.abs, ap.my, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.apmy1s)
summary(intrxn.mod.apmy2s)
summary(intrxn.mod.apmy3s)
summary(intrxn.mod.apmy4s)

# does the presence of Myrmica influence Aphaenogaster persistence?
intrxn.mod.apmy1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, ap.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.apmy2p<-glm(cbind(per.num,per.den) ~ my.pres.abs, ap.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.apmy3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + my.pres.abs, ap.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.apmy4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * my.pres.abs, ap.my, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.apmy1p)
summary(intrxn.mod.apmy2p)
summary(intrxn.mod.apmy3p)
summary(intrxn.mod.apmy4p)

my.on.ap<-
signif(rbind(
summary(intrxn.mod.apmy1c)$coefficients,
summary(intrxn.mod.apmy2c)$coefficients,
summary(intrxn.mod.apmy3c)$coefficients,
summary(intrxn.mod.apmy4c)$coefficients,
summary(intrxn.mod.apmy1e)$coefficients,
summary(intrxn.mod.apmy2e)$coefficients,
summary(intrxn.mod.apmy3e)$coefficients,
summary(intrxn.mod.apmy4e)$coefficients,
summary(intrxn.mod.apmy1o)$coefficients,
summary(intrxn.mod.apmy2o)$coefficients,
summary(intrxn.mod.apmy3o)$coefficients,
summary(intrxn.mod.apmy4o)$coefficients,
summary(intrxn.mod.apmy1s)$coefficients,
summary(intrxn.mod.apmy2s)$coefficients,
summary(intrxn.mod.apmy3s)$coefficients,
summary(intrxn.mod.apmy4s)$coefficients,
summary(intrxn.mod.apmy1p)$coefficients,
summary(intrxn.mod.apmy2p)$coefficients,
summary(intrxn.mod.apmy3p)$coefficients,
summary(intrxn.mod.apmy4p)$coefficients
), digits=3)


write.csv(my.on.ap, "my.on.ap.csv")

################################################################################
# my on ca #####################################################################
################################################################################

my$my.pres.abs<-recode(my$occ.num, "lo:0=0;1:hi=1")

my.s<-my[,c("my.pres.abs","ch","Nest")]

ca.my<-merge(my.s,ca,all=T)


# does the presence of Myrmica influence Camponotus colonization?
intrxn.mod.camy1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, ca.my, family=quasibinomial)
intrxn.mod.camy2c<-glm(cbind(col.num,col.den) ~ my.pres.abs, ca.my, family=quasibinomial)
intrxn.mod.camy3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + my.pres.abs, ca.my, family=quasibinomial)
intrxn.mod.camy4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * my.pres.abs, ca.my, family=quasibinomial)

summary(intrxn.mod.camy1c)
summary(intrxn.mod.camy2c)
summary(intrxn.mod.camy3c)
summary(intrxn.mod.camy4c)

# does the presence of Myrmica influence Camponotus extinction?
intrxn.mod.camy1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, ca.my, family=quasibinomial)
intrxn.mod.camy2e<-glm(cbind(ext.num,ext.den) ~ my.pres.abs, ca.my, family=quasibinomial)
intrxn.mod.camy3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + my.pres.abs, ca.my, family=quasibinomial)
intrxn.mod.camy4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * my.pres.abs, ca.my, family=quasibinomial)

summary(intrxn.mod.camy1e)
summary(intrxn.mod.camy2e)
summary(intrxn.mod.camy3e)
summary(intrxn.mod.camy4e)

# does the presence of Myrmica influence Camponotus occupancy?
intrxn.mod.camy1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, ca.my, family=quasibinomial)
intrxn.mod.camy2o<-glm(cbind(occ.num,occ.den) ~ my.pres.abs, ca.my, family=quasibinomial)
intrxn.mod.camy3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + my.pres.abs, ca.my, family=quasibinomial)
intrxn.mod.camy4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * my.pres.abs, ca.my, family=quasibinomial)

summary(intrxn.mod.camy1o)
summary(intrxn.mod.camy2o)
summary(intrxn.mod.camy3o)
summary(intrxn.mod.camy4o)

# does the presence of Myrmica influence Camponotus persistence?
intrxn.mod.camy1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, ca.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.camy2s<-glm(cbind(stasis.num,stasis.den) ~ my.pres.abs, ca.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.camy3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + my.pres.abs, ca.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.camy4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * my.pres.abs, ca.my, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.camy1s)
summary(intrxn.mod.camy2s)
summary(intrxn.mod.camy3s)
summary(intrxn.mod.camy4s)

# does the presence of Myrmica influence Camponotus persistence?
intrxn.mod.camy1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, ca.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.camy2p<-glm(cbind(per.num,per.den) ~ my.pres.abs, ca.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.camy3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + my.pres.abs, ca.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.camy4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * my.pres.abs, ca.my, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.camy1p)
summary(intrxn.mod.camy2p)
summary(intrxn.mod.camy3p)
summary(intrxn.mod.camy4p)

my.on.ca<-
signif(rbind(
summary(intrxn.mod.camy1c)$coefficients,
summary(intrxn.mod.camy2c)$coefficients,
summary(intrxn.mod.camy3c)$coefficients,
summary(intrxn.mod.camy4c)$coefficients,
summary(intrxn.mod.camy1e)$coefficients,
summary(intrxn.mod.camy2e)$coefficients,
summary(intrxn.mod.camy3e)$coefficients,
summary(intrxn.mod.camy4e)$coefficients,
summary(intrxn.mod.camy1o)$coefficients,
summary(intrxn.mod.camy2o)$coefficients,
summary(intrxn.mod.camy3o)$coefficients,
summary(intrxn.mod.camy4o)$coefficients,
summary(intrxn.mod.camy1s)$coefficients,
summary(intrxn.mod.camy2s)$coefficients,
summary(intrxn.mod.camy3s)$coefficients,
summary(intrxn.mod.camy4s)$coefficients,
summary(intrxn.mod.camy1p)$coefficients,
summary(intrxn.mod.camy2p)$coefficients,
summary(intrxn.mod.camy3p)$coefficients,
summary(intrxn.mod.camy4p)$coefficients
), digits=3)


write.csv(my.on.ca, "my.on.ca.csv")

################################################################################
# my on la #####################################################################
################################################################################

my$my.pres.abs<-recode(my$occ.num, "lo:0=0;1:hi=1")

my.s<-my[,c("my.pres.abs","ch","Nest")]

la.my<-merge(my.s,la,all=T)


# does the presence of Myrmica influence Lasius colonization?
intrxn.mod.lamy1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, la.my, family=quasibinomial)
intrxn.mod.lamy2c<-glm(cbind(col.num,col.den) ~ my.pres.abs, la.my, family=quasibinomial)
intrxn.mod.lamy3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + my.pres.abs, la.my, family=quasibinomial)
intrxn.mod.lamy4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * my.pres.abs, la.my, family=quasibinomial)

summary(intrxn.mod.lamy1c)
summary(intrxn.mod.lamy2c)
summary(intrxn.mod.lamy3c)
summary(intrxn.mod.lamy4c)

# does the presence of Myrmica influence Lasius extinction?
intrxn.mod.lamy1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, la.my, family=quasibinomial)
intrxn.mod.lamy2e<-glm(cbind(ext.num,ext.den) ~ my.pres.abs, la.my, family=quasibinomial)
intrxn.mod.lamy3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + my.pres.abs, la.my, family=quasibinomial)
intrxn.mod.lamy4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * my.pres.abs, la.my, family=quasibinomial)

summary(intrxn.mod.lamy1e)
summary(intrxn.mod.lamy2e)
summary(intrxn.mod.lamy3e)
summary(intrxn.mod.lamy4e)

# does the presence of Myrmica influence Lasius occupancy?
intrxn.mod.lamy1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, la.my, family=quasibinomial)
intrxn.mod.lamy2o<-glm(cbind(occ.num,occ.den) ~ my.pres.abs, la.my, family=quasibinomial)
intrxn.mod.lamy3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + my.pres.abs, la.my, family=quasibinomial)
intrxn.mod.lamy4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * my.pres.abs, la.my, family=quasibinomial)

summary(intrxn.mod.lamy1o)
summary(intrxn.mod.lamy2o)
summary(intrxn.mod.lamy3o)
summary(intrxn.mod.lamy4o)

# does the presence of Myrmica influence Lasius persistence?
intrxn.mod.lamy1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, la.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.lamy2s<-glm(cbind(stasis.num,stasis.den) ~ my.pres.abs, la.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.lamy3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + my.pres.abs, la.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.lamy4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * my.pres.abs, la.my, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.lamy1s)
summary(intrxn.mod.lamy2s)
summary(intrxn.mod.lamy3s)
summary(intrxn.mod.lamy4s)

# does the presence of Myrmica influence Lasius persistence?
intrxn.mod.lamy1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, la.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.lamy2p<-glm(cbind(per.num,per.den) ~ my.pres.abs, la.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.lamy3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + my.pres.abs, la.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.lamy4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * my.pres.abs, la.my, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.lamy1p)
summary(intrxn.mod.lamy2p)
summary(intrxn.mod.lamy3p)
summary(intrxn.mod.lamy4p)

my.on.la<-
signif(rbind(
summary(intrxn.mod.lamy1c)$coefficients,
summary(intrxn.mod.lamy2c)$coefficients,
summary(intrxn.mod.lamy3c)$coefficients,
summary(intrxn.mod.lamy4c)$coefficients,
summary(intrxn.mod.lamy1e)$coefficients,
summary(intrxn.mod.lamy2e)$coefficients,
summary(intrxn.mod.lamy3e)$coefficients,
summary(intrxn.mod.lamy4e)$coefficients,
summary(intrxn.mod.lamy1o)$coefficients,
summary(intrxn.mod.lamy2o)$coefficients,
summary(intrxn.mod.lamy3o)$coefficients,
summary(intrxn.mod.lamy4o)$coefficients,
summary(intrxn.mod.lamy1s)$coefficients,
summary(intrxn.mod.lamy2s)$coefficients,
summary(intrxn.mod.lamy3s)$coefficients,
summary(intrxn.mod.lamy4s)$coefficients,
summary(intrxn.mod.lamy1p)$coefficients,
summary(intrxn.mod.lamy2p)$coefficients,
summary(intrxn.mod.lamy3p)$coefficients,
summary(intrxn.mod.lamy4p)$coefficients
), digits=3)


write.csv(my.on.la, "my.on.la.csv")

################################################################################
# my on te #####################################################################
################################################################################

my$my.pres.abs<-recode(my$occ.num, "lo:0=0;1:hi=1")

my.s<-my[,c("my.pres.abs","ch","Nest")]

te.my<-merge(my.s,te,all=T)


# does the presence of Myrmica influence Temnothorax colonization?
intrxn.mod.temy1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, te.my, family=quasibinomial)
intrxn.mod.temy2c<-glm(cbind(col.num,col.den) ~ my.pres.abs, te.my, family=quasibinomial)
intrxn.mod.temy3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + my.pres.abs, te.my, family=quasibinomial)
intrxn.mod.temy4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * my.pres.abs, te.my, family=quasibinomial)

summary(intrxn.mod.temy1c)
summary(intrxn.mod.temy2c)
summary(intrxn.mod.temy3c)
summary(intrxn.mod.temy4c)

# does the presence of Myrmica influence Temnothorax extinction?
intrxn.mod.temy1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, te.my, family=quasibinomial)
intrxn.mod.temy2e<-glm(cbind(ext.num,ext.den) ~ my.pres.abs, te.my, family=quasibinomial)
intrxn.mod.temy3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + my.pres.abs, te.my, family=quasibinomial)
intrxn.mod.temy4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * my.pres.abs, te.my, family=quasibinomial)

summary(intrxn.mod.temy1e)
summary(intrxn.mod.temy2e)
summary(intrxn.mod.temy3e)
summary(intrxn.mod.temy4e)

# does the presence of Myrmica influence Temnothorax occupancy?
intrxn.mod.temy1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, te.my, family=quasibinomial)
intrxn.mod.temy2o<-glm(cbind(occ.num,occ.den) ~ my.pres.abs, te.my, family=quasibinomial)
intrxn.mod.temy3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + my.pres.abs, te.my, family=quasibinomial)
intrxn.mod.temy4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * my.pres.abs, te.my, family=quasibinomial)

summary(intrxn.mod.temy1o)
summary(intrxn.mod.temy2o)
summary(intrxn.mod.temy3o)
summary(intrxn.mod.temy4o)

# does the presence of Myrmica influence Temnothorax persistence?
intrxn.mod.temy1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, te.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.temy2s<-glm(cbind(stasis.num,stasis.den) ~ my.pres.abs, te.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.temy3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + my.pres.abs, te.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.temy4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * my.pres.abs, te.my, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.temy1s)
summary(intrxn.mod.temy2s)
summary(intrxn.mod.temy3s)
summary(intrxn.mod.temy4s)

# does the presence of Myrmica influence Temnothorax persistence?
intrxn.mod.temy1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, te.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.temy2p<-glm(cbind(per.num,per.den) ~ my.pres.abs, te.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.temy3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + my.pres.abs, te.my, family=quasibinomial, na.action=na.omit)
intrxn.mod.temy4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * my.pres.abs, te.my, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.temy1p)
summary(intrxn.mod.temy2p)
summary(intrxn.mod.temy3p)
summary(intrxn.mod.temy4p)

my.on.te<-
signif(rbind(
summary(intrxn.mod.temy1c)$coefficients,
summary(intrxn.mod.temy2c)$coefficients,
summary(intrxn.mod.temy3c)$coefficients,
summary(intrxn.mod.temy4c)$coefficients,
summary(intrxn.mod.temy1e)$coefficients,
summary(intrxn.mod.temy2e)$coefficients,
summary(intrxn.mod.temy3e)$coefficients,
summary(intrxn.mod.temy4e)$coefficients,
summary(intrxn.mod.temy1o)$coefficients,
summary(intrxn.mod.temy2o)$coefficients,
summary(intrxn.mod.temy3o)$coefficients,
summary(intrxn.mod.temy4o)$coefficients,
summary(intrxn.mod.temy1s)$coefficients,
summary(intrxn.mod.temy2s)$coefficients,
summary(intrxn.mod.temy3s)$coefficients,
summary(intrxn.mod.temy4s)$coefficients,
summary(intrxn.mod.temy1p)$coefficients,
summary(intrxn.mod.temy2p)$coefficients,
summary(intrxn.mod.temy3p)$coefficients,
summary(intrxn.mod.temy4p)$coefficients
), digits=3)


write.csv(my.on.te, "my.on.te.csv")

################################################################################
# la on ap #####################################################################
################################################################################

la$la.pres.abs<-recode(la$occ.num, "lo:0=0;1:hi=1")

la.s<-la[,c("la.pres.abs","ch","Nest")]

ap.la<-merge(la.s,ap,all=T)


# does the presence of Lasius influence Aphaenogaster colonization?
intrxn.mod.apla1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, ap.la, family=quasibinomial)
intrxn.mod.apla2c<-glm(cbind(col.num,col.den) ~ la.pres.abs, ap.la, family=quasibinomial)
intrxn.mod.apla3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + la.pres.abs, ap.la, family=quasibinomial)
intrxn.mod.apla4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * la.pres.abs, ap.la, family=quasibinomial)

summary(intrxn.mod.apla1c)
summary(intrxn.mod.apla2c)
summary(intrxn.mod.apla3c)
summary(intrxn.mod.apla4c)

# does the presence of Lasius influence Aphaenogaster extinction?
intrxn.mod.apla1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, ap.la, family=quasibinomial)
intrxn.mod.apla2e<-glm(cbind(ext.num,ext.den) ~ la.pres.abs, ap.la, family=quasibinomial)
intrxn.mod.apla3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + la.pres.abs, ap.la, family=quasibinomial)
intrxn.mod.apla4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * la.pres.abs, ap.la, family=quasibinomial)

summary(intrxn.mod.apla1e)
summary(intrxn.mod.apla2e)
summary(intrxn.mod.apla3e)
summary(intrxn.mod.apla4e)

# does the presence of Lasius influence Aphaenogaster occupancy?
intrxn.mod.apla1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, ap.la, family=quasibinomial)
intrxn.mod.apla2o<-glm(cbind(occ.num,occ.den) ~ la.pres.abs, ap.la, family=quasibinomial)
intrxn.mod.apla3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + la.pres.abs, ap.la, family=quasibinomial)
intrxn.mod.apla4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * la.pres.abs, ap.la, family=quasibinomial)

summary(intrxn.mod.apla1o)
summary(intrxn.mod.apla2o)
summary(intrxn.mod.apla3o)
summary(intrxn.mod.apla4o)

# does the presence of Lasius influence Aphaenogaster persistence?
intrxn.mod.apla1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, ap.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.apla2s<-glm(cbind(stasis.num,stasis.den) ~ la.pres.abs, ap.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.apla3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + la.pres.abs, ap.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.apla4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * la.pres.abs, ap.la, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.apla1s)
summary(intrxn.mod.apla2s)
summary(intrxn.mod.apla3s)
summary(intrxn.mod.apla4s)

# does the presence of Lasius influence Aphaenogaster persistence?
intrxn.mod.apla1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, ap.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.apla2p<-glm(cbind(per.num,per.den) ~ la.pres.abs, ap.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.apla3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + la.pres.abs, ap.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.apla4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * la.pres.abs, ap.la, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.apla1p)
summary(intrxn.mod.apla2p)
summary(intrxn.mod.apla3p)
summary(intrxn.mod.apla4p)

la.on.ap<-
signif(rbind(
summary(intrxn.mod.apla1c)$coefficients,
summary(intrxn.mod.apla2c)$coefficients,
summary(intrxn.mod.apla3c)$coefficients,
summary(intrxn.mod.apla4c)$coefficients,
summary(intrxn.mod.apla1e)$coefficients,
summary(intrxn.mod.apla2e)$coefficients,
summary(intrxn.mod.apla3e)$coefficients,
summary(intrxn.mod.apla4e)$coefficients,
summary(intrxn.mod.apla1o)$coefficients,
summary(intrxn.mod.apla2o)$coefficients,
summary(intrxn.mod.apla3o)$coefficients,
summary(intrxn.mod.apla4o)$coefficients,
summary(intrxn.mod.apla1s)$coefficients,
summary(intrxn.mod.apla2s)$coefficients,
summary(intrxn.mod.apla3s)$coefficients,
summary(intrxn.mod.apla4s)$coefficients,
summary(intrxn.mod.apla1p)$coefficients,
summary(intrxn.mod.apla2p)$coefficients,
summary(intrxn.mod.apla3p)$coefficients,
summary(intrxn.mod.apla4p)$coefficients
), digits=3)

write.csv(la.on.ap, "la.on.ap.csv")

################################################################################
# la on ca #####################################################################
################################################################################

la$la.pres.abs<-recode(la$occ.num, "lo:0=0;1:hi=1")

la.s<-la[,c("la.pres.abs","ch","Nest")]

ca.la<-merge(la.s,ca,all=T)


# does the presence of Lasius influence Camponotus colonization?
intrxn.mod.cala1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, ca.la, family=quasibinomial)
intrxn.mod.cala2c<-glm(cbind(col.num,col.den) ~ la.pres.abs, ca.la, family=quasibinomial)
intrxn.mod.cala3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + la.pres.abs, ca.la, family=quasibinomial)
intrxn.mod.cala4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * la.pres.abs, ca.la, family=quasibinomial)

summary(intrxn.mod.cala1c)
summary(intrxn.mod.cala2c)
summary(intrxn.mod.cala3c)
summary(intrxn.mod.cala4c)

# does the presence of Lasius influence Camponotus extinction?
intrxn.mod.cala1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, ca.la, family=quasibinomial)
intrxn.mod.cala2e<-glm(cbind(ext.num,ext.den) ~ la.pres.abs, ca.la, family=quasibinomial)
intrxn.mod.cala3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + la.pres.abs, ca.la, family=quasibinomial)
intrxn.mod.cala4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * la.pres.abs, ca.la, family=quasibinomial)

summary(intrxn.mod.cala1e)
summary(intrxn.mod.cala2e)
summary(intrxn.mod.cala3e)
summary(intrxn.mod.cala4e)

# does the presence of Lasius influence Camponotus occupancy?
intrxn.mod.cala1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, ca.la, family=quasibinomial)
intrxn.mod.cala2o<-glm(cbind(occ.num,occ.den) ~ la.pres.abs, ca.la, family=quasibinomial)
intrxn.mod.cala3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + la.pres.abs, ca.la, family=quasibinomial)
intrxn.mod.cala4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * la.pres.abs, ca.la, family=quasibinomial)

summary(intrxn.mod.cala1o)
summary(intrxn.mod.cala2o)
summary(intrxn.mod.cala3o)
summary(intrxn.mod.cala4o)

# does the presence of Lasius influence Camponotus persistence?
intrxn.mod.cala1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, ca.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.cala2s<-glm(cbind(stasis.num,stasis.den) ~ la.pres.abs, ca.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.cala3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + la.pres.abs, ca.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.cala4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * la.pres.abs, ca.la, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.cala1s)
summary(intrxn.mod.cala2s)
summary(intrxn.mod.cala3s)
summary(intrxn.mod.cala4s)

# does the presence of Lasius influence Camponotus persistence?
intrxn.mod.cala1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, ca.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.cala2p<-glm(cbind(per.num,per.den) ~ la.pres.abs, ca.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.cala3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + la.pres.abs, ca.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.cala4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * la.pres.abs, ca.la, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.cala1p)
summary(intrxn.mod.cala2p)
summary(intrxn.mod.cala3p)
summary(intrxn.mod.cala4p)

la.on.ca<-
signif(rbind(
summary(intrxn.mod.cala1c)$coefficients,
summary(intrxn.mod.cala2c)$coefficients,
summary(intrxn.mod.cala3c)$coefficients,
summary(intrxn.mod.cala4c)$coefficients,
summary(intrxn.mod.cala1e)$coefficients,
summary(intrxn.mod.cala2e)$coefficients,
summary(intrxn.mod.cala3e)$coefficients,
summary(intrxn.mod.cala4e)$coefficients,
summary(intrxn.mod.cala1o)$coefficients,
summary(intrxn.mod.cala2o)$coefficients,
summary(intrxn.mod.cala3o)$coefficients,
summary(intrxn.mod.cala4o)$coefficients,
summary(intrxn.mod.cala1s)$coefficients,
summary(intrxn.mod.cala2s)$coefficients,
summary(intrxn.mod.cala3s)$coefficients,
summary(intrxn.mod.cala4s)$coefficients,
summary(intrxn.mod.cala1p)$coefficients,
summary(intrxn.mod.cala2p)$coefficients,
summary(intrxn.mod.cala3p)$coefficients,
summary(intrxn.mod.cala4p)$coefficients
), digits=3)

write.csv(la.on.ca, "la.on.ca.csv")

################################################################################
# la on my #####################################################################
################################################################################

la$la.pres.abs<-recode(la$occ.num, "lo:0=0;1:hi=1")

la.s<-la[,c("la.pres.abs","ch","Nest")]

my.la<-merge(la.s,my,all=T)


# does the presence of Lasius influence Myrmica colonization?
intrxn.mod.myla1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, my.la, family=quasibinomial)
intrxn.mod.myla2c<-glm(cbind(col.num,col.den) ~ la.pres.abs, my.la, family=quasibinomial)
intrxn.mod.myla3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + la.pres.abs, my.la, family=quasibinomial)
intrxn.mod.myla4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * la.pres.abs, my.la, family=quasibinomial)

summary(intrxn.mod.myla1c)
summary(intrxn.mod.myla2c)
summary(intrxn.mod.myla3c)
summary(intrxn.mod.myla4c)

# does the presence of Lasius influence Myrmica extinction?
intrxn.mod.myla1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, my.la, family=quasibinomial)
intrxn.mod.myla2e<-glm(cbind(ext.num,ext.den) ~ la.pres.abs, my.la, family=quasibinomial)
intrxn.mod.myla3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + la.pres.abs, my.la, family=quasibinomial)
intrxn.mod.myla4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * la.pres.abs, my.la, family=quasibinomial)

summary(intrxn.mod.myla1e)
summary(intrxn.mod.myla2e)
summary(intrxn.mod.myla3e)
summary(intrxn.mod.myla4e)

# does the presence of Lasius influence Myrmica occupancy?
intrxn.mod.myla1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, my.la, family=quasibinomial)
intrxn.mod.myla2o<-glm(cbind(occ.num,occ.den) ~ la.pres.abs, my.la, family=quasibinomial)
intrxn.mod.myla3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + la.pres.abs, my.la, family=quasibinomial)
intrxn.mod.myla4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * la.pres.abs, my.la, family=quasibinomial)

summary(intrxn.mod.myla1o)
summary(intrxn.mod.myla2o)
summary(intrxn.mod.myla3o)
summary(intrxn.mod.myla4o)

# does the presence of Lasius influence Myrmica persistence?
intrxn.mod.myla1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, my.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.myla2s<-glm(cbind(stasis.num,stasis.den) ~ la.pres.abs, my.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.myla3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + la.pres.abs, my.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.myla4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * la.pres.abs, my.la, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.myla1s)
summary(intrxn.mod.myla2s)
summary(intrxn.mod.myla3s)
summary(intrxn.mod.myla4s)

# does the presence of Lasius influence Myrmica persistence?
intrxn.mod.myla1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, my.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.myla2p<-glm(cbind(per.num,per.den) ~ la.pres.abs, my.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.myla3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + la.pres.abs, my.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.myla4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * la.pres.abs, my.la, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.myla1p)
summary(intrxn.mod.myla2p)
summary(intrxn.mod.myla3p)
summary(intrxn.mod.myla4p)

la.on.my<-
signif(rbind(
summary(intrxn.mod.myla1c)$coefficients,
summary(intrxn.mod.myla2c)$coefficients,
summary(intrxn.mod.myla3c)$coefficients,
summary(intrxn.mod.myla4c)$coefficients,
summary(intrxn.mod.myla1e)$coefficients,
summary(intrxn.mod.myla2e)$coefficients,
summary(intrxn.mod.myla3e)$coefficients,
summary(intrxn.mod.myla4e)$coefficients,
summary(intrxn.mod.myla1o)$coefficients,
summary(intrxn.mod.myla2o)$coefficients,
summary(intrxn.mod.myla3o)$coefficients,
summary(intrxn.mod.myla4o)$coefficients,
summary(intrxn.mod.myla1s)$coefficients,
summary(intrxn.mod.myla2s)$coefficients,
summary(intrxn.mod.myla3s)$coefficients,
summary(intrxn.mod.myla4s)$coefficients,
summary(intrxn.mod.myla1p)$coefficients,
summary(intrxn.mod.myla2p)$coefficients,
summary(intrxn.mod.myla3p)$coefficients,
summary(intrxn.mod.myla4p)$coefficients
), digits=3)


write.csv(la.on.my, "la.on.my.csv")

################################################################################
# la on te #####################################################################
################################################################################

la$la.pres.abs<-recode(la$occ.num, "lo:0=0;1:hi=1")

la.s<-la[,c("la.pres.abs","ch","Nest")]

te.la<-merge(la.s,te,all=T)


# does the presence of Lasius influence Temnothorax colonization?
intrxn.mod.tela1c<-glm(cbind(col.num,col.den) ~ CAT_Avg, te.la, family=quasibinomial)
intrxn.mod.tela2c<-glm(cbind(col.num,col.den) ~ la.pres.abs, te.la, family=quasibinomial)
intrxn.mod.tela3c<-glm(cbind(col.num,col.den) ~ CAT_Avg + la.pres.abs, te.la, family=quasibinomial)
intrxn.mod.tela4c<-glm(cbind(col.num,col.den) ~ CAT_Avg * la.pres.abs, te.la, family=quasibinomial)

summary(intrxn.mod.tela1c)
summary(intrxn.mod.tela2c)
summary(intrxn.mod.tela3c)
summary(intrxn.mod.tela4c)

# does the presence of Lasius influence Temnothorax extinction?
intrxn.mod.tela1e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg, te.la, family=quasibinomial)
intrxn.mod.tela2e<-glm(cbind(ext.num,ext.den) ~ la.pres.abs, te.la, family=quasibinomial)
intrxn.mod.tela3e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg + la.pres.abs, te.la, family=quasibinomial)
intrxn.mod.tela4e<-glm(cbind(ext.num,ext.den) ~ CAT_Avg * la.pres.abs, te.la, family=quasibinomial)

summary(intrxn.mod.tela1e)
summary(intrxn.mod.tela2e)
summary(intrxn.mod.tela3e)
summary(intrxn.mod.tela4e)

# does the presence of Lasius influence Temnothorax occupancy?
intrxn.mod.tela1o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg, te.la, family=quasibinomial)
intrxn.mod.tela2o<-glm(cbind(occ.num,occ.den) ~ la.pres.abs, te.la, family=quasibinomial)
intrxn.mod.tela3o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg + la.pres.abs, te.la, family=quasibinomial)
intrxn.mod.tela4o<-glm(cbind(occ.num,occ.den) ~ CAT_Avg * la.pres.abs, te.la, family=quasibinomial)

summary(intrxn.mod.tela1o)
summary(intrxn.mod.tela2o)
summary(intrxn.mod.tela3o)
summary(intrxn.mod.tela4o)

# does the presence of Lasius influence Temnothorax persistence?
intrxn.mod.tela1s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg, te.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.tela2s<-glm(cbind(stasis.num,stasis.den) ~ la.pres.abs, te.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.tela3s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg + la.pres.abs, te.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.tela4s<-glm(cbind(stasis.num,stasis.den) ~ CAT_Avg * la.pres.abs, te.la, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.tela1s)
summary(intrxn.mod.tela2s)
summary(intrxn.mod.tela3s)
summary(intrxn.mod.tela4s)

# does the presence of Lasius influence Temnothorax persistence?
intrxn.mod.tela1p<-glm(cbind(per.num,per.den) ~ CAT_Avg, te.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.tela2p<-glm(cbind(per.num,per.den) ~ la.pres.abs, te.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.tela3p<-glm(cbind(per.num,per.den) ~ CAT_Avg + la.pres.abs, te.la, family=quasibinomial, na.action=na.omit)
intrxn.mod.tela4p<-glm(cbind(per.num,per.den) ~ CAT_Avg * la.pres.abs, te.la, family=quasibinomial, na.action=na.omit)

summary(intrxn.mod.tela1p)
summary(intrxn.mod.tela2p)
summary(intrxn.mod.tela3p)
summary(intrxn.mod.tela4p)

la.on.te<-
signif(rbind(
summary(intrxn.mod.tela1c)$coefficients,
summary(intrxn.mod.tela2c)$coefficients,
summary(intrxn.mod.tela3c)$coefficients,
summary(intrxn.mod.tela4c)$coefficients,
summary(intrxn.mod.tela1e)$coefficients,
summary(intrxn.mod.tela2e)$coefficients,
summary(intrxn.mod.tela3e)$coefficients,
summary(intrxn.mod.tela4e)$coefficients,
summary(intrxn.mod.tela1o)$coefficients,
summary(intrxn.mod.tela2o)$coefficients,
summary(intrxn.mod.tela3o)$coefficients,
summary(intrxn.mod.tela4o)$coefficients,
summary(intrxn.mod.tela1s)$coefficients,
summary(intrxn.mod.tela2s)$coefficients,
summary(intrxn.mod.tela3s)$coefficients,
summary(intrxn.mod.tela4s)$coefficients,
summary(intrxn.mod.tela1p)$coefficients,
summary(intrxn.mod.tela2p)$coefficients,
summary(intrxn.mod.tela3p)$coefficients,
summary(intrxn.mod.tela4p)$coefficients
), digits=3)

write.csv(la.on.te, "la.on.te.csv")














